#!/usr/bin/perl

use IO::File;
use POSIX qw(tmpnam);
use strict;
use Cwd;


sub parseCgiRequest {
    my ($query,%formdata);
    %formdata=();
    if( $ENV{'REQUEST_METHOD'} eq 'POST' ) {
        read(STDIN,$query,$ENV{'CONTENT_LENGTH'});
    } else {
        $query=$ENV{'QUERY_STRING'};
    }

    my @params=split(/&/,$query);
    
    $formdata{'djem_version'} = 'djem2';
    $formdata{'http_host'} = $ENV{'SERVER_NAME'};
    $formdata{'install_version'} = $0;

    foreach my $keyvalueparam (@params) {
        my ($keyparam, $valueparam) = split(/=/, $keyvalueparam);
        $valueparam=~tr/+/ /;
        $valueparam=~ s/%([\dA-Fa-f][\dA-Fa-f])/pack ("C", hex ($1))/eg;
        $formdata{$keyparam}=$valueparam;
    }
    return ( wantarray ? (\%formdata,$query) : \%formdata );
}

sub getSystemLibraries {
    my ($env,$stub_file,$uname,%libs,$res,$sock,$arch);
    
    $env=locateExecutables(undef);
    
    $stub_file=getTmpName();
    unless( open(F,">$stub_file") ) {
	htmlDie("Cannot create stub file $stub_file: $!");
    }
    
    $uname=getUname($env);
    $arch=getArch($env);
    
    if( $uname=~/linux/i ) {
	if( ($arch eq "i386") || ($arch eq "x86_64") ) {
	    print F getBinaryResource("Linux"); 
	} elsif( $arch eq "amd64" ) {
	    print F getBinaryResource("Linux_amd64"); 
	} else {
	    htmlDie("Unsupported Linux architecture: $uname ($arch)");
	}
    } elsif ( $uname=~/freebsd/i ) {
	if( $uname=~/6\./ && ($arch eq "amd64") ) {
	    print F getBinaryResource("FreeBSD6_amd64");
	} elsif( $uname=~/7\./ && ($arch eq "amd64") ) {
	    print F getBinaryResource("FreeBSD7_amd64");
	} elsif( $uname=~/8\./ && ($arch eq "amd64") ) {
	    print F getBinaryResource("FreeBSD8_amd64");
	} elsif( $uname=~/9\./ && ($arch eq "amd64") ) {
	    print F getBinaryResource("FreeBSD8_amd64");
	} elsif( $uname=~/8\./ ) {
	    print F getBinaryResource("FreeBSD8");
	} elsif( $uname=~/9\./ ) {
	    print F getBinaryResource("FreeBSD8");
	} elsif( $uname=~/7\./ ) {
	    print F getBinaryResource("FreeBSD7");
	} elsif( $uname=~/[56]\./ ) {
	    print F getBinaryResource("FreeBSD6");
	} elsif( $uname=~/4\./ ) {
	    print F getBinaryResource("FreeBSD4");
	} else {
	    htmlDie("Unsupported FreeBSD architecture: $uname ($arch)");
	}
    } else {
	htmlDie("Unsupported OS: $uname ($arch)");
    }

    close F;
    chmod(0755,$stub_file);
    
    open(L,"$env->{ldd} $stub_file|") || htmlDie("Cannot spawn ldd process");
    while(<L>) {
	chomp;
	s/^\s+//;
        next if /ld-linux\.so/ || /linux-gate\.so/ || /$stub_file/;
	my ($lib,$path)=(/^(.+) => (.+)/); $path=~s/ \([0-9a-zA-Zx]+\)$//;
	$libs{$lib}=$path;
    }
    close L;

    $res="";
    foreach my $k (keys %libs) {
	$res.="$k=$libs{$k};";
    }

    $sock=getMySQLSocket($env);
    $res.="\r\nmysql_socket=$sock";

    return $res;
}


sub downloadWithWget {
    my ($env,$tar_name,$raw_query)=@_;
    my ($post_file,$line);
    
    $post_file=getTmpName();
    unless( open(F,">$post_file") ) {
	htmlDie("wget: Cannot create temporary file $post_file for use with wget");
    }
    print F $raw_query;
    close F;
    
    `$env->{wget} -q --post-file=$post_file -O $tar_name http://www.djem.ru/access/install.php`;
    
}


sub downloadWithLWP {
    my ($env,$tar_name,$raw_query)=@_;
    my ($ua,$req,$res);
    
    $ua=LWP::UserAgent->new;
    $ua->agent("DJEM-Installer");
  
    $req = HTTP::Request->new(POST=>'http://www.djem.ru/access/install.php');
    $req->content_type('application/x-www-form-urlencoded');
    $req->content($raw_query);
	  
    $res = $ua->request($req);
	      
    if ($res->is_success) {
	unless( open(F,">$tar_name") ) {
	    htmlDie("LWP: Cannot create DJEM-server archive file $tar_name: $!");
	}
	print F $res->content;
	close F;
    } else {
	htmlDie("LWP: Cannot download DJEM-server archive: " . $res->status_line);  
    }
}


sub downloadWithLynx {
    my ($env,$tar_name,$raw_query)=@_;
    
    unless( open(F,"| $env->{lynx} -post_data http://www.djem.ru/access/install.php > $tar_name") ) {
	htmlDie("Lynx: Cannot spawn lynx process: $!");
    }
    
    print F $raw_query;
    print F "\n----\n";
    close F;
}


sub installDjemServer {
    my ($form,$raw_query)=@_;
    my ($env,$tar_name,$file_name,$srv_cgi,$res);

    $env=locateExecutables($form);
    $tar_name=getTmpName();
    my $currentDir = getcwd();
    
    $raw_query = $raw_query . '&djem_version=djem2&install_version='.$0.'&http_host='.$ENV{'SERVER_NAME'};
    
    if( isWgetAvailable($env) ) {
	downloadWithWget($env,$tar_name,$raw_query);
    } elsif (isLWPAvailable()) {
	downloadWithLWP($env,$tar_name,$raw_query);
    } elsif( isLynxAvailable($env) ) {
	downloadWithLynx($env,$tar_name,$raw_query);
    } else {
	htmlDie("No transport method is found");
    }

    if( -z $tar_name ) {
	htmlDie("DJEM-server archive is 0 bytes");
    }

    unless( open(F,"$tar_name") ) {
	htmlDie("Cannot open temporary DJEM-server archive $tar_name: $!");
    }
    
    my $line=<F>;
    chomp($line);
    close F;
    
    if( $line=~/^Error:/ ) {
	$line=~s/^Error://;
	htmlDie($line);
    }    

    $file_name=$tar_name;
    $file_name=~s,.*/,,; $file_name=~s,^/,,;

    `$env->{mv} $tar_name $form->{cgi_path}`;
    chdir($form->{cgi_path});

    `$env->{tar} zxf $form->{cgi_path}/$file_name`;

    unless( -e "$form->{cgi_path}/djemserver" ) {
	htmlDie("Error unpacking DJEM-server archive $form->{cgi_path}/$file_name. File djemserver is not found");
    }

    if( -e "$form->{cgi_path}/table.sql" && (($0 =~ /install2.pl/io) || ($0 =~ /install_djem.pl/io)) && ($form->{mysql_replace} eq 'on')) {
	my $mysqlPort = '';
	if ($form->{mysql_port}) {
		if ($form->{mysql_port}=~/^\d+$/) {
		    $mysqlPort = " -P$form->{mysql_port} ";
		} else {
		    $mysqlPort = " --socket=$form->{mysql_port} ";
		}
	}

	$res=`$env->{mysql} -h $form->{mysql_host} $mysqlPort -u $form->{mysql_user} -p"$form->{mysql_password}" $form->{mysql_base} < $form->{cgi_path}/table.sql`;
	unlink("$form->{cgi_path}/table.sql");
	if( $res=~/^ERROR/ ) {
	    htmlDie("Error initializing DJEM sql-tables: $res");
	}

	if( -e "$form->{cgi_path}/www.tgz") {
	    chdir($form->{htdocs_path});
	    `$env->{tar} zxf $form->{cgi_path}/www.tgz`;
	    unlink("$form->{cgi_path}/www.tgz");
	    chdir($form->{cgi_path});
	}
    }
    
    unlink("$form->{cgi_path}/$file_name");
    
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/djemserver.cgi");
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/ins");
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/ins.cgi");
    link("$form->{cgi_path}/vx","$form->{cgi_path}/vx.cgi");
    link("$form->{cgi_path}/dynadjem","$form->{cgi_path}/dynadjem.cgi");

    $srv_cgi=$form->{cgi_path};
    $srv_cgi=~s|^.+(/cgi-bin/.+?)/?$|$1|;
    $srv_cgi.="/djemserver";

    if (open(D, ">$currentDir/install2.done")) {
	print D "Successful";
	close(D);
    }
         
    print "Content-type: text/plain\n\n";
    print "ok: $srv_cgi";
}




sub updateDjemServer {
    my ($form,$raw_query)=@_;
    my ($env,$tar_name,$file_name,$srv_cgi,$res);
    


    $env=locateExecutables($form);
    $tar_name=getTmpName();
    my $currentDir = getcwd();
    
    $raw_query = $raw_query . '&djem_version=djem2&install_version='.$0.'&http_host='.$ENV{'SERVER_NAME'};
    
    if( isWgetAvailable($env) ) {
	downloadWithWget($env,$tar_name,$raw_query);
    } elsif (isLWPAvailable()) {
	downloadWithLWP($env,$tar_name,$raw_query);
    } elsif( isLynxAvailable($env) ) {
	downloadWithLynx($env,$tar_name,$raw_query);
    } else {
	htmlDie("No transport method is found");
    }


    if( -z $tar_name ) {
	htmlDie("DJEM-server archive is 0 bytes");
    }

    unless( open(F,"$tar_name") ) {
	htmlDie("Cannot open temporary DJEM-server archive $tar_name: $!");
    }
    
    my $line=<F>;
    chomp($line);
    close F;

    if( $line=~/^Error:/ ) {
	$line=~s/^Error://;
	htmlDie($line);
    }    

    $file_name=$tar_name;
    $file_name=~s,.*/,,; $file_name=~s,^/,,;

    `$env->{mv} $tar_name $form->{cgi_path}`;
    chdir($form->{cgi_path});

    `$env->{tar} zxf $form->{cgi_path}/$file_name`;

    unless( -e "$form->{cgi_path}/djemserver" ) {
	htmlDie("Error unpacking DJEM-server archive $form->{cgi_path}/$file_name. File djemserver is not found");
    }

    unlink("$form->{cgi_path}/$file_name");    
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/djemserver.cgi");
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/ins");
    link("$form->{cgi_path}/djemserver","$form->{cgi_path}/ins.cgi");
    link("$form->{cgi_path}/vx","$form->{cgi_path}/vx.cgi");
    link("$form->{cgi_path}/dynadjem","$form->{cgi_path}/dynadjem.cgi");

    $srv_cgi=$form->{cgi_path};
    $srv_cgi=~s|^.+(/cgi-bin/.+?)/?$|$1|;
    $srv_cgi.="/djemserver";
    
    if (open(D, ">$currentDir/install2.done")) {
	print D "Successful";
	close(D);
    }
	         
    print "Content-type: text/plain\n\n";
    print "ok: $srv_cgi";
}


sub uudecode {
    my($in) = @_;

    my(@result,$file,$mode);
    $mode = $file = "";
    if (
	ref($in) eq 'IO::Handle' or
	ref(\$in) eq "GLOB" or
	ref($in) eq "GLOB" or
	ref($in) eq 'FileHandle'
       ) {
	local($\) = "\n";
	binmode($in);
	while (<$in>) {
	    if ($file eq "" and !$mode){
		($mode,$file) = ($1, $2) if /^begin\s+(\d+)\s+(.+)$/ ;
		next;
	    }
	    last if /^end/;
	    push @result, uudecodeChunk($_);
	}
    } elsif (ref(\$in) eq "SCALAR") {
	while ($in =~ m/\G(.*?(\n|\r|\r\n|\n\r))/gc) {
	    my $line = $1;
	    if ($file eq "" and !$mode){
		($mode,$file) = $line =~ /^begin\s+(\d+)\s+(.+)$/ ;
		next;
	    }
	    next if $file eq "" and !$mode;
	    last if $line =~ /^end/;
	    push @result, uudecodeChunk($line);
	}
    } elsif (ref($in) eq "ARRAY") {
	my $line;
	foreach $line (@$in) {
	    if ($file eq "" and !$mode){
		($mode,$file) = $line =~ /^begin\s+(\d+)\s+(.+)$/ ;
		next;
	    }
	    next if $file eq "" and !$mode;
	    last if $line =~ /^end/;
	    push @result, uudecodeChunk($line);
	}
    }
    wantarray ? (join("",@result),$file,$mode) : join("",@result);
}

sub uudecodeChunk {
    my($chunk) = @_;
    return "" if $chunk =~ /^(?:--|CREATED)/;
    my $string = substr($chunk,0,int((((ord($chunk) - 32) & 077) + 2) / 3)*4+1);
    my $ret = unpack("u", $string);
    defined $ret ? $ret : "";
}


sub getBinaryResource {
    my ($name)=@_;
    my (%resources);

    $resources{FreeBSD6_amd64}=<<'__EOS__';
begin 644 uuencode.uu
M?T5,1@(!`0D```````````(`/@`!````$`9```````!```````````@-````
M`````````$``.``&`$``%@`5``8````%````0`````````!``$```````$``
M0```````4`$```````!0`0````````@``````````P````0```"0`0``````
M`)`!0```````D`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````"D(````````*0@`````````
M`!````````$````&````,`@````````P"%```````#`(4```````$`,`````
M``!H`P``````````$````````@````8```!0"0```````%`)4```````4`E0
M``````"``0```````(`!````````"``````````$````!````*@!````````
MJ`%```````"H`4```````!@`````````&``````````$`````````"]L:6)E
M>&5C+VQD+65L9BYS;RXQ``````@````$`````0```$9R965"4T0`>#,)`!$`
M```1``````````L````,````#P````,`````````!``````````)````$```
M```````(``````````X`````````"@`````````````````````````!````
M``````````````````````<```````````````8````%``````````T`````
M`````@````````````````````````````````````\````1`/'_4`E0````
M`````````````!@````2``<`B`5``````````````````*H````2````K`5`
M``````#8!````````-,````1`!,`D`M0```````(`````````!X````B````
MO`5````````%`````````-L````1``P`,`A0```````(`````````/X````0
M`/'_0`M0`````````````````.8````2````S`5````````"`````````#8`
M```2``H`B`=``````````````````/`````2````W`5````````O````````
M`/<````0`/'_0`M0`````````````````#P````1`/'_^`I0````````````
M``````H!```0`/'_F`M0`````````````````/(````2````[`5````````V
M`````````%(````@`````````````````````````&8````B````_`5`````
M```)``````````!L:6)C<GEP="YS;RXS`%]$64Y!34E#`%]I;FET`%]?9&5R
M96=I<W1E<E]F<F%M95]I;F9O`%]F:6YI`%]'3$]"04Q?3T9&4T547U1!0DQ%
M7P!?2G9?4F5G:7-T97)#;&%S<V5S`%]?<F5G:7-T97)?9G)A;65?:6YF;P!L
M:6)M>7-Q;&-L:65N="YS;RXQ-0!L:6)Z+G-O+C,`;&EB<W1D8RLK+G-O+C4`
M7U]G>'A?<&5R<V]N86QI='E?=C``;&EB;2YS;RXT`&QI8F,N<V\N-@!E;G9I
M<F]N`%]?<')O9VYA;64`7VEN:71?=&QS`&%T97AI=`!?961A=&$`7U]B<W-?
M<W1A<G0`7V5N9```$`M0```````'`````P``````````````&`M0```````'
M````!0``````````````(`M0```````'````"```````````````*`M0````
M```'````"@``````````````,`M0```````'````#@``````````````.`M0
M```````'````$```````````````2(/L".A?`0``Z+H!``!(@\0(PP#_-5X%
M$`#_)6`%$`"0D)"0_R5>!1``:`````#IX/____\E5@40`&@!````Z=#_____
M)4X%$`!H`@```.G`_____R5&!1``:`,```#IL/____\E/@40`&@$````Z:#_
M____)38%$`!H!0```.F0____`````$%43(UG"%53BQ](8\.%VTB-;,<02(DM
M9040`'XS2(M'"$B%P'0J2(G!2(D%\`$0`.L#2(G1#[8!A,!T%#PO2(U1`77N
M2(D5U0$0`.OE9F:0N%`)4`!(A<!T*TB)]^AJ____OX@'0`#H8/___^@'____
MB=](B>I,B>;HL@```(G'Z%?____H,O___^O6D)"0D(`]F000``!52(GE=!#K
M.)!(@\`(2(D%A0$0`/_22(L%?`$0`$B+$$B%TG7DN+P%0`!(A<!T"K^("%``
MZ-S^___&!5D$$``!R<-F9F:09F:05;C\!4``2(7`2(GE=`^^8`M0`+^("%``
MZ._^__](@SW;`Q```'09N`````!(A<!T#\F_\`I0`.G4^+__9F9FD,G#D)"0
MD)"0D)"0D)"0D)`QP,.0D)"0D)"0D)"0D)"054B)Y5-(Q\/0"E``2(/L"$B+
M!6D#$`#K$&9F9I!F9I!(@^L(_]!(BP-(@_C_=?%(@\0(6\G#D)!(@^P(Z`__
M__](@\0(PP`D1G)E94)31#H@<W)C+VQI8B]C<W4O86UD-C0O8W)T:2Y3+'8@
M,2XW(#(P,#0O,#,O,C$@,#$Z,SDZ,#$@<&5T97(@17AP("0`)$9R965"4T0Z
M('-R8R]L:6(O8W-U+V%M9#8T+V-R=&XN4RQV(#$N-B`R,#`T+S`S+S(Q(#`Q
M.C,Y.C`Q('!E=&5R($5X<"`D``````````"6!T``````````````````Z`I0
M```````4``````````$``7@0#`<(D`$````````D````'````!`&0```````
MC`````````!"#A",`D4.&$$.((,$A@,`'````$0```"@!D```````$D`````
M````2`X0A@)##08<````9````/`&0```````0@````````!!#A"&`DL-!AP`
M`````````7I0``%X$`D`K`5````````,!PB0`0``'````"0```!`!T``````
M``,`````````````````````````$``````````!``%X$`P'")`!```L````
M&````%`'0```````-@`````````$`0````X0A@($`P````T&!`$```"#`P`!
M``````````$``````````0````````!\``````````$`````````D0``````
M```!`````````)L``````````0````````"_``````````$`````````R0``
M```````,`````````(@%0```````#0````````"(!T````````0`````````
MP`%````````%`````````.@#0```````!@````````!0`D````````H`````
M````#P$````````+`````````!@`````````%0````````````````````,`
M````````^`I0```````"`````````)``````````%``````````'````````
M`!<`````````^`1`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#__________P``````````________
M__\`````````````````````4`E0````````````````````````````L@5`
M``````#"!4```````-(%0```````X@5```````#R!4````````(&0```````
M`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]C;VUM;VXO8W)T8G)A;F0N8RQV(#$N
M-"XR,BXQ(#(P,#<O,3(O,#<@,30Z,38Z-3,@:VEB($5X<"`D`"1&<F5E0E-$
M.B!S<F,O;&EB+V-S=2]A;60V-"]C<G0Q+F,L=B`Q+C$T(#(P,#0O,#@O,34@
M,38Z,3@Z-3$@9&9R($5X<"`D`$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=
M(#(P,#8P,S`U``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$72`R,#`V,#,P
M-0``1T-#.B`H1TY5*2`S+C0N-B!;1G)E94)31%T@,C`P-C`S,#4``$=#0SH@
M*$=.52D@,RXT+C8@6T9R965"4T1=(#(P,#8P,S`U```N<VAS=')T86(`+FEN
M=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N9&%T80`N96A?9G)A
M;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M``````````````````````````````````L````!`````@````````"0`4``
M`````)`!````````%0````````````````````$````````````````````3
M````!P````(`````````J`%```````"H`0```````!@`````````````````
M```$````````````````````(0````4````"`````````,`!0```````P`$`
M``````"0``````````0`````````"``````````$`````````"<````+````
M`@````````!0`D```````%`"````````F`$````````%`````0````@`````
M````&``````````O`````P````(`````````Z`-```````#H`P````````\!
M```````````````````!````````````````````-P````0````"````````
M`/@$0```````^`0```````"0``````````0````(````"``````````8````
M`````$$````!````!@````````"(!4```````(@%````````$P``````````
M``````````0````````````````````\`````0````8`````````G`5`````
M``"<!0```````'`````````````````````$`````````!``````````1P``
M``$````&`````````!`&0```````$`8```````!X`0``````````````````
M$````````````````````$T````!````!@````````"(!T```````(@'````
M````#@````````````````````0```````````````````!3`````0````(`
M````````E@=```````"6!P```````),````````````````````!````````
M````````````6P````$````#`````````#`(4```````,`@````````8````
M````````````````"````````````````````&$````!`````@````````!(
M"%```````$@(````````"`$```````````````````@`````````````````
M``!K````!@````,`````````4`E0``````!0"0```````(`!````````!0``
M```````(`````````!``````````=`````$````#`````````-`*4```````
MT`H````````0````````````````````"````````````````````'L````!
M`````P````````#@"E```````.`*````````$`````````````````````@`
M``````````````````""`````0````,`````````\`I0``````#P"@``````
M``@````````````````````(````````````````````AP````$````#````
M`````/@*4```````^`H```````!(````````````````````"``````````(
M`````````(P````(`````P````````!`"U```````$`+````````6```````
M`````````````"````````````````````"1`````0``````````````````
M``````!`"P```````"T!```````````````````!````````````````````
M`0````,`````````````````````````;0P```````":````````````````
3`````0``````````````````````
`
end
__EOS__
#`    
    
$resources{FreeBSD7}=<<'__EOS__';
begin 755 uuencode.uu
M?T5,1@$!`0D```````````(``P`!````4(,$"#0````P"````````#0`(``&
M`"@`&``7``8````T````-(`$"#2`!`C`````P`````4````$`````P```/0`
M``#T@`0(](`$"!4````5````!`````$````!``````````"`!`@`@`0(/04`
M`#T%```%`````!````$```!`!0``0)4$"$"5!`@$`0``#`$```8`````$```
M`@```%`%``!0E00(4)4$",@```#(````!@````0````$````#`$```R!!`@,
M@00(&````!@````$````!````"]L:6)E>&5C+VQD+65L9BYS;RXQ``````@`
M```$`````0```$9R965"4T0`EZX*``,````)````"`````8````#````````
M`````````````@````$````$````!0`````````'````````````````````
M`````&X`````````!0```!(```!;````2)8$"`0````1`!4`8P```$"5!`@$
M````$0`.`'H`````````0P```!(```!_````3)8$"``````0`/'_>```````
M```K````$@```"4``````````````"`````0``````````@$```2`````&QI
M8G-T9&,K*RYS;RXV`%]?9WAX7W!E<G-O;F%L:71Y7W8P`%]*=E]296=I<W1E
M<D-L87-S97,`;&EB;2YS;RXU`&QI8F=C8U]S+G-O+C$`;&EB8RYS;RXW`&5N
M=FER;VX`7U]P<F]G;F%M90!?:6YI=%]T;',`871E>&ET`%]E;F0`0UA804))
M7S$N,P!&0E-$7S$N,`````(``0`!``(``0`"`````P````$``0`!````$```
M`"````#3KVL%```#`(0``````````0`!`%$````0`````````+`H>@<```(`
MCP`````````XE@0(!P$``#R6!`@'!```0)8$"`<&``"#[`SH*`$``.AS`0``
M@\0,PP```/\U,)8$"/\E-)8$"`````#_)3B6!`AH`````.G@_____R4\E@0(
M:`@```#IT/____\E0)8$"&@0````Z<#___\```````````````!5B>564X/L
M$(/D\(M=!(G1C72=#(7;B35(E@0(?C:+10B%P'0OHT"5!`@/MA"$TG0C@\`!
MZPH/MA"#P`&$TG04@/HO=?&C0)4$"`^V$(/``832=>RX4)4$"(7`=#2)#"3H
M?____\<$))R$!`CH<____^@J____C44(B70D"(E$)`2)'"3H=P```(D$).A#
M____Z"[____KS9"0D)"0D)"058GE@^P(@#U$E@0(`'0,ZQR#P`2C2)4$"/_2
MH4B5!`B+$(72=>O&!426!`@!R<.058GE@^P(H2B6!`B%P'02N`````"%P'0)
MQP0D*)8$"/_0R<.0D)"0D)"0D)"0D)"0C4PD!(/D\/]Q_#'`58GE45E=C6'\
MPY"0D)"0D)"0D)!5B>53@^P$H1B6!`B#^/]T$C';_]"+@Q26!`B#ZP2#^/]U
M\(/$!%M=PY"0D(/L#.A,____@\0,PP`D1G)E94)31#H@<W)C+VQI8B]C<W4O
M:3,X-BUE;&8O8W)T:2Y3+'8@,2XW(#(P,#4O,#4O,3D@,#<Z,S$Z,#8@9&9R
M($5X<"`D`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]I,S@V+65L9B]C<G1N+E,L
M=B`Q+C8@,C`P-2\P-2\Q.2`P-SHS,3HP-B!D9G(@17AP("0`````J(0$"```
M```DE@0(``````$````!`````0```#D````!````0P````$```!1````#```
M`/""!`@-````G(0$"`0````D@00(!0```.R!!`@&````7($$"`H```"8````
M"P```!`````5``````````,````LE@0(`@```!@````4````$0```!<```#8
M@@0(_O__;YB"!`C___]O`@```/#__V^$@@0(````````````````````````
M````````````````````````````````````````_____P````#_____````
M``````!0E00(```````````:@P0(*H,$"#J#!`@`)$9R965"4T0Z('-R8R]L
M:6(O8W-U+V-O;6UO;B]C<G1B<F%N9"YC+'8@,2XT+C(P+C$@,C`P-R\Q,B\P
M-B`Q,SHT,SHT,R!K:6(@17AP("0`)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS
M.#8M96QF+V-R=#$N8RQV(#$N,34@,C`P-2\Q,"\P-R`R,CHQ,SHQ-R!B9&4@
M17AP("0`1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.
M52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N
M,2`R,#`W,#<Q.2`@6T9R965"4T1=```N<VAS=')T86(`+FEN=&5R<``N;F]T
M92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N9&%T80`N96A?9G)A;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N
M:F-R`"YG;W0`+F)S<P`N8V]M;65N=```````````````````````````````
M````````````````````````````"P````$````"````](`$"/0````5````
M```````````!`````````!,````'`````@````R!!`@,`0``&```````````
M````!``````````A````!0````(````D@00()`$``#@````$``````````0`
M```$````)P````L````"````7($$"%P!``"0````!0````$````$````$```
M`"\````#`````@```.R!!`CL`0``F````````````````0`````````W````
M____;P(```"$@@0(A`(``!(````$``````````(````"````1````/[__V\"
M````F(($")@"``!`````!0````(````$`````````%,````)`````@```-B"
M!`C8`@``&`````0````*````!`````@```!<`````0````8```#P@@0(\`(`
M`!$```````````````0`````````5P````$````&````!(,$"`0#``!`````
M```````````$````!````&(````!````!@```%"#!`A0`P``3`$`````````
M````$`````````!H`````0````8```"<A`0(G`0```P```````````````0`
M````````;@````$````"````J(0$"*@$``"5```````````````!````````
M`'8````!`````P```$"5!`A`!0``#```````````````!`````````!\````
M`0````(```!,E00(3`4```0```````````````0`````````A@````8````#
M````4)4$"%`%``#(````!0`````````$````"````(\````!`````P```!B6
M!`@8!@``"```````````````!`````````"6`````0````,````@E@0((`8`
M``@```````````````0`````````G0````$````#````*)8$""@&```$````
M```````````$`````````*(````!`````P```"R6!`@L!@``&```````````
M````!`````0```"G````"`````,```!$E@0(1`8```@```````````````0`
M````````K`````$``````````````$0&```T`0`````````````!````````
I``$````#``````````````!X!P``M0```````````````0``````````
`
end
__EOS__
#`

$resources{FreeBSD7_amd64}=<<'__EOS__';
begin 644 uuencode.uu
M?T5,1@(!`0D```````````(`/@`!````X`5```````!``````````.`,````
M`````````$``.``'`$``&0`8``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````-0'````````U`<`````````
M`!````````$````&````V`<```````#8!U```````-@'4```````$`,`````
M```@`P``````````$````````@````8```#("````````,@(4```````R`A0
M``````#``0```````,`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````S`<```````#,!T```````,P'0```````"``````````(``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`"7K@H``P````\````.````#`````H```````````````$`````````
M``````0````%`````@````<````#````!@````@````+````"0````T`````
M```````````````````````````````6````$0#Q_\@(4```````````````
M``#&````$@```)P%0````````@`````````?````$@`)`'@%0```````````
M``````"S````$0`6`/`*4```````"`````````"[````$0`/`-@'4```````
M"`````````#>````$`#Q_^@*4``````````````````E````$@`,`"@'0```
M``````````````#2````$@```*P%0```````+P````````#7````$`#Q_^@*
M4``````````````````K````$0#Q_[`*4`````````````````#J````$`#Q
M__@*4`````````````````#0````$@```+P%0```````+P````````!!````
M(`````````````````````````!\````$@```,P%0````````@4`````````
M;&EB;7ES<6QC;&EE;G0N<V\N,34`7T193D%-24,`7VEN:70`7V9I;FD`7T=,
M3T)!3%]/1D93151?5$%"3$5?`%]*=E]296=I<W1E<D-L87-S97,`;&EB>BYS
M;RXT`&QI8F-R>7!T+G-O+C0`;&EB<W1D8RLK+G-O+C8`7U]G>'A?<&5R<V]N
M86QI='E?=C``;&EB;2YS;RXU`&QI8F=C8U]S+G-O+C$`;&EB8RYS;RXW`&5N
M=FER;VX`7U]P<F]G;F%M90!?:6YI=%]T;',`871E>&ET`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`$-86$%"25\Q+C,`1D)31%\Q+C```````0`"``$``0`!
M``$``0`"``$``0`!``(````#``````````$``0!M````$````"````#3KVL%
M```#`.\``````````0`!`*D````0`````````+`H>@<```(`^@````````#(
M"E````````<````"``````````````#0"E````````<````(````````````
M``#8"E````````<````,``````````````#@"E````````<````.````````
M``````!(@^P(Z#\!``#H>@$``$B#Q`C#`/\U)@40`/\E*`40`)"0D)#_)28%
M$`!H`````.G@_____R4>!1``:`$```#IT/____\E%@40`&@"````Z<#_____
M)0X%$`!H`P```.FP____`````$%43(UG"%53BQ](8\.%VTB-;,<02(DM]000
M`'XZ2(M7"$B%TG0Q2(D5RP$0``^V`H3`="-(@\(!/"](BP6W`1``2`]$PDB)
M!:P!$``/M@)(@\(!A,!UX;C("%``2(7`="M(B??H<____[\H!T``Z&G____H
M(/___XG?2(GJ3(GFZ(L```")Q^A`____Z"O____KUI"0D)"0D)"0D)"0D)!(
M@^P(@#U=!!```'00ZR202(/`"$B)!4T!$`#_TDB+!40!$`!(BQ!(A=)UY,8%
M-000``%(@\0(PV9F9I!F9F:02(,]X`,0``!T%K@`````2(7`=`R_J`I0`$F)
MPT'_XY#SPY"0D)"0D)"0D)"0D)"0,<##D)"0D)"0D)"0D)"0D$B+!8$#$`!3
M2(/X_W05,=O_T$B+@X`*4`!(@^L(2(/X_W7M6\.0D)!(@^P(Z$____](@\0(
MPP`D1G)E94)31#H@<W)C+VQI8B]C<W4O86UD-C0O8W)T:2Y3+'8@,2XW(#(P
M,#0O,#,O,C$@,#$Z,SDZ,#$@<&5T97(@17AP("0`)$9R965"4T0Z('-R8R]L
M:6(O8W-U+V%M9#8T+V-R=&XN4RQV(#$N-B`R,#`T+S`S+S(Q(#`Q.C,Y.C`Q
M('!E=&5R($5X<"`D``````$;__\@`!```````#8'0`````````````````"@
M"E```````!0``````````7I2``%X$`$##`<(D`$``!P````<````X`5``),`
M````0@X0C`)%#AA!#B"#!(8#%````#P```"`!D``.`````!$#A``````%```
M`%0```#`!D``(@``````````````'``````````!>E!2``%X$`8#S`5```,,
M!PB0`0`````4````)````/`&0``#````````````````````&``````````!
M>E(``7@0`0,,!PB0`0```````!0````@``````=``"4`````2`X0@P(```$`
M`````````0`````````!`````````%4``````````0````````!?````````
M``$`````````;0`````````!`````````)$``````````0````````";````
M``````$`````````J0`````````,`````````'@%0```````#0`````````H
M!T````````0`````````^`%````````%`````````+`#0```````!@``````
M``!(`D````````H``````````P$````````+`````````!@`````````%0``
M``````````````````,`````````L`I0```````"`````````&``````````
M%``````````'`````````!<`````````&`5```````#^__]O`````-@$0```
M````____;P`````"`````````/#__V\`````M`1`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M_____P``````````__________\`````````````````````R`A0````````
M````````````````````H@5```````"R!4```````,(%0```````T@5`````
M````)$9R965"4T0Z('-R8R]L:6(O8W-U+V-O;6UO;B]C<G1B<F%N9"YC+'8@
M,2XT+C(P+C$@,C`P-R\Q,B\P-B`Q,SHT,SHT,R!K:6(@17AP("0`)$9R965"
M4T0Z('-R8R]L:6(O8W-U+V%M9#8T+V-R=#$N8RQV(#$N,34@,C`P-2\Q,"\P
M-R`R,CHQ,SHQ-R!B9&4@17AP("0`1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q
M.2`@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E
M94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``
M1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N9&%T80`N96A?
M9G)A;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`,@!0```````R`$````````5`````````````````````0``````````````
M`````!,````'`````@````````#@`4```````.`!````````&```````````
M``````````0````````````````````A````!0````(`````````^`%`````
M``#X`0```````%``````````!``````````(``````````0`````````)P``
M``L````"`````````$@"0```````2`(```````!H`0````````4````!````
M"``````````8`````````"\````#`````@````````"P`T```````+`#````
M`````P$```````````````````$````````````````````W````____;P(`
M````````M`1```````"T!````````!X`````````!``````````"````````
M``(`````````1````/[__V\"`````````-@$0```````V`0```````!`````
M``````4````"````"````````````````````%,````$`````@`````````8
M!4```````!@%````````8``````````$````"@````@`````````&```````
M``!=`````0````8`````````>`5```````!X!0```````!,`````````````
M```````$````````````````````6`````$````&`````````(P%0```````
MC`4```````!0````````````````````!``````````0`````````&,````!
M````!@````````#@!4```````.`%````````2`$``````````````````!``
M``````````````````!I`````0````8`````````*`=````````H!P``````
M``X````````````````````$````````````````````;P````$````"````
M`````#8'0```````-@<```````"3`````````````````````0``````````
M`````````'<````!`````@````````#,!T```````,P'````````"```````
M``````````````0```````````````````"%`````0````,`````````V`=0
M``````#8!P```````!@````````````````````(````````````````````
MBP````$````"`````````/`'4```````\`<```````#8````````````````
M````"````````````````````)4````&`````P````````#("%```````,@(
M````````P`$````````%``````````@`````````$`````````">`````0``
M``,`````````B`I0``````"("@```````!`````````````````````(````
M````````````````I0````$````#`````````)@*4```````F`H````````0
M````````````````````"````````````````````*P````!`````P``````
M``"H"E```````*@*````````"`````````````````````@`````````````
M``````"Q`````0````,`````````L`I0``````"P"@```````#@`````````
M```````````(``````````@`````````M@````@````#`````````.@*4```
M````Z`H````````0````````````````````"````````````````````+L`
M```!`````````````````````````.@*````````,0$`````````````````
M``$````````````````````!`````P`````````````````````````9#```
D`````,0````````````````````!````````````````````
`
end
__EOS__
#`    
    $resources{FreeBSD5}=<<'__EOS__';
begin 644 uuencode.uu
M?T5,1@$!`0D```````````(``P`!````"(0$"#0```#@"````````#0`(``&
M`"@`%@`5``8````T````-(`$"#2`!`C`````P`````4````$`````P```/0`
M``#T@`0(](`$"!4````5````!`````$````!``````````"`!`@`@`0($08`
M`!$&```%`````!````$````4!@``%)8$"!26!`@$`0``)`$```8`````$```
M`@```"0&```DE@0())8$",````#`````!@````0````$````#`$```R!!`@,
M@00(&````!@````$````!````"]L:6)E>&5C+VQD+65L9BYS;RXQ``````@`
M```$`````0```$9R965"4T0`P+`'``,````0````#@````\````+````````
M``````````````````$````#````!0````0````'````"`````(````&````
M"0````P````*````#0`````````````````````````6````))8$"``````1
M`/'_'P```)R#!`@`````$@`'`+X````TEP0(!````!$`$P`E````N(,$""``
M```B````Q@```!26!`@$````$0`,`.D````8EP0(`````!``\?_1````````
M``4````2````/0```'"%!`@`````$@`*`-L`````````+````!(```#B````
M&)<$"``````0`/'_0P```/B6!`@`````$0#Q__4````XEP0(`````!``\?_=
M`````````$,````2````60``````````````(````&T```#X@P0()P```"(`
M````;&EB;7ES<6QC;&EE;G0N<V\N,30`7T193D%-24,`7VEN:70`7U]D97)E
M9VES=&5R7V9R86UE7VEN9F\`7V9I;FD`7T=,3T)!3%]/1D93151?5$%"3$5?
M`%]*=E]296=I<W1E<D-L87-S97,`7U]R96=I<W1E<E]F<F%M95]I;F9O`&QI
M8GHN<V\N,@!L:6)C<GEP="YS;RXR`&QI8G-T9&,K*RYS;RXT`&QI8FTN<V\N
M,P!L:6)C+G-O+C4`96YV:7)O;@!?7W!R;V=N86UE`%]I;FET7W1L<P!A=&5X
M:70`7V5D871A`%]?8G-S7W-T87)T`%]E;F0````$EP0(!P0```B7!`@'!P``
M#)<$"`<)```0EP0(!PT``!27!`@'#P``Z$L!``#HH@$``,,`_S7\E@0(_R4`
MEP0(`````/\E!)<$"&@`````Z>#_____)0B7!`AH"````.G0_____R4,EP0(
M:!````#IP/____\E$)<$"&@8````Z;#_____)127!`AH(````.F@____58GE
M5U93@^P,B=&-=0B+7OR-?)X$B3TTEP0(A=M^+8-]"`!T)XM%"*,4E@0(B<*`
M.`!T&(`Z+W4+C4(!HQ26!`B-=@!"@#H`=>J)]K@DE@0(A<!T#H/L#%'H<O__
M_X/$$.L%Z%C___^#[`QH<(4$".A;____Z!K___^#[`175E/HJP```(/$%%#H
M4O___Y"058GE@^P(@#T8EP0(`'5!H1R6!`B+`(7`=!:)]H,%')8$"`3_T*$<
ME@0(BP"%P'7LN+B#!`B%P'00@^P,:""6!`CHVO[__X/$$,8%&)<$"`')PXGV
M58GE@^P(N/B#!`B%P'05@^P(:!R7!`AH()8$".CK_O__@\00@SWTE@0(`'0;
MN`````"%P'02@^P,:/26!`CHT7K[]X/$$(GVR<.0D%6)Y8/L"(/D\(/L$#'`
MR<-5B>53@^P$N^26!`B#/>26!`C_=`V-=@#_$X/K!(,[_W7V@\0$6\G#Z"/_
M___#`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]I,S@V+65L9B]C<G1I+E,L=B`Q
M+C8@,C`P,B\P-2\Q-2`P-#HQ.3HT.2!O8G)I96X@17AP("0`)$9R965"4T0Z
M('-R8R]L:6(O8W-U+VDS.#8M96QF+V-R=&XN4RQV(#$N-2`R,#`R+S`U+S$U
M(#`T.C$Y.C0Y(&]B<FEE;B!%>'`@)`````!VA00(`````/"6!`@``````0``
M``$````!````@P````$```"-`````0```)L````!````J@````$```"T````
M#````)R#!`@-````<(4$"`0````D@00(!0```'B"!`@&````>($$"`H```#Z
M````"P```!`````5``````````,```#XE@0(`@```"@````4````$0```!<`
M``!T@P0(````````````````````````````````````````````````````
M````````````_____P````#_____```````````DE@0(``````````"^@P0(
MSH,$"-Z#!`CN@P0(_H,$"``D1G)E94)31#H@<W)C+VQI8B]C<W4O8V]M;6]N
M+V-R=&)R86YD+F,L=B`Q+C0@,C`P,R\Q,"\Q-R`Q-3HT,SHQ,R!P971E<B!%
M>'`@)``D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O8W)T,2YC+'8@
M,2XQ,R`R,#`T+S`X+S$U(#$V.C$X.C4Q(&1F<B!%>'`@)`!'0T,Z("A'3E4I
M(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R.```1T-#.B`H1TY5*2`S+C0N,B!;
M1G)E94)31%T@,C`P-#`W,C@``$=#0SH@*$=.52D@,RXT+C(@6T9R965"4T1=
M(#(P,#0P-S(X``!'0T,Z("A'3E4I(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R
M.```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N9&%T80`N96A?9G)A;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R
M`"YG;W0`+F)S<P`N8V]M;65N=```````````````````````````````````
M```````````````````````+`````0````(```#T@`0(]````!4`````````
M``````$`````````$P````<````"````#($$"`P!```8```````````````$
M`````````"$````%`````@```"2!!`@D`0``5`````0`````````!`````0`
M```G````"P````(```!X@00(>`$````!```%`````0````0````0````+P``
M``,````"````>(($"'@"``#Z```````````````!`````````#<````)````
M`@```'2#!`AT`P``*`````0````(````!`````@```!``````0````8```"<
M@P0(G`,```L```````````````0`````````.P````$````&````J(,$"*@#
M``!@```````````````$````!````$8````!````!@````B$!`@(!```:`$`
M````````````!`````````!,`````0````8```!PA00(<`4```8`````````
M``````0`````````4@````$````"````=H4$"'8%``";```````````````!
M`````````%H````!`````P```!26!`@4!@``#```````````````!```````
M``!@`````0````(````@E@0((`8```0```````````````0`````````:@``
M``8````#````))8$""0&``#`````!0`````````$````"````',````!````
M`P```.26!`CD!@``"```````````````!`````````!Z`````0````,```#L
ME@0([`8```@```````````````0`````````@0````$````#````])8$"/0&
M```$```````````````$`````````(8````!`````P```/B6!`CX!@``(```
M````````````!`````0```"+````"`````,````8EP0(&`<``"``````````
M``````0`````````D`````$``````````````!@'```M`0`````````````!
M``````````$````#``````````````!%"```F0```````````````0``````
"````
`
end
__EOS__
#`

    $resources{FreeBSD4}=<<'__EOS__';
begin 644 uuencode.uu
M?T5,1@$!`0D```````````(``P`!````P(,$"#0```"P!P```````#0`(``&
M`"@`%@`5``8````T````-(`$"#2`!`C`````P`````4````$`````P```/0`
M``#T@`0(](`$"!D````9````!`````$````!``````````"`!`@`@`0('P4`
M`!\%```%`````!````$````@!0``()4$"""5!`C\````&`$```8`````$```
M`@```#`%```PE00(,)4$",````#`````!@````0````$````$`$``!"!!`@0
M@00(&````!@````$````!````"]U<W(O;&EB97AE8R]L9"UE;&8N<V\N,0``
M```(````!`````$```!&<F5E0E-$`$2"!P`#````#P````H````.````"P``
M```````````````````````!`````P````4````&````!`````@````"````
M!P````D````,````#0`````````````````````````6````,)4$"``````1
M`/'_'P```&2#!`@`````$@`'`+$````TE@0(!````!$`$@`E````@(,$"*$`
M```B````V````#B6!`@`````$`#Q_[D````@E00(!````!$`#`#+````')8$
M"``````0`/'_/0```!B%!`@`````$@`*`)8```"0@P0(3`$``!(```#$````
M')8$"``````0`/'_0P````"6!`@`````$0#Q_]<````XE@0(`````!``\?^8
M````H(,$"%L````2````60```+"#!`AM````(@````!L:6)M>7-Q;&-L:65N
M="YS;RXQ-`!?1%E.04U)0P!?:6YI=`!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!?9FEN:0!?1TQ/0D%,7T]&1E-%5%]404),15\`7U]R96=I<W1E<E]F<F%M
M95]I;F9O`&QI8GHN<V\N,@!L:6)C<GEP="YS;RXR`&QI8G-T9&,K*RYS;RXS
M`&%T97AI=`!L:6)M+G-O+C(`;&EB8RYS;RXT`&5N=FER;VX`7U]P<F]G;F%M
M90!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``,E@0(!P0``!"6!`@'"0``%)8$
M"`<-```8E@0(!PX``.A+`0``Z'H!``##`/\U!)8$"/\E")8$"`````#_)0R6
M!`AH`````.G@_____R40E@0(:`@```#IT/____\E%)8$"&@0````Z<#_____
M)1B6!`AH&````.FP____58GE@^P,5U93B=*-=0B+7OR-?)X$B3TTE@0(A=M^
M*8-]"`!T(XM%"*,@E00(@#@`=!:)]H`X+W4)C4@!B0T@E00(0(`X`'7LN#"5
M!`B%P'0,@\3T4NAV____@\00@\3T:!B%!`CH9O___^@U____@^3P@^P8B5PD
M`(ET)`2)?"0(Z)H```")1"0`Z%'___^-9>A;7E_)PY!5B>6#[`B#/2B5!`@`
M=4#K%(UV`(,%))4$"`2A))4$"(M`_/_0H225!`B#.`!UY;B`@P0(A<!T#8/$
M]&@LE00(Z./^___'!2B5!`@!````R<.-=@!5B>6#[`C)PU6)Y8/L"+BP@P0(
MA<!T$H/$^&@<E@0(:"R5!`CHV_[__\G#D%6)Y8/L",G#58GE,<#)PY!5B>6#
M[!13N_"5!`B#/?"5!`C_=`^-=@"+`__0@\/\@SO_=?1;R<.058GE@^P(R</H
M.____\,``!Z%!`C\E00(```````````!`````0````$```!O`````0```'D`
M```!````AP````$```"=`````0```*<````,````9(,$"`T````8A00(!```
M`"B!!`@%````:(($"`8```!X@00("@```-P````+````$````!4`````````
M`P````"6!`@"````(````!0````1````%P```$2#!`@`````````````````
M``````````````````````````````````````````````#_____`````/__
M__\`````,)4$"```````````AH,$"):#!`BF@P0(MH,$"`!'0T,Z("A'3E4I
M(&,@,BXY-2XT(#(P,#(P,S(P(%M&<F5E0E-$70``1T-#.B`H1TY5*2!C(#(N
M.34N-"`R,#`R,#,R,"!;1G)E94)31%T``$=#0SH@*$=.52D@8W!L=7-P;'5S
M(#(N.34N-"`R,#`R,#,R,"!;1G)E94)31%T``$=#0SH@*$=.52D@8R`R+CDU
M+C0@,C`P,C`S,C`@6T9R965"4T1=``@``````````0```#`Q+C`Q````"```
M```````!````,#$N,#$````(``````````$````P,2XP,0````@`````````
M`0```#`Q+C`Q`````"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F1A=&$`+F5H7V9R86UE`"YD>6YA;6EC`"YC=&]R<P`N
M9'1O<G,`+F=O=``N8G-S`"YC;VUM96YT`"YN;W1E````````````````````
M``````````````````````````````````````L````!`````@```/2`!`CT
M````&0```````````````0`````````3````!P````(````0@00($`$``!@`
M``````````````0`````````(0````4````"````*($$""@!``!0````!```
M```````$````!````"<````+`````@```'B!!`AX`0``\`````4````!````
M!````!`````O`````P````(```!H@@0(:`(``-P```````````````$`````
M````-P````D````"````1(,$"$0#```@````!`````@````$````"````$``
M```!````!@```&2#!`AD`P``"P``````````````!``````````[`````0``
M``8```!P@P0(<`,``%````````````````0````$````1@````$````&````
MP(,$",`#``!8`0`````````````$`````````$P````!````!@```!B%!`@8
M!0``!@``````````````!`````````!2`````0````(````>A00('@4```$`
M``````````````$`````````6@````$````#````()4$""`%```,````````
M```````$`````````&`````!`````P```"R5!`@L!0``!```````````````
M!`````````!J````!@````,````PE00(,`4``,`````%``````````0````(
M````<P````$````#````\)4$"/`%```(```````````````$`````````'H`
M```!`````P```/B5!`CX!0``"```````````````!`````````"!`````0``
M``,`````E@0(``8``!P```````````````0````$````A@````@````#````
M')8$"!P&```<```````````````$`````````(L````!```````````````<
M!@``J````````````````0````````"4````!P``````````````Q`8``%``
M``````````````$``````````0````,``````````````!0'``":````````
-```````!````````````
`
end
__EOS__

    $resources{Linux}=<<'__EOS__';
begin 644 uuencode.uu
M?T5,1@$!`0````````````(``P`!````X(,$"#0```!("0```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(S`4`
M`,P%```%`````!````$```#,!0``S)4$",R5!`@T`0``.`$```8`````$```
M`@```.`%``#@E00(X)4$"``!`````0``!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!`````0```!H`0``:($$"&B!!`@8````&`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````(````%````
M!0````(````!````4W5310`````)`P```P````L````*````!P````@`````
M`````````````````````0````0````"````!0````,````&````"0``````
M```````````````````6````X)4$"``````1`/'_'P```)R#!`@`````$@`+
M`,L`````EP0(`````!``\?^R`````````-8````2````)0```*2%!`@`````
M$@`.`,0`````EP0(`````!``\?_7````!)<$"``````0`/'_HP```,2%!`@$
M````$0`/`"L``````````````"`````_```````````````@`````&QI8FUY
M<W%L8VQI96YT+G-O+C$U`%]$64Y!34E#`%]I;FET`%]F:6YI`%]*=E]296=I
M<W1E<D-L87-S97,`7U]G;6]N7W-T87)T7U\`;&EB>BYS;RXQ`&QI8F-R>7!T
M+G-O+C$`;&EB;G-L+G-O+C$`;&EB<W1D8RLK+G-O+C4`;&EB;2YS;RXV`&QI
M8F=C8U]S+G-O+C$`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?;&EB8U]S
M=&%R=%]M86EN`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`$=,24)#7S(N,```
M``$``0`!``(``0`!``$``0```````0`!`)D````0`````````!!I:0T```(`
MW`````````#@E@0(!@H``/"6!`@'!```58GE@^P(Z%T```#HQ````.C/`0``
MR<,`_S7HE@0(_R7LE@0(`````/\E\)8$"&@`````Z>#___\`````````````
M```Q[5Z)X8/D\%!44FBPA`0(:""%!`A15FB@A`0(Z,/____TD)!5B>53Z```
M``!;@</7$@``4HN#_/___X7`=`+_T%A;R<.0D)"0D)"0D)"0D%6)Y5!0@#T`
MEP0(`'4NH?R6!`B+$(72=!R-M"8`````@\`$H_R6!`C_TJ'\E@0(BQ"%TG7K
MQ@4`EP0(`<G#B?95B>5148L5W)4$"(72=!FX`````(7`=!"#[`QHW)4$".AK
M>_OW@\00R<.0D)"0D)!5B>504#'`@^3P@^P0R<.058GE@^P8B5WTZ+H```"!
MPR82``")??R-@^C^__^-N^C^__^)=?@I^,'X`H7`C7#_=1+HO0```(M=](MU
M^(M]_(GL7</_%+>)\$Z%P'7VB?;HGP```(M=](MU^(M]_(GL7<.-M"8`````
MC;PG`````%6)Y8/L&(E=](EU^#'VZ$4```"!P[$1``")??SH6_[__XV3Z/[_
M_XV#Z/[__RG"P?H".=9S%8E%\(G7D(UT)@#_%+!&BT7P.?YR]8M=](MU^(M]
M_(GL7<.+'"3#D)"0D%6)Y5-2N\R5!`BAS)4$"(/X_W0,@^L$_]"+`X/X_W7T
M6%M=PU6)Y5/H`````%N!PS<1``!0Z';^__]96\G#```#`````0`"``````#_
M____`````/____\```````````$````!`````0```$X````!````6`````$`
M``!F`````0```'(````!````@0````$```"+`````0```)D````,````G(,$
M"`T```"DA00(!````("!!`@%````<(($"`8```#`@00("@```.8````+````
M$````!4``````````P```.26!`@"````"````!0````1````%P```)2#!`@1
M````C(,$"!(````(````$P````@```#^__]O;(,$"/___V\!````\/__;U:#
M!`@`````````````````````````````````````````````````````````
M````````````X)4$"```````````RH,$"```````````V)4$"`!'0T,Z("A'
M3E4I(#,N,RXU(#(P,#4P,3$W("AP<F5R96QE87-E*2`H4U5312!,:6YU>"D`
M`$=#0SH@*$=.52D@,RXS+C4@,C`P-3`Q,3<@*'!R97)E;&5A<V4I("A355-%
M($QI;G5X*0``1T-#.B`H1TY5*2`S+C,N-2`R,#`U,#$Q-R`H<')E<F5L96%S
M92D@*%-54T4@3&EN=7@I``!'0T,Z("A'3E4I(#,N,RXU(#(P,#4P,3$W("AP
M<F5R96QE87-E*2`H4U5312!,:6YU>"D``$=#0SH@*$=.52D@,RXS+C4@,C`P
M-3`Q,3<@*'!R97)E;&5A<V4I("A355-%($QI;G5X*0``1T-#.B`H1TY5*2`S
M+C,N-2`R,#`U,#$Q-R`H<')E<F5L96%S92D@*%-54T4@3&EN=7@I``!'0T,Z
M("A'3E4I(#,N,RXU(#(P,#4P,3$W("AP<F5R96QE87-E*2`H4U5312!,:6YU
M>"D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N4W53
M10`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N
M9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M``````````````````````````````````````````L````!`````@```#2!
M!`@T`0``$P```````````````0`````````3````!P````(```!(@00(2`$`
M`"````````````````0`````````(0````<````"````:($$"&@!```8````
M```````````$`````````"P````%`````@```("!!`B``0``0`````4`````
M````!`````0````R````"P````(```#`@00(P`$``+`````&`````0````0`
M```0````.@````,````"````<(($"'`"``#F```````````````!````````
M`$(```#___]O`@```%:#!`A6`P``%@````4``````````@````(```!/````
M_O__;P(```!L@P0(;`,``"`````&`````0````0`````````7@````D````"
M````C(,$"(P#```(````!0`````````$````"````&<````)`````@```)2#
M!`B4`P``"`````4````,````!`````@```!P`````0````8```"<@P0(G`,`
M`!<```````````````0`````````:P````$````&````M(,$"+0#```@````
M```````````$````!````'8````!````!@```."#!`C@`P``Q`$`````````
M````$`````````!\`````0````8```"DA00(I`4``!H```````````````0`
M````````@@````$````"````P(4$",`%```(```````````````$````````
M`(H````!`````@```,B%!`C(!0``!```````````````!`````````"4````
M`0````,```#,E00(S`4```@```````````````0`````````FP````$````#
M````U)4$"-0%```(```````````````$`````````*(````!`````P```-R5
M!`C<!0``!```````````````!`````````"G````!@````,```#@E00(X`4`
M```!```&``````````0````(````L`````$````#````X)8$".`&```$````
M```````````$````!````+4````!`````P```.26!`CD!@``$```````````
M````!`````0```"^`````0````,```#TE@0(]`8```P```````````````0`
M````````Q`````@````#`````)<$"``'```$```````````````$````````
M`,D````!````````````````!P``<P$``````````````0`````````!````
D`P``````````````<P@``-(```````````````$`````````
`
end
__EOS__

$resources{Linux_amd64}=<<'__EOS__';
begin 755 uuencode.uu
M?T5,1@(!`0````````````(`/@`!````@`1```````!``````````!`+````
M`````````$``.``(`$``'``;``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````"0'````````)`<`````````
M`"````````$````&````*`<````````H!V```````"@'8```````.`(`````
M``!(`@``````````(````````@````8```!0!P```````%`'8```````4`=@
M``````#0`0```````-`!````````"``````````$````!````!P"````````
M'`)````````<`D```````"``````````(``````````$`````````%#E=&0$
M````;`8```````!L!D```````&P&0```````)``````````D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@````@``````````P````4````$
M`````P````````````````````$``````````@````(````$`````0````8`
M````````(````00`````````>4EKM@``````````````````````````````
M```````0````(``````````````````````````?````(```````````````
M``````````!J````$@``````````````P`$````````S````$@```&@$0```
M````;`4`````````;&EB<W1D8RLK+G-O+C8`7U]G;6]N7W-T87)T7U\`7TIV
M7U)E9VES=&5R0VQA<W-E<P!?7V=X>%]P97)S;VYA;&ET>5]V,`!L:6)M+G-O
M+C8`;&EB9V-C7W,N<V\N,0!L:6)C+G-O+C8`7U]L:6)C7W-T87)T7VUA:6X`
M0UA804))7S$N,P!'3$E"0U\R+C(N-0```````````@`#`````0`!``$````0
M````(````-.O:P4```,`?``````````!``$`8````!``````````=1II"0``
M`@"'`````````"`)8```````!@````$``````````````$`)8```````!P``
M``,``````````````$@)8```````!P````0``````````````$B#[`CH<P``
M`.@"`0``Z-T!``!(@\0(P_\UX@0@`/\EY`0@``\?0`#_)>($(`!H`````.G@
M_____R7:!"``:`$```#IT/___P``````````,>U)B=%>2(GB2(/D\%!42<?`
M@`5``$C'P9`%0`!(Q\=P!4``Z*_____TD)!(@^P(2(L%:00@`$B%P'0"_]!(
M@\0(PY"0D)"0D)"0D)"0D)!52(GE4TB#[`B`/8`$(```=4NX0`=@`$B+%7H$
M(`!(+3@'8`!(P?@#2(U8_T@YVG,E#Q^``````$B-0@%(B055!"``_Q3%.`=@
M`$B+%4<$(`!(.=IRXL8%,P0@``%(@\0(6\G#9F9F+@\?A```````54B#/?\!
M(```2(GE=!JX`````$B%P'00OT@'8`!)B</)0?_C#Q]``,G#D)"0D)"0,<##
MD)"0D)"0D)"0D)"0D//#9F9F9F8N#Q^$``````!(B6PDV$R)?"3X2(TM@P$@
M`$R-/7P!(`!,B60DX$R);"3H3(ET)/!(B5PDT$B#[#A,*?U!B?Y)B?5(P?T#
M28G4Z%O^__](A>UT'#';#Q]``$R)XDR)[D2)]T'_%-](@\,!2#GK<NI(BUPD
M"$B+;"003(MD)!A,BVPD($R+="0H3(M\)#!(@\0XPY"0D)"0D)!52(GE4TB#
M[`A(BP7X`"``2(/X_W09NR@'8``/'T0``$B#ZPC_T$B+`TB#^/]U\4B#Q`A;
MR<.0D$B#[`CH;_[__TB#Q`C#```!``(``1L#.R`````#````!/___T0````4
M____=````"3___^,````'``````````!>E!2``%X$`8#:`1```,,!PB0`0``
M```4````)````'`%0``#```````````````4``````````%Z4@`!>!`!&PP'
M")`!```4````'````)C^__\"```````````````D````-````)#^__^)````
M`$J/`H8&9@Y`@P>.`XT$C`4```````````````````#__________P``````
M````__________\``````````````````````0`````````!``````````$`
M````````2``````````!`````````%(``````````0````````!@````````
M``P`````````,`1````````-`````````%@&0```````!`````````!``D``
M`````/7^_V\`````:`)````````%``````````@#0```````!@````````"0
M`D````````H`````````DP`````````+`````````!@`````````%0``````
M``````````````,`````````*`E@```````"`````````#``````````%```
M```````'`````````!<```````````1````````'`````````.@#0```````
M"``````````8``````````D`````````&`````````#^__]O`````*@#0```
M````____;P`````"`````````/#__V\`````G`-`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%`'8````````````````````````````%X$0```````;@1`````````
M`````````````````````$=#0SH@*$1E8FEA;B`T+C,N,BTQ*2`T+C,N,@``
M1T-#.B`H1&5B:6%N(#0N,RXR+3$I(#0N,RXR``!'0T,Z("A$96)I86X@-"XS
M+C(M,2XQ*2`T+C,N,@``1T-#.B`H1&5B:6%N(#0N,RXR+3$N,2D@-"XS+C(`
M`$=#0SH@*$1E8FEA;B`T+C,N,BTQ*2`T+C,N,@``1T-#.B`H1&5B:6%N(#0N
M,RXR+3$N,2D@-"XS+C(``$=#0SH@*$1E8FEA;B`T+C,N,BTQ*2`T+C,N,@``
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M````````````````````````````````````````````````````````````
M``````````````````````L````!`````@```````````D`````````"````
M````'`````````````````````$````````````````````3````!P````(`
M````````'`)````````<`@```````"`````````````````````$````````
M````````````)0````4````"`````````$`"0```````0`(````````H````
M``````4`````````"``````````$`````````"$```#V__]O`@````````!H
M`D```````&@"````````)``````````%``````````@`````````````````
M```K````"P````(`````````D`)```````"0`@```````'@`````````!@``
M``$````(`````````!@`````````,P````,````"``````````@#0```````
M"`,```````"3`````````````````````0```````````````````#L```#_
M__]O`@````````"<`T```````)P#````````"@`````````%``````````(`
M`````````@````````!(````_O__;P(`````````J`-```````"H`P``````
M`$``````````!@````(````(````````````````````5P````0````"````
M`````.@#0```````Z`,````````8``````````4`````````"``````````8
M`````````&$````$`````@``````````!$`````````$````````,```````
M```%````#`````@`````````&`````````!K`````0````8`````````,`1`
M```````P!````````!@````````````````````$````````````````````
M9@````$````&`````````$@$0```````2`0````````P````````````````
M````!``````````0`````````'$````!````!@````````"`!$```````(`$
M````````V`$``````````````````!````````````````````!W`````0``
M``8`````````6`9```````!8!@````````X````````````````````$````
M````````````````?0````$````2`````````&@&0```````:`8````````$
M````````````````````!``````````$`````````(4````!`````@``````
M``!L!D```````&P&````````)`````````````````````0`````````````
M``````"3`````0````(`````````D`9```````"0!@```````)0`````````
M```````````(````````````````````G0````$````#`````````"@'8```
M````*`<````````0````````````````````"````````````````````*0`
M```!`````P`````````X!V```````#@'````````$```````````````````
M``@```````````````````"K`````0````,`````````2`=@``````!(!P``
M``````@````````````````````(````````````````````L`````8````#
M`````````%`'8```````4`<```````#0`0````````8`````````"```````
M```0`````````+D````!`````P`````````@"6```````"`)````````"```
M``````````````````@`````````"`````````"^`````0````,`````````
M*`E@```````H"0```````"@````````````````````(``````````@`````
M````QP````$````#`````````%`)8```````4`D````````0````````````
M````````"````````````````````,T````(`````P````````!@"6``````
M`&`)````````$`````````````````````@```````````````````#2````
M`0````````````````````````!@"0```````-$````````````````````!
M`````````````````````0````,`````````````````````````,0H`````
B``#;`````````````````````0``````````````````````
`
end
__EOS__

    $resources{setup}=<<'__EOS__';
begin 644 uuencode.uu
M_]C_X``02D9)1@`!`@``9`!D``#_[``11'5C:WD``0`$````9```_^X`#D%D
M;V)E`&3``````?_;`(0``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0("`@("`@("`@("`P,#`P,#`P,#`P$!`0$!`0$"`0$"
M`@(!`@(#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#_\``$0@"'P#]`P$1``(1`0,1`?_$`.<``0`!!0$!`0$!````
M```````&!0<("0H$`P(!"P$!``$%`0$!``````````````<#!`4&"`(!"1``
M``4$`0,!`P@&!0<(!0T``0(#!`4`$08'$B$3"!0Q(@E!46$R%;4V=G&!(S,6
M%Y&A0C1$P5*3)'2D)6)RDJ)#4\,UPF2451BQ@F-S@Z/35+3$9=66$0`!`P(#
M!`8%"`0*!P4'!0`!``(#$002!08A,4%187&1(A,'@<$R4A2AL=%"<H(C%6*B
M,V/PX9*RPM)#HV06XE-S@[,D"/'#TS14=+0E-647&)-$E*3$_]H`#`,!``(1
M`Q$`/P#@DS,;YAE@_/DLZ/\`3*.J(HU1$HB41*(E$2B)1$HB41*(E$2B)1$H
MB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1%),R_%^5?F2<^\W5$4;HB41
M*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1
M$HBDN9],PRL/FR6=^]'5$4:HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)
M1$HB41*(E$2B)1$HB41*(E$2B)1$HBDN9_C#+/S+._>CJB*-41*(E$2B)1$H
MB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB4127,_Q
MAEGYEG?O1U1%&J(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1
M$HB41*(E$2B)1$HB41*(I+F?XPRS\RSOWHZHBC5$2B)1$HB41*(JBA$2SH$A
M:Q<BY!<2@B*#)RL"PF'B4$A32-W!,;H%KW&OE0O)>P;R.U5MO@.=.S&(TPO+
M'1R!R,5OCDPL8I;VY&*FS,(!?Y1H7-&\A4S<0#>]@](^E5E#3^VG1"J-M7;%
M<)G$2E40PG)5B&$!XB!3IQABB(&Z=/EKYC9S':O!O+0;#+&/O-^E5U#QXWVX
M/VT]*[6*;B)KKZ_RIJ2P6_[5S%(I\NOLO<:^>)'[P[5X.8V`V^/%_+;]*K"'
MBYY$.2"HGIO/BE`PELO`.VI[@`#<$W145!+U]MK#\_2OGBQ^\%X.:9<-\T?:
MJZAX=>3#DY")ZCR$IE`$2BNZA&I``"B?WU'4JBFD-@]AA`;]/;TKYXT7-4SG
M&6#^V;\OT*LM_!WRE<@8R>JG!0*(`/J,LP-H(B(7]TKK*43'#Z0`0IX\7/YU
MX.>96-\H_DN_JJMM_`7R@6[7<P:,:=P"\_49EB)NQR"X@KZ69<W$GL'AS^B]
M?/B(N?R+P<_RL?7)^Z[Z%6F_P\/)%<3@K%XDSX@%A<96T,"E[W`GI$70@);=
M>7'V]+U\-Q'TKP=19:-Q>?NJM-_AM^0:Q4Q4D-<-1.(`8CC))<QD0Y<>2@M<
M:<E$`#K[@F&WT]*^?$Q]*\'4F7CA(?0/I5<;_#)W>8X@ZS+52).-RF;RV7.3
MB>X6*)%,,:`4MK]>0C?Y/E#Y\2SD?X>E4SJ:QX,E[&_UE6$/AA[0,F`N=BX$
MDK<;D01R%PF`7Z""BD:V,(B'M#@%OII\4SD5X.I[7A')3T?2J\A\+K*#*`#G
M;L`DE8;G0Q61<*7^0`34F&Q1`1]H\^GTU\^*')4SJB+A"ZOVA]"K#?X6CDQ!
M%UN]!$_*Q2M]<J.2"2P6,)U,Y:"4U[].(A;Y?D#Y\5^C\O\`$O!U2.$'Z_\`
MHJN(?"XA"F3%UN656(`?M2H82T;&./&PBF93)G0)!SZV$#].GTU\^*/N_*O!
MU0_A"/Y7^BOS,?"\AAC''V!MF3+,A8S09C&FIXQ0"@;D@X!E(D=(]PUK*E$_
M``']F>_0+HUVC8C-4/Q#Q(1@Z';?E'\.:U\[M\:]IZ#<M/XWBFJ\+(KJ-HS*
M()RI(P#UPF`G%L9PH@U=L'AT@$Y$G2*)U"E,)`,!#"%PR1LGL[UL-EF5K?@^
M`3C&]IV$?3Z*JP55%?I1$HB41*(E$2B)1%)<S_&&6?F6=^]'5$4:HB]#-F[D
M';5@P;.'KYZX1:,V;1%1PZ=NG*A46[9LW1*=5=PNJ<"D(4!,8P@``(C3<OA(
M:"YQHT+>CXG^%F-:YQH,FVSCD'E&?Y"U3,>&FX]A-Q.'1ZG%4L:W;/$G+->=
M5Z>K=`!NW;LHCP!0ZUC+,7&C#1JT;-LZEN9?"M'.9;M.\$@N//9PY#TGHS';
MZGU:T*8C76N`-B&'D8K?#<=1*8UK<C%3CB@(V#VU1QOYGM6&-W='?+(?O'Z5
M76^'XBU%(6N+8XV%`"@B+>$C$11`I>)02%-J44P*7H%K6"OE3S7@S3'>]W:5
M66[)FTY^D:-FO<X]STZ"2//ARX<^V0O+CR&U_9<:^*F7$[R2O31?$HB41*(E
M$2B)1$HB41*(E$2B)1$HB41*(H[EF)8WG6/2F*9;$,YW'YEL9K(QKY/FBLF(
M@8AR&*)56[ENH4%$EDS$514*4Y#%,4!#Z"6FHWJI#-)!()826R-.PA:"_*CQ
M'R30<HKD$&#S(=72+KA'3@D[CW'UESV1ALE!$A2)J\AX(.P*5%ST"Q%![=7\
M4PD%#[2W[*LWCOV^&^C;H#:.!Z6^L;QU;5AM599E*(E$2B)1$HB4127,_P`8
M99^99W[T=411JB+8U\-;&<=F]N95+2\6VD)7%\3))8XX=%%7[*>.I-NP=/FR
M1A[0//2KBF100$R93FXV$;U;W)(8`-Q*US4LLC+1C&$ACGT/3LK1;Q:L5HZ4
M1*(E$2B)1$HB41*(E$2B)1$HB]39B]>B<&;-T[%,`%0&S=5<2`:X%$X)$.)0
M,(#:_MJF^6./]HYK:\R!\Z]M8]_L`GJ%5)F^O,_=J%2:8/F#I4P"8J3?&9I9
M0Q0#D(E(FR,80`O4>GLJS?FV5QC$^YMVMYF1@]:NFY;F+S1D$Q/0QQ]2KK;2
MNY'A#*,]2[,=$*;@8[;`\I7(4]@-Q,9**,`&L(#;VV&K9^HM/QFDE_9M/3-&
M/G<J[<CSIXJRSNB.B*0_T5YLGU%MC"8E*>S/6&P\1@EG"#1&:R?"LD@(E9TZ
M356;-DI&5C&C-1PX11.<A`.)CE(80`0`:]V6?9'F4YM<OO;2>Y`)+(YHWN`%
M`26M<30$@$TV5"\W63YO8PBXO;6YAMR0`Y\3V-J=H&)S0*FAH*JW=998U7%U
MCJ;8>Y<@<8KK3&U\IGVL4XG'$<W>Q;%1.+:.F3-P[[TL^8-C%2<R*)1*!Q./
M.X`(`(AB,YSW*=/6@OLXF$%JYX8'$.=WB"0*-#CN:3NIL62RK)\RSNY-IE<1
MEN`PN+06CN@@$U<0-Y'&NU?#8^KM@:CR(V*;(Q:2Q.>!J@^(RD2H'(Y9.0'L
MNV+UFLY8/VQCE,05$%5"E5(8AA`Y#%#WE&=95GUI\=E$[)[7$15M=A&\$$!S
M3QH0#0@C805YS/*LQR>Y^$S.)T-Q0&AIM!W$$$@CA4$[01O!4!K*+'JG2\1%
MS\6_A)N/9RT1*-5F,C&R#=-TR>M'!!36;N6ZQ3)JI*$&P@(4!(-1O7ICWQN#
MV$AX-01O"T)>9?BLEH29C\IQ%9=UKC+)!RU8MG(J+.\6ERI"["#<NS\O6LG3
M<JBC)4PBL*:*A%>1DP55OX9?$%#[06^Y-FIOV&*;9<L&W](<^@\_DY#!ZJZS
MB41*(E$2B)1%)<S_`!AEGYEG?O1U1%&J(MD?PQW''<N<-;_OM9/'%NO7TV58
MNG?YNGJ_ZZMKGV!UK6]3C_DXS^]_HN6[RK):0I-A<2QG\QQ."E%'*,9-9-`Q
M,BLS412=I,9*4:LW:C55PBX03<IMUC"0QTSD`P`(E$+@-I?S2VUA/<0`&:.%
M[F@U(+FM)%0"#2HVT(/2KJRACN+R&"4D1/E8TD;Z%P!I4$5H=E0>I;]FWPI/
M&]`3BKDVX'H&```KG)<2("8@(W$GH\$:&$37Z\A,'S5RT_SQU>[V8<O;U1R^
MN8KH1OE)IEN^6]=UOC]407FRGX:WC/BF,/YE)MGTJXC2MU`(_P`N33*Y!5\@
MB<J_H(=H!0*DL-N`$'H'6]QJI8^<&L;Z]9;N-JQCZ^S%NHTG9B>>(XU7J7RN
MTM!"7TN'.;SDW[>AH^1643\2_'M)0QAU^9P02\2I.<LS00*/NCS`[7(6AA,%
MAM?I8?8(]:V4ZXU413XNAZ(H?7&59MT%I=IJ;=Q'3))ZG!?4WBAX]C;CKA%,
M2F`W(N59V>]AN`"5;*54Q+]`AUKX-;ZJXW9/^[A]4853_(VE?_2_WDW_`(BT
MY98P1BLJR6+;)]IO&Y!,L$$@$P@FBSD7+=).YS&,/`B8!U$1Z>VI^L973V4,
MSS5[XF./66@E0#?1-@O9H6"C&2O:!T!Q`4?JZ5JE$2B)1$HB41;=_A&N..P=
MP-+_`+_#8!Q;_99M=*_ZO65`OGPRN59?)RN'CM8#ZE,7D\ZF8WK.<##V./TK
M>U7,JGU*(M=GQ06W?\77*MO[GGV(.?T<OM-I?_>JEGR7?AUJ![UK*/YI]2C;
MS4;BTJ3[MQ&?YP]:YP:Z[7-*V0_"S<]CR;=I7MZS6>5MK=.O&3QMY;_=;_JJ
M(?.QF+1K7>[>1']60>M29Y4.PZI(]ZUD'ZS#ZENY\@?'C7_D9A2V)9LR[3UL
M"[C&<I9))_;F+2:A`+ZM@J>W?:+B0H.FAQ[+DA0OQ.5-1/G#2NK,UTCF(OLN
M=6-U!)&?8D;R<.!&W"X;6GF"09SU%IS+M2V)L[YM'BI9(/:C=S!X@_6:=CAT
M@$<RV_/'[8'CMFR^'YRPN@L*SC',E9IJC!Y3%IG*4'T8X.'NK)<R@Y;'LLV4
M,`&#B8AS]D:7U5E6K,N&89:[O"@DC/MQN]UPY';A<-CANV@@<O:AT[F.F[XV
M=^WNFI8\>S(WFT\_>:=K3OV$$V.K95@5CQY7XA$YEX\[792S?O!#8=-9='*%
MX@LUEL28.)]BNB<0$2"<[$4E+6$Z"IR>PPU4B<6R"G.BR.4S/AS&)S/K/#3U
M.-#\_:N:>LDI*2B)1$HB41*(I+F?XPRS\RSOWHZHBC5$6PCX:CCL[^G4[V]7
MJ_(6_P`O7CD>'NK?[M5O<_L_2M>U**Y>T\I1\SEO7JQ6BJ08HY%EE.-/`'B+
M2?AW(#>UA0D6RM[C[+<*H7+/$MY(SN<QP[00J]J[!=1OY2-/80NS&OSR7;"A
M&QT^[@V2E^:.,I_H54E?_0K)Y.<.9PG]/YP0K>[%;=_4L&:D]:XE$6@?::79
MV=L9$/8EGF7I!_\`9Y!(%_R5T_DIQ9-:.YVT7\QJY>SH8<XNV\KF7^>Y0.LF
ML8E$2B)1$HB41;6/A*N>.Z=D-+_O]7J.;?[+EF.)7^?IZRH/\]F5T[9R<KVG
M;%(?4I:\H'4SRY9SM*]DC/I6_FN6UT*E$6!7Q*6W?\3,S5M?T>080Y_1RR>/
M:7_WJU2AY/OPZZMV^]%,/[MQ]2C_`,SFXM(3GW9(C^N!ZUS1UV(N8%L"^&6Y
M['E7CZ5[>LQ',VUKAUXQ7J[?3_=;_JJ*_.1F+0\I]V>$_K4]:D3RN=AU;&/>
MAD'ZM?4ND^N/UTVM4/Q;&P'T]K)Y;JALH[;E\H`[Q>;5$/9\OHOZJG+R)?34
M%Y'SLZ]DC!ZU$?F^VN2VK^5U3MC=]"T&5U$N?%;3=*'JM.;9;6OZG6F=H6^?
MO8M*IV]@^WE7IGMCK"N;(TO(C^];_."Y:ZRBE)*(E$2B)1$HBDN9_C#+/S+.
M_>CJB*-419W?#I7[/D:W3_\`S6$Y0A^GC]GN?_V]4+C]GZ5@M1"N7'H>WUK?
MC5@M!7W;*B@X07#H**R2H6]MTSE.'L_17PBHHOK3A<'<BNTD!`0`0$!`0`0$
M!N`@/L$!^4!K\[5VZHQFR?=P_*"6O_P"6.`?2DR65#]=R5>Y8<.8P']ZWY2`
MJ5P*P/\`LGYE@54J+6DHBT([@"VV]I`'L#8N;A_1DTF%=.9#_P#(K+_V2'_A
MM7,.?"F>WH_Q<W_$<K<UEEB4HB41*(E$2B+9U\*%SV?(S+$1'H[T[D28!TZG
M3S#`EP'Y[@1(W]-0SYY,Q:2@=[N81_\`"G"E+RC=AU+,WG9/_P")$5T+URBN
MC4HBPI^(@V]1X?[:$`N9N."N2^W_`+/8^(E4'I\R)S5(WE._!KZPY'QA_P#U
MY?6M'\QVXM&WG,>$?[Z-<PE=G+EA9R?#C<]CR\UJE>WK&&>-K7MRXX%DCNWT
M_P!UO^JHU\W&8M!7CO=="?[^,>M;YY:NPZQM1[S91_=//J73;7&JZC6L#XL+
M;N>/&&N`#JVW%`7]O1-;#,](;]?<`E31Y&/IJRX9[V7O^26#^-17YNMKIR!W
M*]9\L<JY[:ZL7.BA^Q$/5:_SEM:_J,.R9"WS]Z%>IV_ZU?6^T.M5K<TN(S^F
MWYPN5"LJI52B)1$HB41*(I+F?XPRS\RSOWHZHBC5$6:?P_E^SY-XDG>WJH3,
M$/T\<<?NK>W_`-6JC<?LBL+J`5RQ_0YOSA=!E8]1\E$79W!.?60<,[O?U45'
M.;W$;]]HBK>X]1ORK\\KIGAW,D?NO<.PD+MFW=C@8_FP'M`7XR)/O8_.H^WN
MPTFG_P!-DN7_`"UZLSANXG<I&_S@O4HK$X?HGYEK[J65K"41:&=U)"CN#:)!
M`0OL#+E;"%NB\Z^6`>OR&!2X?/73.GG8LALC_A8AV,:%S)J)N'/[T?XJ4]KW
M%6QK,K#)1$HB41*(E$6QOX7#GL>3QDKV]9KG+&UNGO<7<$[MU_V6_P"JHC\Z
MF8M&8O=NXC\CQZU)7E2[#JFGO6T@^5A]2Z-JY'72J418D>=K;U7B7N=*U^,%
M$.;6$?[GE<`[OT_S>Q>M\\LGX-=Y<[]Z\=L3QZUI^OFX](7P_=M/9(P^I<LM
M=L+E!9B^`+GTOEYIM6]N3_*VU[V_OF!94TM\OUN_;Z:C_P`TF8]!9@W]&(]D
M\1]2W3R\=@UC9']*0=L4@]:ZC*XK75:UO?%,;=_QD:JVOZ/9F*.;]>G*-R-I
M?_>K?KJ7O)-^'63A[UG*/UHSZE&?FNW%I8'W;J,_JO'K7.?76RYL5)GV_JX*
M::VOZF)DF]OG[S-9.WZ^5!O7N,TD:>1"Y-JRREA*(E$2B)1$HBDN9_C#*_S+
M._>CJB*-419<^"B_8\IM8W&Q5PS)`WLZ\\!R@2!UM[52EJC/^R/\.*Q&>BN5
M2_=_GM71-6/4=I1%V+ZO=^OUIKM\(\A>X+B3L3?YWJ("/6O^OG7`&>Q^#GEY
M#[EW,.R1P79^4O\`$RNVD]ZWC/:P%3!\GWF3Q&U^ZU<)V^?FD<MOZZQT3L,K
M7<G`_*KYPJTCH6NRI>6K)1%HU\BVWI=W[)2`+<LC6<VM;^^-V[P1_6*]ZZ0T
MF_'IRS=^Z`["1ZES9JMF#4=X/WQ/;0^M65K8EKR41*(E$2B)1%GY\-!SV/*[
M%TKV]9B^:MK7]O&"7=V^G^ZW_546^<3,6AIG>[/"?UP/6I"\L'8=71#G%*/U
M"?4NE6N/5TZE$6*WF2^B7?C%N]E]I1YG!<(DS`W!ZV%;OM%D%P2!(%>YW041
MMQM>_2U;OY?13LUGELF!^#XENVAI0@BM:;MJU+6KXGZ6OV8FXO`=LJ*U!!]2
MY5Z[=7)JRG\)7/I?*O2:M[<LN]->XA_?(J2:6Z?/W[5I/F.S'H?,A^XKV.:?
M4MLT,[!JVQ/[ZG:UP]:ZJJXA76:U^_$T;=_Q4R!6U_1Y=ACF_7W>4L#2_3_:
MK=?GJ5/)M^'7$0]Z"8?JU]2COS1;BTE(?=FC/ZU/6N;"NP%S(OX8I3E,0P7*
M8HE,'SE,%A#I\X#1%R3N$3-UUT#?60641-_SDSF(/]9:RREH&HJOC1?4HB41
M*(E$4ES/\897^99W[T=411JB+)[PR<>F\G-2J7MRFI1O?I_B\:FVMNOS]ZU4
MIOV16+SD5RR8?HC^<%T@UCE'"41=>^@UQ=:*TLY$;BXU-KE<1]MQ6P^&4OUZ
M]>5<%ZL;AU3F;1N&87`_OGKL;3SL606+N=G"?[MJNS6OK,K70NGV5UDO^Z54
M3_Z!Q+_DJ8&G$T.YA:J10D+Y5Z7Q:3_*E+L[]V$0`MR=02O_`+1BT&N(_K%2
MNB-$NQ:7M3T/'9(\+G/6C<.I[L?I-/;&PK'NMJ6KI1$HB41*(E$52B9F7@7R
M4G!2LE"R2)5"(R$2^=1SY(JR9DEBI.V:J*Z954CB4P`8`,41`>E49[>WNHS#
M<L9)"=[7-#@:;1L((V%589IK>02P/<R4;BTD';TBA53<9GF#M,R3K*\E<I&$
M#&2<3LHLF8P#R`3$4=&*(@/4.GMJBS+LO8<3((0[H8T>I577MX\87S2EO2]Q
M]:H;EX[>G*H\=.79R%X%.Y757.4EQ-Q*94QQ`MQ$;>RXU<LCCC%(VAHZ`!\R
MMW/>\U>23TFJ\U>UY2B+(CQ)<^E\F]%JWMRV9BK:_7_&2:+.W3Y^_:M3UVS'
MHW,V_P"#E/8TGU+9-'NP:IL#_BHQVNIZUUDUPNNNU@W\1MMW_$/9:MK^C?X&
MYO8?=Y9]C;2_T?WJWZZDKRC?AU[9M]YLP_N)#ZEH?F4W%HZZ/NNB/]ZP>M<R
M5=E+EQ*(N3_*V_I,HR1K:WII^8;VM:W9D7"=K#U"W&LJ-P4KQ&L33S:/F5`K
MZJB41*(E$2B*29E^+\J_,DY]YNJ(HW1%D)XHN/3>1VGE+VY9I'-[WM_>RK-;
M?K[UJIR_LSU+'YL*Y;-]@KI;K&J-$HBZW_&-QZGQQT*K\VGM;HC[>IFV(1#8
MP]?E$4JX0UFW!J[-!_\`4+@]LKCZUV#I9V/367G_``4([(VA7RK6EGE`#:NP
M,YU%#X^D=190ZJACOI0PF44,)CC[SX>("8?8%@#Y`K+#/,U`#1*:`4]EO]56
MOP=MOP_*?I7H)K?!B#R+C4>(VM[X+*!_T5%3%O\`JKP<YS,BAF?\@]2]?"6_
MN!<SGG9'(1/E?MZ/:I$0;(2.-"W03#B1)%;",9723(4+V(0BH`'T5V-Y9S.G
MT-82O-7EDE3S(FD!^9<L^8#!'J^]:-P<S_A,6)%;VM.2B)1$HB41*(E$2B+[
MMVSAVH"+5!9RL8!$$FZ1UE!`H7,($3*8P@4/;TZ5Y<]C!B>0&\R:+TUKGG"T
M$GH5;;8AECPAE&>+Y$Z3*;@8[:$DER%/8#<#&2;&*!N)@&WML-6S[^QC-))X
M6GI>T?.57;9WCQ5D4A'0UQ]2D+?4>UWADB--8["='7`#(E;X7DBYE@$O,!2*
ME&F%0!)UZ7Z=:M'Y]D<8)DO;1H&^LT8IU]Y7#<GS=Y`9:W))W4B>?Z*OWXZ:
M3W=%[WTS/.=.[4;Q,)M?7<A,R:^O<N2CXN,;Y9%+/GL@\/$%;LFC=DFHH=14
MQ2$(43&&P#6KZMU'IN;3&8VK,PL3/)8SM8T3Q%SG&)P:&C%4DF@``J2:!;#I
MO(\]BS^RN'65V(8[N$N<89*-:)&DDG#0`"I).P+J3KBE=6K#KS];>K\1-R)6
MOQC\5<VM?^Y9[BKR]OH[%_HJ0/*U^#7N7N_3E';!*/6M+\PFX]'7H_1C/9+&
M?4N7.NU%RHE$7*SL]OZ796PVMK>FSG+6]K6MV9^03M8;VMQK*-]D=2E2U-;:
M,\V-^8*#5Z5=*(E$2B)1%),RZ9AE8#[0R2=^]'5$4;HBO3XX./3;_P!+J7MR
MV?A+?VV_O>0,&MOU]ZU>)/V;NHJRS(5R^;_9.^8KIVK&*,4HBZP/#YT#SQ@T
M:J`WX:\@6OZV*`LA#]0MZX;U_'X6M,R:>-V\_P`HXO6NN-&/QZ5L#_AF#L%/
M4LD:T];.E$2B+#;9_@EH';^PY_9N;Q^4/,BR0(W[3299(O&Q@FBH:.@FAT&K
M5N19(P,8M+E^U$#'Y&$.M@D')?,W5.093%DV6O@;:0XL-8PYW>>YYJ2:'O./
M#=0+2LUT#I[.<RDS2^;*ZYEPXJ/+6]UH8*`#DT<=ZBS;X;'B6@02*X1.O#"8
M3`JYSC*RG`!`H<`!I*-4N("%^I1-<1ZVM:^?YP:Z<:MN8FCD(8O6TJT;Y9:0
M:*&"1QZ99/4X*0M_AZ>'[8Z:A-0)J*)A:[C.-DN2'$2B03*(+9@=L<1`;]26
M`>H`%@JT?YKZ^>"#?D`\H;<?*(J_*KEOESHUI!%G4CG+,?D,E/D5=;>"WB:T
M`X):7QXX'$!'U,EDST0$`$`X&>3BYDPZ]0+8!JU?YF:Z?[68R^AL8^9@5=F@
MM(,W6,?I<\_.XJOMO#KQ>:]GM:.U^;L<.'J88KSEPM;O>K47]1>W7N<N7RWJ
MU?Y@:T?6N976WD^G92E/117+=%Z592EA;[.;:]M:U]*K[;Q>\;F@G%+0VH3B
M<``?4Z\Q5Z`<;B'`'D6N"8]>HEL(_+5L_6FKY/:S2_V<IY1\S@KANE=,LW9?
M9^F&,_.TJO-]"Z,9D33::8U.U31&Z)&^NL/0(D/(3W3*E#E`@\QOTMUZU:OU
M1J60DR9C?.)WUGE->UZKMT_D+``RQLP!NI#&/Z*D#;66MF1Q59Z^P=HH8@D,
MHVQ.!0.8@B4PD$Z3`IA()B@-O9<`JT?G.<2##)=W+ATRO/SN5RW*\L8:LMH`
M>B-@]2K;?&,::)]EKCT&V2`1,"3>)8(I@8WUC<$VY2W'Y1M5LZ]O'G$^64NY
MESCZU7;:VS!A9'&!T-`]2KE6RN%_:(E$2B)1%BSYM-O5>*F[$K7XXCZFU@'^
MYRL:\OU_S>Q>MV\N'X-<9:[]_3M:X>M:GKEN/25\/W->QS3ZERJ5V\N3$HBY
M=-Z-_2[MW$VM8&^T]@H@%K=$LLER!8+B%K!649[`Z@I1L36RA/.)G\T*U=>E
M=)1$HB41*(I/FWXSR[\SS_WJ[HBC%$5S])./2[GU$ZO;TVS\!<7]ENSE<2I>
M_6UN->7^P>HJUO16RF'[I_\`-*ZD*Q:BY*(NIOP4<^K\3-+JWOQ@)5M\G^"R
MF>9VZ?-V*XI\T&>'KS,&_O(SVPQGUKJ_0+L>D+$_NW#LD>/4LMJT%;@E$2B)
M1$HB41*(E$2B)1$HB41*(E$2B)1$HBQW\MFWJO&7>J5K\=994YMT_P`'&+.[
M]?\`-[%ZVS0C\&LLL=_C(AVN`]:UO6#<>EK\?X60]C2?4N3:NZ%R(E$7,=Y*
MM_3>06YT[6Y;*R]Q[`#^]S3MU?I\_>O63B_9MZE)N6FN7PG]TWYE9&O:ODHB
M41*(E$4GS;\9Y=^9Y_[U=T11BB*::W7]+L3`G5[>FS3%E[W$+=F<8J7N'4+<
M:\N]D]2HW(K;R#FQWS%=5=8M14E$74#\/5;O^'^GS7N)$\X1'YP[.R<Q2`!^
M;W"A^JN,/-@4U_?_`.X_]WA75'ER<6C+/_>_\:19H5'2W=0%[M36<<NJU>Y_
MAR#E!55!=N;(XDR[==`XIK(N$B.C'0624`2F*<"F`0$+=!K*1Y+G$K0^.UN"
MP@$'PW4(.X@TVCJ6&EU#D,#S'+>6HD!((\5E01L((KL(/`JEJ;MU(D<2&V#C
M`F+:XIR22I.H`/11+FF;H/R"-AZ>VJPT[GA%1:S?R2%;NU7IMIH;VWKT.!^4
M*FJ>0.FTRF.;/8D0+[031DE3>VWND28G.;]0#54:7S\F@MG]K1ZU1.L],-%3
M>1TZG'YFKP*^2>DT0`3YP@(&&P=J$R5<?U@A"J"4/I&U56Z1U$[=;'TOC'SO
M5%VNM*,WW8]$<I^9A7@5\HM*)FXERMPL%@'FECN2`7K\EEHI(]P_1:JK=&:A
M(J8`.N2/U.*H.\P-*@T%PXCHCE];`J>IY7Z=)SXRDRKQY<03@7P=SC>W#NE2
M`.=NG+C]-JJC1&?FE61C[X]551/F+I@5I)*?]V[;VT^54]7R[U*F4#$+E*XW
M`."4,@!@"P^\(KR*)+!;Y[]?954:%SPG;X(^^?4TJB[S*TVT5'Q!ZF#UN"\"
MOF/JU,P`2(SA<!"XF2BH4"@-Q#B/?R-$U_T`(54;H'.B-K[8=;G^J,JB[S.T
M^T[([L]3&>N4*GJ>9VO@$W:QG,CE"_`5$(1,3?-R*6:5`E_H$U5AY?YI3;-;
MUZW_`-0*B[S1R6O=@NB.D1C^F53E/-+%`((I89D)S]+%4>QJ1!"_6YRF6$+!
M_P`D:JCR]O:]ZXB`ZG'Z%0=YIY=3NVLQ/2YH^E>!7S6AR\>Q@$DI[>7=GFJ-
MO9;CPC''*_6_LM51OEY/]:Z8.IA/](*B[S5MA[%G(>N0#^B5X5/-M,#B"6M#
MG3Z<3*9@5(X]`O<A<86`+#_RAN%51Y=FG>O`#_LJ_P#>!47>:S:]VP)'3-3_
M`+H_.J:IYKR8E,"6O6)#C]4RF1N%"AU_M%+#I";I\PA58>7D-=MTZG^S']94
M#YJW%.[9,!_VI/\`0"\"OFGDX@'8PF"3&_O"K(R"P"'S`!"("`W^D:J-\O;/
MZUQ*>IK1]*HN\T[\^S:0@]+G'Z%X%?,_.A-='%<33)8/=5"85-?Y1YDDD0L/
MS<:JCR^RVG>GG)^Z/Z)5)WFEFY/=M[8#IQG^D%G]B4PKD.*XS/KII)+SF/PT
MPLDAS!!-63CFSU1-$%#'."1#KB!>1A&P=1&HOOH&VM[-:M)+8Y7M!.^C7$;>
MG8IDRVY=>Y=;WCP`^:%CR!N!<T.(%>&W8K;^2+;U?CQO=O:YE=.;,`@?_2%P
MR:,E\_L4*%9G2#_#U9EC^`S"W_XS*JPU,W'IS,&\[*?_`(;ER+UWBN/$HBYJ
M/+1OZ;R0W`G:W++W3BW3_%MVKJ_3Y^]>LE%^S'4I*RDURV'["QWJHLBE$2B)
M1$HBD^;?C/+OS//_`'J[HBC%$5:QMQZ7(H%U>WIIJ+<7Z].R^04OTZ].-?#N
M7B05C<.;3\RZQ:Q2B=*(NF7X;KGO^)&`)7OZ.7SEM;I[O+,YMW;I_M5_UUQQ
MYO,PZ\NG>]'"?[I@]2ZA\LW8M'VXY/E']XX^M9V5&2WY:3-BI]G8.=I6MVLR
MR=.WLMPFWQ;6Z6]E=$92<65VSN=O'_,"Y3SMN'.KQO*ZE']XY0VL@L8E$2B)
M1$HB412K-<54PK)I/&59F$R$\9Z.\QCBT@O"O0>,&L@0S%:5C8A^H5(CL$SB
M=NG^T(;CR+8QJUQ`;>9T)<UY;3:VM#4`[*@'CR7I[,#BVH-.(W**U17E*(E$
M2B)1$HB41;H-1*][5FNC_-A6-)?Z"(:(_P#AUS[GK<.=78_Q$A[7$KJ33;L6
MGK$_X2(=C`%\=SM_6:>VNTM?U6M<Z;V^?OXO*)6Z@/\`G5ZTZ_P]06,GNWD)
M[)&JOG;<>37;.=K*.V-RX^:[\7&B41<X?FFW]-Y/;93M;E*PKC_VO%(%U?I\
M_>K(P_L@I'R4URN(]!_G%8N55642B)1$HB412?-OQGEWYGG_`+U=T11BB+]I
MG,DH14G0R9RG*/S&(8#%]EA]H40[11=;*2A54DU2_553(H7_`)IR@8/ZAK$J
M)2*&B_=%\72'\,)WZGQ:CT;W]!G.8-`"X>[S69/K?1U>W_77(GG1'@UJYWOV
ML1_G-_HKICRL?BTHUONW$@^8^M;#JB92.M+6V$^UM'8I+6#^.,J.`>RP*S;U
M0+!8.EC]*Z$R,XLFM#_AH_Y@7+.HVX=07P_Q<ORR.*M_646&2B)1%<?$-0[-
MSZ*>3V'X3/SL#'/OLM_.M68DA&<D+7UP1[F7<F0CD7PL_P!J"1E04%/WK6J[
M@L+RZ898(W.B!H74V`TK2NZM-M*JHR&608F-);7?P60&D_%?(<LE\Q-L"#=Q
M^/P.K-H9.U<1V3XR5Z3(\9PJ5F<>%5D@^D)!S'#*-DP5`B'`P>Z)RA>LIEV2
MRSR2?%-(B;#([8YM<36$MV5)I7?L]*N(+1SW'Q!W0QQWC>!4+%3'9**B91)[
M,XXQRI@1-8BD/(OIB.;+'4()4U3.H-_&R!#(&'D4"J@41"Q@$.E82)[&/Q2,
M#V\B2/E!!5HT@&KA4<O^Q;9=]:/A&L7FNR</T?/;\RUUM3`(`S;*)O<^<NH/
M")[QHUIFS(JYL#S#&Y]V,?D4NNV;NWCA4B;9-%`0-8H!O&9Y=&UDEW!;.N9S
M.QO>,KZ,=;QO'L.:XT<2`2=U`LO<0-`=*QAD?C`VEQH"QIX$'>K,ZQU([F/Y
MG16V/$)GJN"C--;1R5CF,K"[XQ5Q!99!X>^D\270D]@;!D8HZBLHFEQ:G24!
MP!OJ&+RK'V=BZ3QH[VP$$8MY'!Y$S<+@PENU[R-]-E-JH10DXA-#@:&.-:.%
M"!LWE>S8L-K^%\M_Y"PVKM71."2!,-QUFY>Q$LXDV:>::T@I$LRXR!64>R?K
MFTE.^I!P0IA(8@"4@VL/J[CM8\\_+(X81;'`T$@U&.,&N*I-036J^R"-MW\.
MUC!&:#=S:./I6)T[HM:.U=)[;Q[9FN,^QF#RN#PZ>:XJ38S&;AY;(F,S(1*C
MEGG.N\-;.&+E"#6_:-EW`E,)0$OUN.#ERTLLS?130RPM>&.#?$!!<"14/C9L
MV'<2K1T%(C,US7-!`-*U%:\P.2L36-5!*(E$2B+<?HY7O:BU^?YL;9)?Z#FC
M_P"'4!:C;ASVZ'[XGMVKIW23L6FK(_N&CLV>I2K/6WK,&S-I:_JL3R)M;Y^_
M#O$K?]:K/*W^'F=O)[L\9['A9;,&X["=G.%X[6E<;5?H*N+$HBYW?/!#L^4V
MRCVL#E'"UP__`,%C")A_6=$1K(0?LAZ?G4B9":Y5%T8OY[EB%599=*(E$2B)
M1%)\V_&>7?F>?^]7=$48HB41=8F,N/58YC[J]_4PD4XO\_>8(*7_`.M6*.]1
M1**2N')Q^=5NOBIKHC^%2X[WC9.IWOZ3;63MPZ^SEC>&.K?1_>;URAYXMPZO
MA//+XS_>S#U+H_RE=BTS(.5X\?J1'UK9=4-*4%IIW2GVML["+:U\KEU/],Z.
MK?V![>=3_IXUR.U/[AOR"BY>U2W#J.]'^(>>TU5L*S*P*41*(LG</SO#G'CK
M*:DS6(V`U9*[JC-@1>7XC$1<Q'%D2X2_QI3&7K>6DX9('SMLKZE/MN!4$J7U
M!`!&LQ!<P'*G6-PV4-^(#PYH!%<!;A-2-IW[^&Y7+)&?#F%X=3'6HZJ44UU)
MDFOM49>XR3#<!WIF,U.8MLG7^,14G'PL8VE)C(L1D<8E4CI13&9>/%X%*:%5
M9JV$RQ#`03B4!XC<V,UK93F:WBN9)',D8T$`5+FEIW`DX:U(&U5(71POQ,;(
M7$.`W<13Y*J'Y`\T;E&2*,HK0VUL=R1C$I-9_$,?VMC\5$Q[["L8XYA)H(Y!
MJ7)9EH=0\&Z?NTG"YNRH96PE*`$"WE=ELTN%EM.R8-HYK9&@`L;WCWHG$;BX
M@G9MZEX<8'NHV-X=3:`X<!MWM/*JO5LOR,C]HXJXA<PT#DA<#G9/%=BXB,3M
M1JQFVC/6&MF&G79I&<6UV_9S*#AG$%<.`+'L%2*"02E[8@8^0O,V;>P&.XM7
M_#.+9&TD`($<8B-3@(.P5/=;V*O+<B5N%\9\,T([VWNMP[Z>H*U6//L4PY=\
MXCO'6,DIF8U;D.4PX[.V3#Y)#-,5E<?E6Y\KC8%6&QMM(SD<T[KIBCW3ODW"
M!5$4NX4HA91.AMR2RT:9'0N</$D#@&EI[P%&U(&T#?4;!546EC#41C$6$]XU
M%*;Z;-O+BJ;EV<;/RW:,EY(.,6@F,A@C724Q,,DWA5HA-N7$<7@L)<KM1E0D
MWB62QT,@LZ304YH'7,4_:'H'B>YO)[TYL6-#HA"2*[/9:&<:G$`":;J\%\?)
M*^4W-!5N$GL`':J/)M-I:TUWN;3DO%XZC$H9AJV<SD/4#*34=+-8W)#8N:%?
MQ<@K$*P[MM.J`\6%-9/N"V*FJ45`!3P]M[9VMQE\@8&"2,OXD$!V&A!I0XMI
MV\*';M^$2Q1OA(&&K2>?&E.C:L<JQ*MDHB41*(MOWCTKWM,X&?YHUVE_H):0
M1_J[=0/JIN'4%R/TP>UK2NEM%.Q:7LS^[(['N'J5V9)MZR.D&EK^J9.FUOG[
MZ"B5NG7KRK"0O\.9DGNN![#5;+*W'$YG-I':%Q>5^AZXD2B+GX^(*AV?)C)E
M+?WK'\17_3Q@VS6_^[5?V_[(*0-/FN6-')SOG6$]5UFTHB41*(E$4GS;\9Y=
M^9Y_[U=T11BB)1%U5:U7]5KG`'7M]3A.*KW^?O03!3_TJQ3O:/6HKN12YD')
M[OG*FM?%0705\)ISST#G32_5#<$PO;Y0*ZPO!DP_0%VHURMYZ,IJFU?SR]@[
M)IOI71/E"ZNGKAG*]<>V*+Z%M'J%%*RT[[Y3[6X,^+:UYU13_3-FZM_8'MYU
M/>F37(;4_N_F)"YDU@W#J:\'[ZO:`5:*LZM;7J38O5B%419NE4S7XJ)MUCD-
M81*/$Q2"4;&`0'Z0KV(Y'"K6N(ZBOH:X[0#1?3[,DO\`W>^_]D7_`/PZ^^#+
M[KNPIA=R*D;6:S)G`EQEN#TL$3(6V5!'*1*"Z7V\S:&8H/3'79*+G*#4_`R(
MF%!0``3D,)0$*K3=MB\$!WA8\5,/U@*5W<N&Y>P9`W"`<-:[N*]P9=L%,8\X
M2LHR4B9J=R*.D1(E&NF$UDR3-&<?IS`I-W*"LD5@B`@*P$`Y0$@`<PB/KQ+P
M4-7-PN+@=U"ZE3BV4K0<>I,4O2*$GEM._:J0E)Y,A-.,D;S9V\^[7D7+B8;3
MK-O(J.)=-RE)K"Z1>D6*H]3>*E4$!`3`H8/EKP#.)#,'`2FNW$VNW?MKQJ5\
M[X=B![W.H0)3*BH,6Q<B>`VC(Z0B(UN&3I@A'Q,LHY6E8MBD$EVVD=)JO5C.
M$$P*DL98XG*(F-=6XH!CV`$#OC8#O`V[`:FHXU3O[J[`*;_XUY%59Q?TW?EC
M+>C8#%-.[/ME/2Q9N_>-;<WX]A@/J5+HELG^T-T]X;^2V4TJX;!0=\;!RW[N
MA?*.Y\.8^E><04$JB:DTB`*$0372%615*8K0A4VZ2ADFBJ"Q&I"@5/B8Q"@`
M<!M:OF'@7M_6X=0(V=G)*=(^5?-1!-4XJ*RS110WUCJ%DSG-8``+F,P$1L`5
M\+&G:7MK][^JE!S'R_0OQZ1#_P!YL?\`1R7_`/7TP-]]OZW]5?*#F/E^A/3M
M"=5)`AR^P`:-W"JE_G,5V1@F!+!U$#B:]NEKB#"P;W`CH!/ST^=*#B?X?(OF
MH1D!#"BX='4Z<2J,T4B#U"_)0KY8Q;%N(>Z-QZ?37PB.G=+B>H#UE#AX5K_#
MI7EKPOBVV>,JO=TEA7SIAD"1OHX93-@7_J6J#=8-PZBN.G`?[MBZ/T$[%I2U
MYCQ!_>R*_-:RMP7&!,-O1R\HTM;TLB^;6Z].PY52MUZ].-?H=;O\2!DGO,![
M0"N)9FX)GLY.(["J;594EK#\S_#O8>V\R4VCKMY$2SO[!CHM[B#U8(J26/%^
MI`CB*D7)_LMT==-8H"DX.UX"7H<][!<PS-8W"Y;/DN<6]I#\+<`@8B0X;1MY
MC?V56G[*<1RG")=>`S#'Y?&IEMU6C9I@XCW0$$1`BR:;A,G>;*\1$BI.29PZ
ME,(=:O`0X5&T+<(IHIV>)"X.8>(-5':^JHE$2B)1%)\V_&>7?F>?^]7=$48H
MB41=1^D%_5:6U"ZO?U.K\`7OTZ][%(E2_3IUY5BW^V>LJ+KX4O9ARE?_`#BK
MH5Y5JM]?PD7('U1M-G?JAL)FYX]>@.\;CT@'YO>]%^GI^BN8//=E,\LI.=H1
MV2./K70/D^^N47;.5R#VL'T+;-4%*7EJ$\BD^UNC.RVM=_'J?Z:$C%;_`*^=
M3OI0UT_;']%WR/<%S5K9N'5-X/TVGMC859Q%RY;<O3N%T.=N?9542Y\;\>7`
MQ>7'D-K^R];&U[V>R2.HK502-R_"BJBQS*+*'54-;DHH<QSFL`%#D8PB8;%`
M`#Z`KX27&KB24))VG>OG7Q$HB41*(E$2B)1$HB41*(E$2B+:WXKJ]S3$`2]^
MQ(Y`E^B\P[6M]'[ZH2UJVFH)3S8P_J`>I=$>7KL6EH1R?(/UW'UK(JM46[KC
M>V$V]'GV<,[6]+F&3-K6$+=B:>I6L/4+<:_03*7^)E=M)[UO&>U@*XLS%N#,
M)V<IGCL<5#ZR"LTHBA><ZYP79<0>"SS%H;*(PW,4T91H159HH<`*9>.>D[;Z
M,="4+=UNJDJ`=`-7UKG--6FA5>"YGMG^)`]S'='K&X^E:S-P_#3;J^JF-)Y.
M+8_[18,-S!8ZB`^TW8B<E02,NE8`XII/$5+B-SN2A<:NF7/!X]*V:SU*=C+U
MNSWF^MOT'T+6+L#5VP=62PPNP,2F,8?"8X(#(-A%B_*G8#JQ<H@9:,E4"B-A
M.W65(`]!&_2KEKVO%6FJV:WNK>Z9CMWAS>C>.L;QZ5`:]*X2B*3YM^,\N_,\
M_P#>KNB*,41*(NG7QN7]3X_Z74O?CK+"T+]/\+`,6MNG^;V;5C)?VCNM1CF0
MIF$P_>N^<J]5>%9+>/\`"'<\\7W>SOT0G\)<V^;U<=D25_U^B_JKFWS[92ZR
MR3G'..PQ'^DIW\G'UM;]G*2(]H?]"W%5SZIH6I/R:3[>[LU^8XX\H'T\\5A!
M-_U[U.6CS73MO]__`(CUS?KUN'5=UT^&?[J-6-1;J+\N!D"\+7[SELVORO;C
MZA5+G[.MKV^7VA6T-:7;J>D@?.5J`%54XZ!?2<@QC6RD=ZF0>-F+?N2L<5/O
MNUR-TN9@<F$I.XH%QL-@JHV![W!@+:DT]IO'TKT&$F@I4](614]XA[4@F4ZL
M60P*;E<98#*SN+068,GN4QL:5$CDSQQ$K)-3%2!HH54H<^:A#%X`83``Y23(
M;V-KC6)SV"KFAX+@.9&SAM5PZSF:#[)(W@':K9ZMU%.;6GY#'H>5@8QU'X_)
M9"=:2>G716;QAVI%6R1(A*2<`X4]4`E$Q"I^Z("8!$`&TL\OEO93$QS&D-+M
MIKNI[M3ZE3B@=*XM!`(%?X4JKH)>,[)IBV(93E6Y]<8@AFL(C/PS.7"?!RJQ
M51;K'``+&%[BS<')"J%*`@!AL`C5W^3M;#'--<PL$C<0KBW=BJ_"@,:]\C1B
M%1O^A>6>\9Y"&T\UV^CFT)(L%X^+E58=&.E4G2,=)RQ(8CH'`IJ`LF@]5(![
M)A8#@(V"U_DF3.CL!?"5A90&E';B:<N?0OCK4B'QL0IZ>=%]]L>,Y]5:]@,W
M=YVPE'4O,0\*_@RP+]D$0\EL85R7MGD0=O%'*K=$A2<1;)`8#@:X#[E>KW)O
M@K5MPZ5I+G`$82*$MQ;]OS!?9;7PHP\N!J:;CRJOIKW1."2FO([9>QM@RV,P
M,_EH85")P>,_:Q@DS%6+]H2CH[PH,HPJS=3H9(AS$)>Y3&*6EKEEH^U%W=S.
M9$Y^`4;7;S)KNW\`4CMXS&)9'$-+J"@_AL45FO'S+D=C9;KO$&TMGCK%%&QW
M,G`1+4S`S&0;(O(]PX74F?2LG"Z"W$43*B8%DU"%$W`1JC)E4HNWVD&.5S-Y
M:T4H=H^MLZN=5X=;.\0QLJXCD/XU(<4\9\BG<,VWD$FWR6$FM:#'HHP#R$8M
ME)-V*0R4ZDJHZF4C(A$0)T78"`"5=-P04S&O8:L.3ODMYY7^(U\-.Z6@5.\[
MW<&T/378O;+5SF/<<0<WA3MX\E;]?2V=LW>0,7&+R2CO&,1_CR=14E,<CC1V
M)@D*_P!K@)I.0+($.EU[*`BX"WU#"/2U.7SM<]I8XN9'C=M:VC>>]U>H;>A4
M_`>"10U`J=PV<^*E3[QIVA'8_)Y&[Q(2,HJ`1RATU2S#&G4J;'U4/4J2K>-:
MD6<KM&J`"*ABAT$IBEY&*8H5W91=,B,SHSA:W$>^VN'?6E*T7HVT@:7%NP"N
M\;E8$QX\2F`C9X4XE'@8SY$Y2FM[HF($<03%`?:`&"_SA6+)BIL#J]8_JJW[
MO(]O\2\=>%\6TGQ)5[FHD"7OV,BFTOT7,V6M_P#?5#&N6TSTGG$P_./4N@?+
M=V+30'*>0?,?6LG*TY;\N/W=C;T>YMN-+6]+L[/6UK6MV,JEDK6N-K<:[ZTX
M_P`33UA)[UE`>V)I7&N>MP9W>,Y74H[)'*V%9I8I*(E$2B*B9%C6/9=$N8+*
M8.)R*&>!9S%S3!M),5K`(%,9L[352[B?(1*<``Q!Z@(#7T$@U&]>XY9(7B2)
MQ:\<0:%:Y]Q?#<PG(?52^H)M7!Y4X'5+C<T=U+8HX5&X@FV>B*\Y"E.8PB)A
M%\F``!2)$"KAERX;'[0MCL]23QT9>-QLYC8[Z#\G6M?0^%WD:7-T\%'7SH'J
MJ2SM.>]8R_A$\<W6016?ADG>]!9,729A;7]=8P?L.72KCQH\.*JV#\ZR[P/'
M\08>5#BKRIO].[I6/^;?C/+OS//_`'J[JJLJHQ1$HBZ6O$]QZGQQT\I>_'#&
M#?VW_NJB[6WZNS:L;+^T/6HUS84S*;[960M4UCENL^$`M=+R";B/U5-6+%#Y
M^X78A#C^KME_IKG7S\'_`,J=_P"T_P#^=3AY-NV9BW_8'_C+=+7.JF]:H?*9
M/ANG)#?]\RQY3]-H)@E_X53=HLUT]".3G_SW%<Z^8+::IG/-D9_NVCU+'BMJ
M6E*L8\MZ:?@W%[>GF(Q:_P`W:>H'OUZ=.->XC25IY.'SKZWVAUK:A'I*H>>N
M8JV'T"^`)KS!S!=N2-)B6.H&,[$?V96WK&R(#S]WE;Z*W5@(U-(?JF+;U86[
M_3198#_X@[EAV]@5C?$S7^3XIMK&I*:C2LX?8NN<N?XRN5XS>"]B/^&G*NJ1
MJX7.T,)54AX+<%`Y@!B@-P#&Y':S07S'R"D<L3BW:#4;.6[TJWLXW,F!<.ZY
MIIU*49ID<1$:/\;UY+3\=M-1[A<PT06?*31#07V8,&B8A`ARFY%?F7`1[EOW
M/N_+:M<31QY=:%\`FK&1MKLI3ES]2]O<&V\1+`_NGGLW<E-\$(SG]?\`CMKR
M:,=&-V?K#<^"N@4`P>FE8J4Q^7BG1B&XB#EDK"K%(41#WC\0ZB%7-L&RVMI:
MR>Q-#*SJ(+2.RA52.CHXHW;GL</F/J4%\D)T,LTSL*1(8#I1/E5(0Z!BC[@-
MX#"U<>;]NWN]H44B\;=.(A5MFTGCY?*_@V](]#6853N78X''E-3L%%$O'];9
M6.ZH6GL:B6FX,"G,S-C>::;&$/+/F/>:$45GD%"^J%J"Z)&Q3<D%&]CE.H4.
M'<+;Y6;R*Q,L+1<6KI,+XJ5(V>UQIPX4Y\UXM_%;#B:,<9=0MI7TJ^[G`L0P
M9IY+X)A6'.,];\=5Y(GK-A-R[24Y2+Y91S&IOH5<9XS2(,F#[MD.8XHF*D8U
MC@8<F;6"V;>6UO&91^&[PP2#M.ZH[U!OZMBN#&Q@ECC;B]DX:GU;50IPN99<
MX\H<:FHJ$:9D_P!5:\>!C6.SB\P1,(<SYQ99S)(,'`R:3%9#O@8HVY)AS-R+
M>E)\1.;V&1K1<&",X6FNZO.FVE*^A>78W^*UP&/`-@/)225AGSUWG&=E](?$
M<Q\-G,+&S(2#`4I"=3C146CVZ/J/6++H-/>.)4^)+@`B!A`*K/C<XR7.SP),
MOH#4;74W<]R]%I)<_P"HZ"E>E?1['*Q\U)[#EG48QQ%_X7LH!T_=2T8DN6;D
ME"KL&GV49V$F87R#50$#E2%%90#)D,*@"6OKF%DANGEH@.7AI)(WG<*5KMIL
MV4.[>OI%'&0T##!3TK4?6C+#I1%LX\.U>YJN1)?]QF<LE[?9>*@5[?1^^J'=
M>MIG3#SMVG]9X]2GORR=BT\\<KIX_4C/K65M:2I$7(WY+-O2>16^$`"Q2[BV
M4<@6M9-7,9A9,/:/0$U`KO#1S\>DLK=_]/M_DB8%Q[J=N#4F8-_QLW_$<K)5
MLBP2V??#R\6]8>0$1MZ4V?'.99K$DQW'H!)C)O(QW$O9+[0DG\T@LT53`7B1
M&#=-$%2JHB4ZI3IF`;5#'FQK7.=*SV$.2O;&^0R2/JT.#@W"UK""-QQ.)I0U
M#:$*5/+C2F5:BAO)<U:7L9@8RCBTM+JN+@1QV`"M1OJ"J]O#X66P\5]9-:5G
MDMBPJ?<5+C,T=G"YHV1"Y@3;NC&;X_/F(0HB8P&8*F$0*F@<:M=-^=F4WV&W
MU'$;2Y.SQ&5?"3TC:]GZX&\N"KY[Y49E:8I\CD%S![CJ-D'4=C'_`*AY-*U@
M9)C&1X=,.\>RR!F,:G6!^#V'G8YW%238PWX]YF]217(4X!<IN/$P=0$0J9[.
M]L\PMVW=C+'-;.W/8X.:>H@D*++FUN;*8VUY&^*X;O:]I:X>@T*H572MTHB4
M1<H^;?C/+OS//_>KNLLI;48HB41=('A@X]3XQ:F4O?C#RS?VW_NF3SC6WZNS
M:L=-^U*CC.A3,YA^D/YH63]4EBUN/^$,YXY#O-I?]_#8$YM_LK[*DK_J]97/
MOGVRMIEDG*2<=HB^A33Y..I<W[.;(CV&3Z5O"KFU3LM5_EBGPW#(&_[V$@E/
MZ&HI?^'4TZ(-<A8.4C_GJN>O,9M-3//.*,_)3U+&]%,BAA*==)N`%$>:P+F*
M(W`.(`@BN?D-[]0MT]M;@T`FA('77U`K11M7L30224(J248@=,Y5"#VY+H8A
M@,4?_+_D$*]AC0:XV_K?U5ZH.8^7Z%D-DWE'N#)H^7C)/-F;9I/M182@XWBL
M0Q>NF`I&149+RAV,=*)MU4SB%DUC")1,41*4;&RLV<7LK7,DE&%XH<+!6G(D
MAI["KAUU,X$%VP\A_P!BH,)Y"[0QS#2X'#9Y+,L=2:.H]JD3'X)218L'IA.Y
M9L9E5526:(',8>/;6*9/H!!*```4X\TNHK?X:.5XBH0.ZVH!X`UJ.U>6W$C6
M>&UQP]0^=?&`W_M3&(>-Q[']D9+%PT4W!I'1[6)AP2;(=PZ@)DYJG4/=101N
M83&&_MKY%F=U#&(HII&QM%``UOTHVXD:T-:]P:.@?2HV?.\Y<KXZG_%V9F=X
MU*R;G&`1;&3=Q,S,N@=RIXPR,B1=)\^=K`=0"CR,8WLZU1^(F<6?B2XF.);L
MV@G::=[>2O/B/-.\ZH.S9N)]*\(O\PDX=:-$F?/L?E)U*67CBRDDXA9#)90Q
MFJ$BJS+&F8.IN0.D*2:HE,NJ)1*41M:O..5\>"DQB<ZM,1H7'96F&E3SWE?*
MN+:=["37?LKV;U[6"NPM>-%)V+:[.P=C(+FBU9AA(S>,M'SI`[HAHY20;QC)
M%RNBHV7`41.8Q13.%O=-;TTW%JWQ&-GC:32H<6@G;LKA'3LZT!?&,0#VCKIZ
ME3`5RF.>R,^5MG3"113!U+S82,BU>I(R+P697$C)!&$7(F^?E[0'5.`*K!QN
M)NE>*O8XRX90_>3BV[33:</$[.DKYM!+J.KU_P`2C9I0`<*NRIN5G;DRAW+I
M](NEW"IU1$5#"LU%@H8RPF$3B<5!,-O9UO1\1H.(`EQWU)/S8?EJO.(5K3;T
MG_L7Q,_(8B:9F#4R:7+M)F6E!(GS'D?ME&1XDYFZC;VC7SQ&[L#:=;OZR8AR
M'R_2IWGNT9;8JF*JST+CR*F(8=#81&&C4YIN*\1!BY,S5?>HFW8*OS"[/W#D
M[9#=+$"KFYOGW6#Q6,_#C#!3%N&ZO>W[5[DF,M,0&P4X[AZ5;\SE$Q3%".9D
M$Q1`#E/("8@B%@,4#OCD$Q?:%P$/G`:M2]I%,#?UOI5.HY#Y?I7CKPOBV3>&
M2M]=Y(A?]WFCI6WS=Z#@B7_7V/ZJB/S`;_\`%87<[<#L>_Z5.GE<ZN23LY71
M/;'']"R_K0U):Y.O+IMZ7R=WFE:W+9.2N;6`/[X^.\OT^?OWKN?0;\>C,L=_
M@XQV-IZER+K%N#5-^/\`$O/::^M8YUMJUI;O_A"N>4%O5I?]Q+:_<VO[/5,\
MM2O;Z?1_U5S=Y]LI=99)SCG'88CZU.ODXZMO?LY/A/:)/H6Y*N?%-2MILS3F
ML-QP_P!A[+PN$RQD4IRM59!MPDXT5`L=2(FFIF\O$+&^4[9=(Q@Z"(ATK,Y-
MJ#.M/W'Q.3W,D$G$-/==]IAJQPZ'`K%YIDN59U#X&:01S1\*CO-^RX4<T_9(
M7-KYJ:5UGH3<)\"UKD$W,-R0C&7FXZ;,S=*XP_E3K.&<*23;$;*/;Q8HN0!5
M$ITT5T[J*F,82]?>76H\YU1I\9IG$4<;S(6,<RH$C6T!?A-:=ZK=AH2T[&BB
MYEUQD>5Z?SG\ORR21[<`<YKJ'`7;0W$*5[M#M%0"-I6(=;ZM.2B+E'S;\9Y=
M^9Y_[U=UEE+:C%$2B+HF\$W'?\6=9`(W,@;,VYNHC]3/<H,0.OLLD<M8Z?\`
M:G^'!1WGHIFLOW?YC5ES5)8A;;_A'N^&R]M,;_WC!HAW;Y_1SY$;^WY/7U!/
MGO'7);&7W;IP_E1D_P!%3!Y//IFEY'SMVGL?3UK?%7,*G]:O?+M/AMHAO^^Q
M:&4_39>22_\`"J9="&N1TY3/^9I4`>93::C!YV[#\KAZEBY6YJ/THB41*(LR
M=4[2P7'\)Q#[<F$6&2,,C9X>^2!@^<.&F&-IB8S>/RE15JT6!5*(R:5(4I4S
M'=D%N44TQ`I:S]E>VT5O'XCJ2AX:=AV,J7AVP<''KV;`KR*6-L8Q&C@:>C?7
MM]*K;_96!++:KDWFPHR0F]:9SAF49,X4C\U=O<S^S,:P&-FW4)(GQE1-](&/
MC1T1/)*L16,ERY"42B-1UY;$PO=*#)#(QSMCZOHU@)!P[3W:=XBM%Z,L?<)<
M"YK@3OV[!6FSHXT7W8[PUUBV*M,6:S"\^I$0+-)I(1\5*M62L_`OL_S'&WC0
M)9FR>)$:9"YA6JAE$4S`!UQ+=(!.;ZW,;2&$0AQ<6M%"`0,32][2*@'8[`-W
M/@OHGB:S`#6@Y<14CY:*`;VVIA&?&BI''UTW3B-R&<?+,7^/.T';UH_SO.,D
M0`91=\JP^S3QV0H`=L=D*G>Y7.)0XC:YE>VUT6OBVD.)H6FI!>]V^M*4<-E-
MZIW$T<E"W@3PZ2?6O+LS>T7F0[(BXMO+1^,Y-!8VSQZ'0;LF$:G-165QD^]F
M9:,9N$&:;U1B5TV*Y(FNX.4$B&$"7$OR\S)EQXS&!PA>UH:-@%0X.)(&RM*B
MNT[E\EN`_$!7"0*#J-5B[6&5JE$2B)1$HBV*^%JM\2S)"_[O(VBMO_KHQ,E_
MU]BHH\PF_P#/6[N<1'8[^-3;Y6.KEMTSE.#VM'T+-"H^4I+E8\WFWI?*W=:5
MK<LJ2<VZ?XR%BGE^GS]^]=N^6[\>A\N/[@CL>X>I<FZZ;@U;?#]]7M:T^M8J
MUNZU);H/A`N>+O?[01_>M]8.2EZ_X=3/TCB'R!?U(7^?I7/'GXRK,JDY&Y';
MX!]2FWR;=W\Q9S$![/%^E;L:YR4Y*&;$SF#UG@N5Y_DBW9A<1@W\V^L8I5%R
MLT#'18MN70[R0<\$$"^TZRA2AU&LCE.67.<YG!E5F*W,\K6-Y"IVD]#15Q/`
M`E6.97\&5V$V8W)I!#&7'IH-@'230#I(7(CL#-YO9.;Y5GN2+=^;RV<D)R0,
M!C"DDJ^<'5(T;`<1%-FQ1$J*!/81%,I0Z!7>>59;;9/EL&5V8I;01-8WF<(I
M4]+CM)XDDKCK,;Z?,[Z7,+DUGFD+CZ3N'0!L`X``*)$(=0Y$TR&444,4A"$*
M)CG.80*4A"E`3&,8PV``ZB-7Y(`J=@"M`"30;UN?-\+.-_DJED)<AR<-PAK1
M>57Q0PQQH53/S&;336(2.#,KM%!%D5:)4()S@HY.1R!R`0R2G/`\[)O\QFT,
M4/\`E_XP-$O>Q^!M87G;0DFDH-!1H+*$D.$V_P#VHB_(Q<B27\Z^%+C'W</C
M;'!NZH`%8R*FKB'5%*'_`#I<V_&>7?F>?^]7==/+&*,41*(N@OX?KCO>,N*)
MWOZ2=R]O\O3ED+UU;K_M-^GSUC[C]J5'VH!3,WGFUOS!9J516%6POX<>X->:
M;VQG$YLO*66)P4CK=Y'MG[Y%ZX(XE$\EQQVDR12CVKQRHX.S17.4H$Z@F(>V
MP#%7FYD.:Z@R"WM<G@=/=,O6N+6D"C?#E!)+B!2I:-_%2-Y:YSEV2YQ/<9I*
MV&W=:D`D$U=C80!0$UH"=W!;?7/Q`O$%H!3*[C9G`XB`>FQ#83T0$`O[Q6>)
M+F('TF``&H!9Y5Z^D]G+W;.<L`^>4*9'>8FC6;3>M]$<Q^:,K7IY1>8OCQEN
MPV$OC.;N9:.)B\>P.[)BF7,BB[;R$JNJ0J,G!L7(E(DZ3#D*8`(WM>UQDS2>
MB-393ECK;,;<1S&9S@/$B=L(:-[7N&\'BHIUGFV6:@S=MYE,PDMVP-826O;W
M@YY.QS0=Q&VBQA5\J=0IE,))*9<"`V`J4&\*8X7]I>^")0#](@-;4--9L=[&
MC[P]55J?P_Z;?UOZJIBWEQJM(P`1MEC@!"XF1B&12A]`^HED#7_0`A50:6S,
M[S$/O'U`KSX!]YOR_0J4;S%UX!C`7'LS,4.7`PM(0HF$`'CR+]NFX@8?;U&P
M?/[*J_Y3S"G[2&O6[^J@AV[3L_AU+RJ^9&$``=G%LJ4&_O`K]D)``?)82R"U
MQ_HKT-)7W&2+];^J%[\"/BX_R1_65-6\S8`HG]/@\PJ`?NQ6EF2`FZ?VP(V<
M=OK\PFJHW2-Q]:9@Z@3]">`SWCV?Z2I"_FB'$OI==CRO[PKY2'$`^0"E3Q^X
MB/Z0M]/R5FZ0/UKCL9_I+R86\">S^,KR&\T7HVX:]:EZ=>63*FN;KU"T&2P?
M1U_37K_*#?\`U!_D?Z:]B*.FW%7K'T%4];S,R(Q1!#"85,]^AEI-\N4`^82D
M1;B(V^6]>QI&#ZTSB/L@>LK[X4/`.[1_55,6\Q\[,:[?&,22);ZJR<PN:_S\
MB2K<+?1:JHTE9T[TLI/W1ZBOGA1?I=H^A4H?+W:`B80C<,+RO8`BI:Q+C<./
M*>,(\?DY7^FJO^5,M]Z;^4W^JO@C8#M%?X="\ROEMM52W!+%D;7OVH=R/*]O
M;WI-7V6^2WMKZ-*Y8-YE/WA_57O#%[@[7?2J8MY3[@5Y\):);<_JBC!1YNW_
M`,SU":X#_P#.Y55;IG*AO:\];CZJ)AC]T=I^E4EQY*;H7XA_&'9`O6S>"QQ/
MD/\`RC?9(F&WS7M55NG<H;_95ZW/_K+Y@9P`';]*\AO(G<Q^HYNZ#H!?=BH`
MG0`L'0D24+_./M&O7^7\G_U(_E/_`*R]"@V`-[!]"N3KKRG\A<?;RK>"VSED
M.BX6:+.$XUT@R*LH4BZ9#J^G;)B<2EZ!>O+]'Z8OW8[VRAE<T4!<"Z@/*I7R
M3/<WRD!F63O@8\DN#*-J12A-!TJ:N?*_R7=&5,KO;:116`2G!MF4TS*`"7A^
MR(S=(%0&WRD`HWZ^WK51FAM'1T#<LLMG.)A[:@U]*M7:NU0\DG,+O;RD</F(
MIZ%96>R"?RJ7>Y!E$Y+Y)/21TU)&;GI)[,2[]1)%-NDH]DI!9P\='3;HD3*)
MSF$"$`H=``*V*UM+6Q@;:V4<<-JSV6,:&-;4U-&M``VDG8-YJL'<7-Q=S.N+
MJ1\MP[>Y[BYQV4VN)).P4VG<J/5PJ*W!?")<<<SW2TO^_P`8Q)Q;KU]+*RZ5
M_FZ>L_KJ`?/EE<ORZ3E-*.UK/H4R^3KJ7M\SG%&>QSOI6\^N:5/2TY?%9WAZ
M"%Q30D(\LYG3(9IG!43]2Q#%PHEC$0OQ$Q1*^E4%7BA#6.06;<WU3]>@?(_3
M?BW$^J+EO<BK##7WG"LCA]EI#`=QQO&\*%O-K/?#@AT_`[O24EEI[H-&-/6X
M%Q'#"T\5H[KI-02L[_AYZ/\`YO[\BIF59^HQ#5I6V:3@J)\VSJ70<"7$HA01
M`Q!,ZETO5&(<!*JW8K$'VA48^:^I/R#2[[>!U+^]K"SF&D?BO]#3AJ-H<]I6
M_P#ESD7YSJ!D\K:V=I25W(N!_#;Z7=ZG$-<%TQ5QRNH%_C[9M^,\N_,\_P#>
MKNOTJ7/:C%$2B+?C\.A?O>.:"=[^ES?*$/T<@C7-O]YO^NK"X_:>A:%J(4S'
MK8WUK.ZJ"P*41*(H/EH?MV8_.DJ']!RC_EJTN-X69RL]QXZ0HC5NLHE$2B)1
M$HB41*(E$2B)1$HB41*(E$4QQ$?>?A\Y6P_T"N'^6KFWX^A8G--S#U^I36KI
M8A*(O=&1LC,R+&(B&+N3E91VW81T<P;JNGK]\[5(@U:-&R!3K.'+A8Y2$(4!
M,8P@`!>J4TT5O$Z>=S60,:7.<X@!H`J22=@`&TDJI%%)/(V&%I=*\@-`%22=
M@``VDD[@NDWP6\1S^..(O<CRU85]H9RR9!/M&[CNQN,12)Q=-,<;BD84'T@F
MLIS>N0$Q!5`$T1%,@JK<@>9FO!JZ_;:6`IDMLXX"1WI''89#7:&TV,;OIM=M
M.%O36@M'G35FZYO#7-9VC&`>ZQHVA@IL)KM<[=78W8*NS=R*?B<4@)O)YYXG
M'PF.Q,A-R[Y7]VTC8MHJ]>N#_*((MD#&L'4;6"HWM+6>^NH[*U:7W,TC6,`X
MN<0`/22MZN;B&TMY+JX<&P1L+G'DUHJ3V!<C6Z]HRVZ-J9MLR8[A'&4S3AVT
M:*'[GV9#(`1E!1)3`/$Q8N';((7#ZXD$WM$:[QTYDL&G<DMLFMZ%D$8!/O/.
MU[OO/)=T5HN/<\S6;.\VGS2:N*5Y('NM&QC?NM`'HJK65FUB5T\^`^C_`.2V
M@8`\HS]-F&P^UG&4=U/@Z;$DFR?\/0RO(`53"+A.T*B1OW3M=?YQKC'S0U)_
MF+5,HA=7+[2L,?(X3^(\?:?6AXM#5U-Y?9%^2:>C,K:7MS^*_F,0[C?NMI4<
M'%RS8J.5O*_Q]LV_&>7?F>?^]7=?I4N>U&*(E$64OC-Y199X\Y!VR@O/:^EW
M2:F2XF98`L<0(D::@3JCVV,V@B0`&]DG9"`FK:R:B5*6(2#])8O,\KAS&.OL
MW`'==ZCS'S;QQ!Z",!S_`!/9V*QF985+MYJ!E4N:+A$>*S=<H%]0P?MC668R
M+,YN*J*@`<@_0("./<TM.%V]1]<6\UK*89P6R#^%1S'2IE7Q44HBA>7![S`?
MG*Y#^@4!_P`M6MQP]*R^5[G^CUJ&U;+++]`F<UK$.-_98HC?]%@ZTH5\Q`;R
M%]`;.#?5;K&M[;)'&W]!:^X7<BO)DC&]P[0KD0^DMS9"@P<P&H]G3C:5227C
M'$/@.52:$B@N0%$%F"K*)63>)+)CR(9,3`8O4.E8J?/,EM7.9<WEK&]A(<'2
MQM+2-A#@7"A'&JR,.69E<-:^"WG>QPJ"V-Y!!X@@&OH4O2\4_)]:_#QUWB''
MV]W56<-_Z._!I\OU7JR.KM*#?F=A_P#R(C_35R-/Y\?_`-E=_P#Z4G]56AE\
M6R.`E)"#G(22AYF(>.(Z5BI)HJRD8V0:*&1=L7S-P5-=H\:K$$BB2A2G3.42
MF`!`0J_CSC*I8Q+%<0NB<*@AX((.X@@[0>!"VBT\J?,J_@CN;3(LT?;RM#F.
M%O)A<T[002T"A&T'<1MW+P!%2`_X8WZS)A_\IZ'.,L;OF9\_S++P^1OFU.XM
M9D5Z"/>#&#M>]H*]3/'I5ZY;M$44$U7*R:"9WC^/8-B'5,!"F</'SINT:HE$
MWO**'(F0.IA``&J#\_RF,$NEK0<&//91IKZ%E&?].WG+)";@9)((P#L-Q:!V
MS]`W`>>@!M3PJLS<9^'%Y9YA&,IS',(Q>8@9%'OL)R+VGK&7B7:?L`S9[$9:
M_27`1Z7+<`$+"(5K$_F?HRV>8IKF1LS30M,$X(ZPZ,+3+GRYUC9SNM;VS=#<
ML-'->YC7`\BTNJ.Q31K\*OS#<$$ZN)XBR,!K`DZSN`.<P?YP"R7=I\?TF`?H
MJS?YMZ*::":9PZ(G^L!>&Z`U*14Q1CKD;ZB5+&7PB/*MTHB1>1U+&E4`!.L]
MR^:43;B(7XK!'8E(+&$!Z?LR'"_T=:LY/.72+`2UMX\C@(V[?Y4@':0KEGES
MJ!QH76[1TO=ZF%21+X-_DD(#W\_T>F-_=!*?SU8!#Y;B?7+?B/\`35J?.S2_
M"WO_`.1#_P",JP\M,\XS6G\J3_PU66_P:-Y&%+U>TM4(`-N\+<V7NA3^?M`K
MC;/O6^2_"]47>=VGQ7!:7A/"OAC_`+PT^55!Y9YM]:>V`^^?Z`4/V+\(_P`A
M\.BE9C&)S#]DD;D$[B(QY5['9#P*`F.HU83B+)B^(0H#[B;L7!QL!$C"-9+*
M/.#2V83BWOA/9D[G/:'1^ES"2WK+<(XN"L,S\OM064)FM!%=`;VL<6O]`<`#
MU!U3P!6!:N#SV!R\E"Y+'RD--M3E;OX>9BG<1),5DQ$W!TR?`FY1.(&O8Q"]
M.M2Y8RVUS"+JSE9-;/%6N80YI',.!(*BS,GSMD^&N8GPSL.UK@0X=8(!"^U7
MJQJ417Z\<]Z+>/.QV6Q&N$XSFSIJV69)M<A]8DYCD77$KIWCT@V4.C$3*J`"
MB#I1LZX(J'*!+'-?5]7:9;JS*'92^YFMF.<#6.A#B-PD:15[`=N$.;4@&NP+
M8--9\[3F9MS)D$4[P"*/J"*[RPCV74V8BUU`2*;5O_T?Y\:`W1Z.+//_`,O,
MP<B1+^&,X5;1I'3DU@[</D/<^PY/N*#Q23,J@[5'V(!>N6=2>5VJ=.XIA%\7
MEXV^)""Z@_3C]MO,FCFCWET-D7F#I[.\,1D^&O3]26C:G]%_LNZ!4./NJPOQ
M2-XAB&LH73D(\X3NS%@D<@!%2RK7"85TFH"1^(@HF$_.))ID,`\5$&CE,P6-
M6T>2NFOC\YDU!<MK:V8PLKN,SQ_0823R+F$;EK_FMGWP>5LR6!WX]T<3Z<(F
MG^FZ@Z0UP6@"NIESRLM/"G2'\]=^8K`R#3U.(XT?^,\TYDY-U82$70.C%+7#
MB<L]+*MV9RW`W854.7Z@UHOF+J3_`"SI>>ZB=2_F_"AYA[P:N'V&ASP=U0`=
MZV_0^1?G^H(;>05LXOQ)>6%I%&G[;J-/02>"ZG``````+`'0`#V`'S!7$JZO
M7]HOJ_Q]LV_&>7?F>?\`O5W7Z5+GM1BB)1$HBG&)[,V+@3:0:81G66XBVE3I
M*2*.-Y!*0I'BJ!3D166".=-^2R1#B!3_`%@`;7M7DM:[V@"J$MM;3D&>-CR-
MV(`_.JVXWGNUWP]7N+:;KM\NWZC8.6K<.5N7#N2YN/+B%[>VU,#.0[%X%C9#
M=#$/N-^A49QM#9;H5#.MB9TY,L`E6,XRV?6%4!+Q$%!4D#"<!+T&]^E,#.0[
M%[%K;#='&/NCZ%1U,ORU4@I*Y1D2B1C%,*:DW)'()B7XF$AG(E$Q>0V'Y+U]
MPM.\!>Q%$-S6CT!;U/`?53O"M1ESK(?4+95M$[::,L^456=M<3:%53QAGW%S
M'.";Q)=5^`E&QDW:8"%R583N!?A&X+1<_NQ/=^!'^RBV?>/M?1Z"LZ:HK!*^
M7C?IY[O;<V$ZX0*N6.E9,KS)GB'(#1V*Q0>NGW8*@4Q4%S,$3(MS&L4SI9(G
MM,%:UJ[/X],Z>N<X?3Q8V4C!^M*[NL%.(Q$%U-H:''@L]IG)9,_SN#+&U\-[
MJO(^K&W:\]!IL'Z1`XKK3CV#**8,HN-:H,8Z-:-F#!DV3*DV:,F:)&[5JW2*
M`%30;H)E(0H=`*`!7"DLLD\KIYG%TSW%SB=I))J23Q).TKKZ.-D,;8H@&QM`
M``W``4`'0`K(>36YV>@]*9MLA8Z`RD='#'8JS7XF+(9;+790+;M#U701=J>I
M<%#J#5!4W]FLGD>6.S?-(K(5\-SJO/)@VN/9L'20MIT=IZ34^HK;*&U\%[\4
MA'U8F[7FO`D=UOZ3FA<C+]^]E'SV3D72SV0D7;E^_>N5#*N';UXL=PZ=.%3B
M)E%G"ZACG,/43"(UT.QC8V"-@`8T``#<`-P7=<44<,3886AL3&AK0-@``H`!
MR`V!>2O2]I1%=C56\ML:2EOMC6.<3>++**%5>,6JY7,'*"0`*`2\`^(YAI.Q
M`L45D#G('U!*/6L??Y5E^:1^'?1-D'`G8X=3A1P]!6#SO3>1ZB@^'SFVCF:!
ML)%'M^R\4>WT$`\:K;]HOXLD#(^C@]_8F?'G8]M$V<X6@YD(0YNA1<2^,*J.
M)B.(4I>1SLE7PG.;W4$R^R.<U\OIF5ERB3&WW'T#NH.W'[P;UE0/J7R/NH<5
MSI>?Q6;_``9B&OZFR`!KN@/#*#>XE;8\%V)@NS8-')=?Y9!9?!K\0!_!2#=\
MFBJ8O(6SU)(XKQ[T@?707(FL0>AB@-1_=V=W8RF"\C?'*.#A3TCF.D5"@_,L
MIS+)[DV>:02P7(^J]I%1S'!PY$$@\"IG5JL>E$2B*U&U-':HW5%?9.S,)A<G
M333,DSD'"!FLY%@81,(Q4^Q.VF(X!./(Q4EBD.(>^4P=*SF2:ESS3D_CY-<R
M0DG:T&K'?:8:L=Z14<"%B,VR'*,\B\'-(&2BFPD4<W[+Q1S?0:'BM1F\/A3Y
M!&>LF]"Y47(VA>XL7",R7:Q\X0O4P-XG)4DV\-(G$PV(1XFP`A"^\LH:IYTW
MYX6LV&VU1!X+]WC1`N9UNCVO;TEA?4[F@*'<]\I;B+%/I^7Q6;_"D(#NIK]C
M7=3@S[16JC-M?YMK:;7QO/<5G,2FT+B:/G8]PP553`W$'+0ZQ`1?,U/:1=$R
MB*@=2F$.M3?EN:Y;G%L+S*YXI[8_68X.`Z#3:T\P:$<0HEOLNOLLG-MF$4D,
MXX/!'I%=XY$5!X%0^L@K-*(JC(2\M+^B&6E)&3&-8(Q<=]H/7+WT$8V.JHWC
MF7J55?2L$%%SF(B3BF4QS"``(C5&*W@@Q>`QC,;BYV$`8G&E7&F]QH*D[30*
MI)---A\9[GX6AHJ2:-&X"NX"IH!LVJG565-='OPU]'_RQT<GG,NT[.5;=5;9
M&H*B?%=IB+4BJ6),A$0OQ>(.%I&X#[Q'J8&"Y*Y%\X-2?G.I3ED#JV-@#'T&
M4T\4^@@1];#3>NEO+'(ORK(1?S-I=WA#^D1C]F/2"7]3AR6Q2HE4DK"5QY-0
MJWFY$Z%)*E1C8[6611[@"'+Z:1V;,O,7RAE&KG$W:`\-AL"N")@'D+I^HB(<
M@"I'9HVY;Y<2:H+*S/O8W#FVW8)(RX<>_,]M?T6!VY:*[5,#M=,T^'TB;:O!
MY&=Q9(&G[,;#3])Y;O7^6AFWXSR[\SS_`-ZNZ[C4:J,41*(E$2B)1$HBO7X\
MZH<[HVYB."D(K]ENWP2.2N$N119XS%V=S"O=+U15<($!LB;V>H73#Y:\2/P,
M+N*LLPNQ96CY_K`4;]H[OI/0%TVM6K9BU;,F:"35HS01:M6R!"I(-VS=,J2"
M"*9``B:2*1`*4H!8`"P5C%&1)<2YVTE?>B^+?C\+#1_\+Z_G]VS3,"3.PEE(
M+%S*D`%6V&0KP0?.4C"`*)EG\B;"!RB%C)QR)RC8]<O>=NI/C,TBTW;N_P"7
MM`'RTW&5X[H/V(SL/.1P.Y=!>4^1?"Y=)GL[?Q[DX(^B-IVG[[QV,:>*VP5!
MBEU<^7Q4][?QALN%TK!O.Y`:S2+)Y(")[HO,WFFA#D14XB9-4<>@EB)E$!`Q
M%WKE,P7+TF#0.4_#6+LSE'XL^QO0QI_I.^1K2NI?)337P&3R:AN6TNKPX8Z[
MQ"P[_OO!/2&,(WK5!4@*;THB41*(E$4SP78F=:RG$<EU_ED[B$XAQ`'\%(.&
M*BR13<A;/4DC@A(,CC]=!<BB)PZ&*(5;7=G:7T1@O(V21'@X5](Y'I%"L?F6
M4Y;G%L;/-((I[8_5>T&AYCBT\B"".!6V/1?Q9)Z.]'![^Q,F0M`[:)LYPM!M
M'S9"]"BXE\854;P\B<QC<CG9*L0(0ONH*&]L?9KY?0OK+E$F!WN/J6]0=O'W
M@[K"@_4OD?:S8KG2\_A/W^#,2YG4V0`N;T!X?4[W`+;]JK>6I]VQ/VQK'.(3
M*44TRJO&+5<S:<BP.(%`)>`?$;3,9<XV**R!"''Z@F#K4<W^59AE<GAWT3HS
MP)VM/4X5:?05`V=Z;SS3L_P^<VTD+B=A(JQWV7BK'>@DCC178K'K")1$HBAF
M=:[P79L(KCFP,3@LNA51,8&,Y'H/2MU3%X^I8K'+ZF/>%+]5=`Z:Q/[)@K(Y
M9FV9Y-<B[RJ>6"X'UF.(J.1&YPZ'`@\E8W^6V&:0&VS&&.:`\'`&G2#O!Z00
M>E:I-X?"FAGWK)O0>5F@W`\UBX/FB[A[$F'J;L1&4))KRC(I2AQ33>I/!.<;
MG<$+[)QTWYX7$6&VU1!XC-WC0@!W6^,D-/26%E!N82HDS[RE@DQ3Z?F\-W^J
ME)+>ILFUPZ`X.KQ<%J.VCI3:>F);[&V9A,WBS@ZATFCMXW!>&DQ3N)C1$ZS.
MYAY4I2A<>PNH)?[0`/2IWR74>2:B@^(R:YCG8!M`-'M^TPT>W[P%>"A_-<CS
M;))O!S2!\3J["15KOLO%6N]!/2K6UFUB5?\`\8=,N=\[LPO7H)K##.GX2V6N
M4N1198E#B5Y-J=T@W05>(E!H@?V`Y<I_/6K:SU"S3&G+G-:CXAK<,0/&5^QF
MSB`>\X>ZTK8=+9([4&>09=0^"78I#RC;M=U5'='Z1"ZRFC1LP:MF+)NBT9LV
MZ+1HU;IE20;-FZ944&Z"1``B:**1`*4H```4``*X7>]\KS)(2Z1Q)).TDG:2
M3S)77C&-C8(V`!C0``-P`W`=2MYN+9D/IW6.:;*G!(9EB<(YD$FIE`3&2DS\
M6L-$)''ZJTO+N$&Q!^0RMQZ`-9;3^37&H,YM\GMOVD\@:3[K=[W'H:T%QZEC
M<ZS2')<KGS.?V(8R:>\[<UO6YQ#?2N3/^9&8?S(_FS]K*_QS_&'\=?;'7G_$
M?VM]M>JX<OW7KNO;OQX>[[*[H_*+#\H_(O#'Y9\/X.#]WAP4ZZ<>>U<A_F=[
M^9_F^,_'^-XN+]/%BKV\.6Q<AN;?C/+OS//_`'J[K:5)BC%$2B)1$HB41*(M
MW/PX=/?POK^7VQ+->$SL!48^",J2RK;$8AR<AE4[@!TPFYE(YS`-P.DT0.4;
M&JRN7U=@&X+2-1WGBW`M&'N1[3]H_0/G*V35;+6U<G3^M)G<.S<+UI`@8K_+
M9QM''<E3[I8V.+R=3,NJF`E$Z$/$-UW2@`-Q(D(!U$*Q&?9Q;Y!DUQG%U^RM
MXBZF[$[<Q@/`O>6M'25D\FRN;.<T@RNW_:32!M?=;O<[J:T%QZEUTXMC4-AF
M-0&(X\T*Q@L9AHV!AV91OZ>.BFB3)HF8]@%10$40Y''J<US#U$:X,OKRXS&\
MEO[MV*ZFD<]YYN<23U;3L'#<NQ+2UALK6.SMAAMXF-8T<FM%!\@4&WEM:(TE
MJ?-]G3':41Q>%7<L&2A^`2LXY$C*`B"B`@<!DYARBB8Q;B0AS']A1JME67R9
MIF$5C'OD=0GDT;7'T`$K8]-Y)/J//+;)K>H=-(`X^ZP;7N^ZP$])%.*Y!,CR
M"7RS()S*)]XI(SF1RTC.3#]8;JO).5=JOGSD_P`@&6<KF-8.@7L%=&0PQV\+
M((1AB8T-`Y`"@'8N\;2U@L;6.RM6AEM%&UC&C@UH``]`"HU5%<)1$HBRTT+X
MVXYLK5FZ=W[2V6XU#JO4X8EC;'(F^&JYN^S':6=R*B6.8/#PJ<]CAUB-H.-?
MR<HY16658,FY3^G5[A2UD[*PCN+:6[N)/"MHL(KAQ8GN.QH%1P!)/`#<5I&I
M=6W>49SE^G<FM!?9U>^+(8S*(1%;PM_$F<_!)2KW,CC:0`][B,0H2J"MXH[8
ME7$4MJUM$;UQF>FX7'XK,-.O'641:,MD<DWAX%AED*Y816;:U>RTFZ31;HY-
M%0ZBYS72!0MC#X.6W+B#;TFC<0`YFT5)H*B@<RIW8PVO!7+=:Y)"U[<Y,F6W
MD<;WNBN@(W88VESS&\%T,X:T$N-O)*&CVJ'8K=[MU:\TCMO8>H9+)<:R^4UQ
ME,IB$MD.'N'SO''LO"KBSE4HUS),(UXJ$?(IJME1,B4O>1/P$Y.)S4+NW-I<
MOM7.:YT;BTENZHWTJ!N.Q973V<QZBR.USV*&:"&[A;*UDH`D#7BK<0:YP&)M
M'#;N(K0U`_D;K%TZU)DVVY236@8N,RN%PW$FK[%LN78;"GG#=60RR*@,P8PS
MG#6,Q@D.XCWKYD_>MG2S622.@12QP`VW)MG7+CA:'!K=CJ..]P#J806BA()!
MH11)LX8S/(<CA8)9GP/EE(DB#H&`X8W/B+Q*6S.#V,>QCFAT;@XC8H-`Y#/8
MK+,Y[&)N6QV<CU0683$'(NXJ39*AT[C5\Q60<H'MTN4P7"K*:&*XC,,[6OB=
MO#@"#U@[%D;JUM;V!UM>1LEMGBCFO:'-(Z6D$%;/M&?%1VGA?HX7<D.WVACZ
M?;1&?9>F@\X9H%L7N**))$A,@%),H6(LDU75-<RCD1&M%S70-A<UERUQ@F]T
MU<P_TF^@D#@U0WJ7R5R7,,5QI^0V5T=N`U?"3Z>^RO,%S1P8MQ^E?*C1V_6R
M7\O<V8KSAD>\YPZ:$L+E[,"EY+`:$=G!1^DW#]XNR,Z;%$0#NWJ-LSR#-<H=
M_P`Y$1%P>WO,/WANZG4/0H!U#HK4FEWG\UMW"VK02L[\1Y=\>R3P#PUW0LAZ
MPRU5*(E$5&G\=@,KB7D#E$)$Y%!R"8I/HB<CFDK&.TQ_L.6+Y)=LL`#U#D4;
M#U"KBUN[JQG;=64DD-RPU:]CBUPZB""%0N+:WNX76]U&R2!PVM<`YIZP:A:Q
MMX?"VUGE_K)K3<TOK2=4YJEQZ1%U-X2[6&YNVD*BBL[``H<PB)TU'B)"@!4V
MQ0J9M-^=><V&&WU#&+RU&SQ&T9,!T[F/ZB&$[R\J+<]\J<KO,4^2O-K<>XZK
MHB?Y[/07`<&A3[P%\2<B\=([/)_8K6,+GV2298)B>,?(R;1MAT3VW"2[-XD!
M%"!D,HJ955)0A%"IM&_,I#\BAB_-'7=IJV:UM<H<_P#*X68W8@6DRNV$$'_5
MMV`@D5<^A(H5D/+W1]SIN.XN,R#?S"5V`82'`1MVU!_3=M(-#1K:@%;%*B52
M2M(_Q6MX>I?XGH.$>72C@0S;.2HJ>U\X250Q6'7X"!@%LR56>JI&N4WJ&IPZ
ME"NC_(_3>"*?5%RWO/K##7D"#*\=9HP$>Z\<5!?FWGV*2'3T#MC:2RTYG9&T
M]0JXCI8>"TS5T*H47*/FWXSR[\SS_P!ZNZRREM1BB)1$HB41*(KC:DUU*;9V
M/B.OHGF1QDDN@T<NB$Y_9T4D!G4Q*&*/0Q8V*066L/UA)Q]HA7E[@QI<>"MK
MNX;:6S[A^YH[3P'I-`NH.!@XO&8.'QR$:D8P\#&,8>+9I_4:Q\:V29M$"_*(
M)H(E"X]1M<:Q9))J=ZC"1[I9'2/-7N))ZRJM1>%NU^%+H_L,\MW[-L[*/17P
M?!163&X-$5$7&5S*',HE$%W1$&**I!`Q10=ICT,-<Y>>.I<3X-+6SMC:334Y
MFHB8>H8GD'G&>"G+RDR+"R;4,[=KJQ15Y"AD<.LT:".3QQ6YRN>%-JT1_%AW
MM]JY'B^@8)Y=EC!6^8YR5%3W5,@D6AR8U$N`*(&`T9"N5'9R#<A_7HC]9/I*
M_E]E/APR9O*.])W&?9![Q]+@!]T\UTMY'Z:\"TFU1<M_$FK%#7W&G\1P^T\!
MH.\8'<"M-]22I^58^U?5>[+M_M+_`-;[OIY8OR_^8]M;U5^)2_ZTFYX)%XI]
MN]ZJ8Z^V*]/'M^FO116OPOA[;5WA_HTJS^344XGN%E2:NQ;D^S6[K_RI[ZM0
M.GHWB)(Y^H/SM4O4NFKOF8Q2$337%RH<1`J(@'(6`'V#4\CL/K![:]"?$/C_
M`/-,PM]YIQ-'6:-+>))+<`&]U=BI2B:B*ATE2'252.9-5)0IB*)J$,)3D.0P
M`8AR&`0$!"X#7@@@T.]7+7->T.:06D5!&XCF%F9C&Q'>$8.\P+7\YCVX=+N(
M/`<_VEJ/:\0Z'%Y7=DR8N).6.N6K0,=SR.RZ+CI$4$Y?'WT9(JQS9T4SI1L4
M$U,K'.883#`6RVE&N>QXV&0]WN[G!P!]II!H#MHM!O,J9F.8MS/-(Y;#4`DF
MAM[FV</$;:-_%!G)QPNB<YM3%.R1@D<PA@>:C*+Q8SOQT\;M_P`_GK>5V5HC
MR!Q>)R36.#:\SA>$S#5V%;7V"(:W7SW)-O0LE!NC8#K1A/OI9["R<&H<A&:9
M?M1XJ4;Y#+IK&PO73`R0WK06-:ZCF->[NXB\$=U@)):6\/:)6FZSRW5>K-,1
M98YEIF6F)GQW$T\(?%<2VT'XXACM7M>/&N',9&R6.8`EY/@QM*P8VSHK:NK=
MXK8$1/(<HFYC/GC#56PHEJ_39;F*?*3Q>,9_KB=(Y=H9#'Y<^,BY9NV;QS^U
M7*45>X`VQ%S9W-O>>#WG/+Z,<*_B;:!S3Q#MX()4CY)J3)<YTX,S)BAMX[8.
MN8'%M;7\/%)#.R@+'1"K7-<UNP5I1;A/./4VA]?:BB<LWM';!S.>A)S&/&^/
MRC5600N&CLG?>"P+R9\I/(?*#R&)SN.YHY@<I>,L)0*Y1:2\NM`._4/Q$I'2
M&T9O;64%J)+P/>\$1`L(;BD:*S2FK2'4-(]M'.PFKN(@CRZSO4N:9Z^RTV^U
MM[:2.2_='<L?+X%G,\,RZQCPR,DB#XP^[.$NBB$S,$6TL=J-<^-ZV814]E'C
MUF3'=L!C4')95D>-)1I\/W-AV,0Z/J9:9R;5T@_DAE(V(:@*SU[B\GDL<Q0L
MHZ<(=2EU@V!E:Z2Q>)F-!)%,,C0-Y+#6H'$L+P!O(4XLU8VPFBL]4V[LNN9I
M&QQR%WBVLLCC1K([AH;A<X[&LN([=[SL8UV\XQUCUN"^[9TY9.$'C-PNT=M5
M4UVSILJH@X;KI&`Z2R"Z1B*I*IG`!*8H@("%PKXYK7-+7`%IW@[EY>QDC#'(
M`YCA0@BH(.\$'>%L1T7\2[>^K/1Q&;K)[@Q-#MIBAD[I1OES5N6P"#',4TG+
MIT?Y1&11?F'V%,0/9IN:Z(RF_K):CX:X/NCN'K9L`^Z6^E13J3R@TSG6*?+@
M;"^/&,5B)Z8J@#_=EG45N5T9YQ>/^^/1QL)E1,4S!R"9/X*S86\),+.3V+V(
MAT9=6'GS'.`\"-'"C@2!R.D3V!&N:Z6S?*:OEC\2V'UV5<*=(WM](ITE<_ZD
M\N-4Z9Q2W$'CV#?[:&KV`<W"F)G27-#:[`XK+^M<6AI1$HB4113.<QA->X;D
M^<Y&X]-!XG!R,])J@)>X+:.;*.#(-RF$H*NW1B`DB0.JBIRE#J(5?99E]SFV
M80Y;:"MS/*UC>MQI4]`WD\`"59W][!EUE+?W)I!#&Y[NIHK0=)W`<30+D2V9
MG\WM//\`+MAY$ISF,OG7TRZ(!S*)M$W*H@SC6QC^]Z.*8D3;(`/4J*10^2N\
M\FRNVR3*K?*;04M[>(,'33>X]+G5<>DE<=YIF$^;9C-F5R?QII"X]%=S1T-%
M&CH`4&K)JP7*/FWXSR[\SS_WJ[K+*6U&*(E$2B)1$HBW"_#4T]Z.+R7=<PUL
MO+&6Q+#C*DZEC6BR:N1RB'(!*)7<@BDT(<MC%%JN7ZI^MG<OVA@6GZEO*O;9
M,.P=YW7P'9M](6UJK5:HI3A&'S>P<PQG!\;;^JG<KFXV!BT1Y`GZN2=)MDU7
M!RE,*+1OW!464$.*:1#&'H`U99C?VV56$V97APVL$;GN/0T5-.9.X#B:!7=C
M93YC>Q6%L*W$TC6-'2XTV\@-Y/`5*Z[=8Z_A-5:^Q#76.D`L1B$$RAFZ@ID2
M4>JH)\GTFY(G[GK99^=5TN(=#++&'Y:X,SK-;G/,VN,WN_V]Q*7D5J&@^RT5
M^JQM&MZ`%V)E67093ET.6VW[&&,-'33>X]+C5QZ24V=L&#U3K[,-C9(IPAL/
M@GTTZ(!RIJO%&Z0@RC&QC@)?6RKXZ39`!Z&65*'RU;6-G+F%Y'90?M9'AHZ*
M[R>@"I/0%L6397<YWFMOE-H/^8N)0P=%=[CT-;5QZ`5Q]YYFL[L?-,HSS)G'
MJI[+9R1GI-4.7;*XD')UQ;MRF$PI,VA#`DBF`V32(4H=`"NC;2UBLK6.T@%(
M8V!HZ@./2=YYE=Z99EUME.7PY99C#;01M8WJ:*5/,G>3Q))5!)&N5FPNFP$=
M$3(HHY3;G!1RS(D)A44<M>C@C8B8%,*X%,@',I1.![E"[#"1B&WU>CU[E7=<
M1LD\*2K22`"=@=7<`[=6M1AJ';":4H3X*\*NE$553E5#)D;R"1))LF0J20.#
M&*\:I$*!"$9/R_ZP@1!/EVT3]UJ4QN0HF&O8>:4=M'R^@^K=T*V=;-#C)`3'
M(34T]DG])NXU.]PH\@4#PO6S[:;MK(8_*.8>59.4'C(KIZ5B[:.VJI5FSJ-G
MT?1MR.6RB/>`Z@,C)FXE3%0_6O0`J'1FCAS-.P[!VTZ*JG(YX8Z*\C$D#@02
MUN($'80Z,XC0UI1OB5VEV$*;N-L9VWUM/Z>D2QQX&>SMIL67=2N/L%LT-D9(
MU5DXOE;QL;(4XR824;KNFIEA267:(*@`&[@J53<S"!UJZF`OQ&H[U:<]]#L)
M'0"K%F2Y9)FT6?P%WQ$=L8&!LA\'P\51^&#X>)A#FM=2H#G-Y4R.\?=P;'U(
M&.O=!;W:X;+XG@N4[BS>,V.K%2^NFN=8O*RY<?BL'P/,L-F(5]LP8%%@+%\W
M2=N_5/#]ATW*BJ`7UE=3VV$V4V!S6%[@ZA;B!-`UKFD8Z4H14U.PBBU35&0Y
M3GGBQZFRTW$$]S':PN@#FSF&1K<;IIHI6O%OC+\;'%K<+!B8\N"OG-^6DWL2
M-UAB61[%G?'',L#T]ANOW4!ED.&U_&#<,3("\S]+,]L84K$Y+(Q64YZ[R\TI
M(K/8+,47C]P"QACBDLG>/S-\[8XI)'02LB:VCACB>#WL3VT)!=BJ:M?4FO=6
MN6^B+?*IKR^M+2+-K"YOY9@^)WPV86KFT@,5M*'1M='"(O#C#)K4L8W"/%K4
MYH>*.N,9PQCD>6Y?J#4>OHG<F#9\;;FU=,^0$/L7#H?Q/T\MC&9;W?8WKIA(
MYJ^PZ0WFHM&X:0PY&`IK2BR"$7%@F"2^5RV".(.EEBB8V5CL;XY`YHA91TE&
M@NPF38SVN)`:W<8_UKFUY?R16-A?WUU/87,/PUM=63H)79E="2*S$D[FQ"5M
MG22Z/X&T1M<Z::N)N&".P=C>?$IY59]FVH\4SUO%P$C):MC<:QR%Q_9>)9UF
M4R6'U!K77V08NG`S^?H0./L'SW^'Y-.<*ZAL??F:-T7J@.`Q0GGSIUS--$UX
M#26``![7.-&,:10NH*G"<56M=0`[5(#LKRKRSAR7+,NOIK9SY6MN'22/?;RP
MQ,Q74\[),;(2]Y8SQXS"6RS18W.C&%:LI"/?Q+YY%RK%Y&2<>Y69OXZ0;+,G
MS%VW4,DX:O&CDB;ALY05*)3D.4IBF`0$`&M=<US26N!#AO!4RQ2Q3QMFA<U\
M+@"US2""#M!!&P@\"%XZ\JHE$6;&B_/KR#TCZ.+)D7\P,-;<$_X3SI1S*E;-
MBV+VH:>[H3L/VD@LBF"RK-,>HMS>RM8S72.3YI5^#P;D_790;?TF^R>G8#TJ
M.]2^6&EM1XIC%\+F!_M8:-J>;V4P.Z30//O!;EM%_$;T!M_T<3D$D?4^8..V
MD,/F;I!."=.3V`4XG,2%1B5R"<P%(#TL>NH<;$2-[:C7-=%YOEU9(6_$6PXL
M'>`Z6;_Y.(#B5S_J3RFU1D.*>U9\=8#Z\0.,#]*+:X=.#&`-[@L^DU$UDTUD
M5"*I*D*HDJF8ITU$SE`Q%$SE$2G(<H@("`B`@-:B00:'>HP(+26N%'!?2OB^
M+4'\5;>'V-BV,:(A'?%_EIT,NS,J2EC)XW%NSDQ^,7*`B`DEIUL=R(#8Q?LX
MGR'J?/)#37Q%[-J>Y;^%`#%#7_6.'?</LL(;_O#R4-^;6>^!:19!`[\2:DDG
MV&GN-/VG@N^X.:T55TPH$2B+E'S;\9Y=^9Y_[U=UEE+:C%$2B)1$HBE&$XC,
M9]EV-X7`(]^8R>88PS$H@84TU7JY$C.7`E`13:-$Q,JL?V$2(8P]`KXXAH+C
MN"I3S,MX732>PUI)]"ZBL#PR'UWAF,X/`)]N)Q>&91#01*4JBX-42E6>N`+[
MIG;]P)UUC?VE5##\M8MSBXEQWE1?<3/N)G3R>VYQ/\7HW*6U\5%;>/A4Z/\`
MMO+<GWM-,^4?AZ:V)X:=4ER*9/+,RGGY%`UP$%(?'W1&_4!*;[2-;WD^D#>=
M^I/AK"'3-N[\:X(EEI_JV'N-/0^0%W1X?(J8O*7(O'O)<_G;^'"#'']MP[[A
M]EAI]_H6]FN9%/JTI_%DWMV6N)^/L$]L=WZ?.,]!!3V-DE%D,3A''`1`06<D
M6?JI&L8O::*!T,%2=Y?935TF<2C8*LCZ_KN[*-!Z7!=#^1VFL3Y]4W+=C:PP
MUYFAE>.H48".;PM']2DNC5^TU%$5"*I'.DJD<JB2J9C$434(8#$.0Y1`Q#D,
M`"`@-P&OH)!J-Z^.:U[2UP!:10@[B.16Q'16NM/P?CAGOD+Y.XO*9C`S^21&
MN]81L5)JP>7OGY'8K9'D$-,%603?N&*;8Y4?6BNB5.+=(<0*I:L[9PVK;!]]
MF+2]CG!K*&CJ\2#Q]-=Q"BG4>9Y[/JRVTMHV9EO<Q0NGN"YN.(-I2-CF4.$$
MFIP823(QVTA6;\I/'2-TGFN-,\&G)/)\2S_!8+8N*-9YJW8YO&PT^=XDC%3T
M8UXH/I)H=BH911F4Q03ZJ$3XC>TS&P;:2M$!+HGL#@#L<`>!'$]7IHL_H[5L
MN?Y?-)F<;(+VUN7P2.82Z%SV4JYCS[+344#Z5.QI<L7I"+DXE5)"5CG\8NLV
M1>(HR#1PR55:.2\V[I)-RFF=1LX(%R'`!*<.H"-8YS7,-'`@]*W.*>&X;C@>
MU[`2*M((J-XJ*[1Q"\%>5552;RKM!(C8_9=M"<@(T?().TDB*&,=<C4RI17C
M_4"8>9FQT5##8>7(I1#V'N`IO;R.WLY>BBMWVT3W&05;*?K-):33=BIL=3@'
MAPX4H2#]NS&/NK97[,=&_P`*\.*C!4X_V6LA;N-.:AP*1-R44TR%$RCH1K[1
MCMVQW([NWAZ?25YQW$/[0>)'[S=CAUMW.V;26;231L:FO\Q\\BH#.,4D7AGS
M;8Z.'ER&2FTBS$V[CL)56_AU.&R!\9TY:QI4^*/-L<2+-42(@;L@)!J^/.QC
MXG;1)AJ3M-&[J'EU<-FY6`RO*[BYM[Z`!KK0RX&L.%@=*!XF.,4!=QHX5#B7
M$8MJN1C;V%S[)LDC,2S1MH!ALY]F#;+81?*'L%K:,UGC<3&9C!060.BK-E,U
M>S^21`@DP!%-#[39-S-F8&702;5XRR:1S8G^`V0NQ"M&!@`<`?>J1NY@4&T`
M8N[CN,LLXIKZW.9R6;8C$\1A\[KB1SHGO8*'P@R-VU]2?#>X/DHUSG_TS/(8
M;$O'W7FUHM[K#3V9Y<OM5?,6+%5_D.2XQDTS$X5*9\:)3=+.9%OB,'BSE.$;
M"BD!C*.U$0-ZTYSJ/9%!!<@QVKW8\6\D$AI=3CA`.$==-Z^"2UN+[-,UR5[;
MS/K>`6PB)#61R1L=*V'%0!IE?(TS.J=S`ZGA@"H>:6^(WR/\D=B[.QUFK'X2
MJZB\2URR=E4^TDM<X%#,,-PA:96<BH^=3LACT*@Z>G<*++>J74*)Q*4MO6;7
MC;^_DN&"D-0UO/"T!K:])`J:\52\O]-2Z3TG:9/=.#\P#72SD>R9YGNEF#`-
M@8U[RU@:`,(!I4E8LUC5N:41*(O2S9NI!VU8,6ZSQ\^<H,V;1NF99PZ=.52H
MMVZ"1`$ZJRZQP*4H`(F,(`%?'.:QI>\@-`J2>`'%>))&11NED(;&T$DG8`!M
M))X`#>NNWQHU*;1^C]?:W<KJ.I6$A4U\@<'<'<D-D,JHI)S2+50YSE]`R?.C
MMVP%L4$$B=+WKG;/,Q_-<TFO6BD;G=W93NC8VO20*GI)7">L,]&H]1W6;L`;
M!))1@I3N-[K"?TB`'._2)5XYJ9C,=AI;()IXE'P\'&OIB6?KB)4&4;&M57KY
MVL(`(@DW:HF.;Z`K'VUO-=W$=K;M+[B5[6-:-Y<X@-`Z22`M5GFBMH7W$[@V
M&-I<XG<&M%23U`57(_OG;$GN[;>;[+DNZF&1S"IXEDL8#&B\>9%*QQ^+L413
M`[*);)%4$M@46YGM<PUW?IC(X=-Y%;9/#0^#&,1'UI#WGN]+B2*[A0<%Q]J#
M-Y<]SB?-):CQ']T>ZP;&-]#0*\S4\5:&L^L,HPOET.AFD9@9EN4_*8O.9<FW
M()3=B'@I;'8999P`#R3]4]R-,J-PL?LJV^H-?:'#BX5540O,)G_LPX-])!/S
M#;Z%RW9M^,\N_,\_]ZNZRJE91BB)1$HB41;4/AJZ>^T9W)-TR[4#-<?*MBF(
MF5)<#33YL12?DD1$`$IH^)<)MBF"Y3>M5#H)*M;E]`&#BM5U+>88VV3#M=WG
M=0W#TG;Z`MQ]6:TY>EFT7?O&K%L!#.7KE!HW*HJD@F9=RJ5%(#KKG301(*AP
MN<YBE*'41`.M>)'MB8Z1_L-!)V$[!M.P;3U#:O3&.D>(V^TX@#AM.S>=@]*Z
MY/'_`%7$:7T]@FNH=5L[)!PC<\E)M!`Z$S/20FDIV725ZF4;OY1VJ="XFX-^
MV0!XE"N#]59W/J+4%UF\X+3+*<+3O8QO=8PCFUH`=S=4[RNP].Y3#D>36^6P
MD$1QC$X;G/=WGNZBXDCD*#@K@9AE<)@F*9'FF2.@90.*PLE/2[H;"9)A%M%7
MCCM$$Q>ZN=-(2ID`>2B@@4.HA6%MK>6[N&6T`K-(X-`Z2:?]JV6PL;C,KV'+
M[1N*ZGD:QHYN<0!Z-NT\!M7']MW94WN'9>9[+R$QOM/+YQU*"W%0521S&Y6\
M3$(',`"9K#Q2"+5(1ZBFB%^MZZ,RZQBRVQBL8?8C8!UGB>LFI/6N\\BRBWR#
M)[?)[7]C!&&U]X[W./2]Q+CTE01IZ`>X1]ZPG/AVG+3LJ]CCR$_<9+=GU?=Z
M%"SA'M]3>_\`5J_;A^M7T?1Q[0LC+XXH8<!IO#JBO4X5PTW^RZN[9O7M"([H
M@JT<D>L2B!W*S=,YGC!L'O++O8R_JB$:HB`J*)]QJ!A`A5C#7K!7:TU;\HZQ
M_`=*I?%!O<F:63'8`3W7'@&OW&IW`T?3:6`+<GE>):.WBT\>6N/[WU5#^*6A
M<7;GR['9R>=8[L>0F&ZA7,^I)X@_8,UE'65%9(H%6(<Q@57>*(=TRA"*;3+%
M9W@@#)HQEL+>\":.)XU:1Q]9I50-97VHM./S5]UEM[)K7,YCX3V,#X&M.QF&
M5KB*1U)H1N$8=A`)%C]RZXV?Y7>6.KY&4@7&.:_W0PCG.L50=1RCMAH_&"`\
M<SKF,;N%W,$Y=Q3A6030=)I$.Z?E22,</99W4%QF691N<W#!*!@W;(QQIPV;
M=O$T6Q9!FV3Z*T1>10RB7-,O<X7`HZCKN38&!Q`#P'`,):20UA<0%FGGS7",
MRPS;FYLAT>KN_5F!A":&T3KN$:/2.6V%8-*I1N=YY`ST.R?RT$R4F$72+5^@
M%B,XDI#`!%A/66F$,L,MU)#XULRD<;1[K31S@14@5K0\ATJ/<L=F.7YA8Y#:
M9D,NSJYQWEY.\BAEF:70POC>6L>["6ES#M+I"0:MHM?T3X=P/D<SR?//%![+
MP^(P:,>U<8KNEZSB9=3-7"4I)SF(8QD4:W<0DDU@(1LV<%</EFQS)N@!4Q!*
M)APK<J9?ATV6DB(4[LFPXMI+01L-!0U)&_:I/GU[=:3DARS6S&27LA<1+:`N
M9X0PM9+)&XA[2]Y<W"QK@"WNUK0:_74>_8W]8R=-0!8[?DN@JD45TDD%E$0.
M<H%,H1%RF<0`;@10IO88!'"%KF^T"%*$<T,PK$YKA2NP@[*D5[01U@C@O'7E
M5%[VLF_9IB@@Y.#8YQ449*@1RP64$I2\UV#DJK-<X<"B`G(82B4HA82@(>P]
MS10'9RX=FY4)+:"5V-[1X@%`X;'`<@X4<..X\2.)7I_X2^__`(5P/^TO(D__
M`.IE&/$A/_7.ZJ?_`+(@=/O<=^B>T?2/E]"\?\U#^^C]#7^ICMO^SH!]8J91
M><;`Q%I+E:2RRS2<PF0UDJ[6=(3[5CB<N[^T)#'(IYWWS2)(X,"IA02,42%<
M**`0IC@>JK99X@:'NEA97>`#M(!V@=72K"6PRK,)&8V`2QW#;C#0QN,C1A;(
MYI#7.IL&(@@EH%=E%;6K99E*(E$2B+9!\,S1?\S]YESZ89][%-/I-<B,*J?)
MN[S)V=9+$F=Q`+G8+-UI&Y1N11DD!@LIUTO7&:_`95\)&:7%S5O4P>V?3L;]
MX\E$GG#J7\FTW^66[J7U^3'LWB(4\4_>!$?2'FFY=)E0FN1EK`^*!O#^!M31
MNIH9YVLBVHX.,L"*EEV>$0RR*TASX#S1^W)04&Q;^ZLW3=$ZV&IH\E]-_F6>
MOSVX;6TL1W:[C,\$-Z\#:NZ'%A45^:F>_`90W*('4N;L][F(FD$_RG4;T@/"
MY[:ZL7.B_"JJ:*:BRRA$D4B'5555.5--)-,HF.HH<P@4A"%`1$1$```HOH!)
MH-ZT0?\`Q<N/_C)_G!ZQ;^`P?C@`-[G[8:R%P#(779^OR%X`3?:O_>O=O:K[
MP?P<'UM_I_AL6]_E`_)O@Z?CTQ_?W_Z/4L*<V_&>7?F>?^]7=7"SZC%$2B)1
M$HBVQ?#(V;V7^=ZB?N+)O4DLXQU(YK%!TV!M$9&@GR'WE7#8S%4I"]>*"AK#
MU$+2Y;L#_0M3U-;5;'=M&[NGYQZ^T+;[5HM02B+)/2GEIO30JK=#",Q<N,<2
M4`ZN%9("DYB:Y!-R.FC'.%B+Q`JFZG4CUFBQ[!R.(=*T_4>A=,ZH:79E;M%V
M1LFC[DHZW`4?3@'AP'`+9LCU?GVGR&V,Q-L#^R?WHSU`[6UXEA:>E9`>5?Q)
M4MW:5B]4EQQ7`,CR*99N,W5))E?P,K!PYDW+-G&O#)-G3)%_.%2<+)NBE*D1
MJ5,%EN9Q"(HO*YVE<X^.9.+JUP.\,8<,C2=A+A4@T!(!:=I).%M%V[_TX:OR
MC4&;3YUG<3K:6S8&,<>]"99`02'>T"U@.PM(;X@)?N6M`IBG*4Y1`Q#D*<AB
MC<IR'*!B'*(=#%.40$!]@@-9H[#0[UW9#-#<1B:![7Q.W.:00>HC85_:^*HO
MVFHHBH15(YTE4CE4253,8BB:A#`8AR'*(&(<A@`0$!N`U]!(-1O7QS6O:6N`
M+2*$'<1R*JOVDW=?^:LO5J!U]8S6)'/U!^9TKZ9TU=\S&,<ZBB`N5#B`F6$`
MXC[Q@^V*GF-A]8/97I5M\.^/_P`J_"WW7#$T=0JTMX``.P`;FUVK-S$O-S;V
M/8`PPF!88'-RT-A2NML:V0XQ0Z>X\3P5<&R/V'$.4)=%J^08(LBG:@D#GM=@
MBK@0.`"&7BS:Z9`(8PQS@S`'8?Q&MY#;MZ*5YE1W?>7V17.:.S"\=<Q027`G
MD@$M;2685.-U6U:231V+!6I:RH60NT=D%S7"M4Y1X=;Y;89':+PJ-QE#3D@\
M>X7L][(R4C'QR[TL6*CR$V.ZG'(,4EVZ8N&_J!,/-4ZYBU>7$_BPQR97-@;"
MP#`>Z^I(&[<ZNS9M%>=5K.393^7YA>V>O<L-Q+F5PZ0W30);<-:US@,6Q\`8
M,9#CA=AIL:&U66F'XSD$<VR'QWQ>99JY5K?2V097M?,WCI(C0GD%Y!BJV-DT
MT]NEW$,/QEW-/O\`/59KHD+[R0!63BC>T.L8R/$CB+GN_>2\3]D8CU46D7]Y
M:ROBU5>1N%E=Y@R.VB`V_!66WPV#;0RR")G0X.)V%6$WQGNN-1^$4?@.&0$+
M,8IG\XXQ/4J>31;=Y(9!"XZX,IG>\7!503=L9+*9DZA8]1`Z1V[-PP61[93"
MD2SO)X+7*!#$T.B><+*C>![4G02=U.!:0MDTWE>;9[YB/S._EDCOK:,2W)C<
M0&/>*0V@WAS8V`8PX$%S96NJ14X2ZE\-W&UM;QNS7NT<*U1%9;EQL$UZPV&X
M<`&8900%D08M9>-1X-D'#UN=$BAVH""B:@"6Q"'5Q%ME7Q-N+@R-B:YV%H?]
M8]8^C^.0L[U]^29N_)VV4]]-!!XT[H`/PH]AJ6..T@$$@/.P@C>0W%[8^N\L
MU1FN0:_S>,-%9+C3]5A(-P.5=NKQ]Y!ZP=)_LGL<^0,55!8GNJ)F`>GL#'7$
M$MM,Z"84D:?X$<P>"W/*,VL,\R^+-,M>)+25M0=Q'-KAO:YIV.!V@J$51627
MI:O'+)056JQT3'(*2H%$!371,8ICMW"1@,DY;*B0.::A3)G`+&`0KT'%IJ%3
MDBCF;AD`(!J.8/,'>".!%".!7O[T8^Z.4OLQT;_%,R"HP5./]IU'W[C3FH<3
M'4;&%-,A0*FU$:]58[?L=S&[LX>CT!4<%Q#^S/B1^Z[8X=3MSMFP!^TDU=(O
MBXBW"21W2!T7[(G'F]8F.JDCR,5,OJDE$T7;#N*B)">H22[HE$2<B]:^%A`J
M-K>8]?$>GT+TRY8YPC>"R8[FNV$\>Z02UU!M.$FGUJ'8J;7A7"_H`(B```B(
MB```!<1$>@``![1&B+JU\)M&!H70&)X[(-`;9?DA/XSS?F3@X3GIQ!N=.*7N
M'(IH"*2;LC%N).\BH<OUQJ`=49K^;9O),PUMF=QGV6\?O&KNH@<%Q)YBZD_S
M-JB>[B=6PA/A0\L#">\/MNQ/YT(!W++%==%LBLY<JI-V[=)1===8Y4D444B"
MHJJJJ<2D323(41,81```+C6OM:Y[@Q@)>30`;22=P`YK1'.:UI<X@-`J2>`7
M)_Y6[I6WUO',L[3654Q\KO\`A_#$5.10;XC"'5;Q1RI']Y`\H<RK]4@WX+NS
MA[+5W)H?3K=+Z:M\L<`+K#CE/.5]"[KP[&`\6M"Y'U;GCM09]/?@DV]<$8Y1
MMV-ZL6UY'-Q6.=;<M:6$WGCN'^6.EGL!&.NQE&S#N<6C03/Q7;0@HE/E4B0`
M$#<"1RQ68&*(&(J](8/JC5>!F)]3N"S>0V?Q5Z)'#\*+O'K^J.W;Z%S\U?J0
M%)\V_&>7?F>?^]7=$48HB41*(E$5SM-;,D-/[-Q'8L<@9X?')+O/(XJ_IADX
MEV@LPEXWOBFL5$SV-=*D(<Q#@F<2GXCQM7E[<;2WFK6]MFWEL^V=LQ#?R.\'
MT%;]=/>76E-S>E80V2%Q[*'';)_".6=F(EU7![%!&,6,LI&39CGOQ(U746XA
M<Z9+VK'OA>S>-BT&\RB]LJN>W%%[S=H]/$>D4Z5DY5-8Q?PQ@*`F,(%*4!,8
MPC8```N(B(]```KYNVG<O3&.D<&,!+W&@`VDD[@!Q)6,^2RXS4P[>@(BAR[#
M0!O[K5$1*D(`/U14ZG$/D,8:T>^N#=7+I?J[AU#=]/I7Z">7^F&Z2TK;920!
M>8?$F(XS/H7[>.'9&#Q:P+X1D[*1!O\`4G1R)<A,=LI^U:G$PDYB*![D*<X)
M@`G+Q4MT`P5C9K:&?]HT8N>X]OJW*2,LSK-,GD\3+YGQ\QO:>MIJT^D5'!7'
MB\^8.`*G)HF8+6ZK)`==F<P%.81X@!G#?D;B4I1!0.MS'`*Q,V62LVPG$WEN
M/T'Y.@*4LF\R[>6D.=1^$_\`UC*EO66[7-]&+J"G22J2Z95D%4ET3\N"R*A%
MDC\3"0PD53,8AP*8H@-A'J%8T@M.%P(<.!V%23:7MI?PBXLI&2PGBT@CJ/(\
MP:$<5]*^*Z6P'6WCMK[*=(Z\R+,7Y<<>9.CM[)DY]BJFK*!%8ZJR9OI:5;*"
M=,<4UA!8-)R"C8>PM)R<['LTETP<F51S=O8P26C))3A+L9KQH.)Z&!I--E2Y
MHKMJ(PS;56:66HKJUL&^+'";6/`1W<3P2&M/^LN'S1L#N\(XX99"TX`'6HV3
MI#+L(>X8\BCOLT9Y\^QYM@[-S$_8^VG4W,8MC&6IL%(B%>3K\)J$:9:P0#B]
M?H`NX1+VN9122M[BUEB+"*O#R,.RCZD!W"IJ,0&\C:-G`9?*,_L,PCN&28;:
M2U:\S$.QVH8R22*M7AC<#S$]Q[D;J-<<5#B=0\<WMLB'QC9&%QN3R#Z/V\]A
M#[*&5<G+L::8PPK)*0[/+7QW1WB+]F[,T.40.Y<E.8H-@2,H4_B.[G;')$QQ
M+92,=?;-.`<=_+F>5%<W>G<JFO+3,+B!C);!K_ARP?\`+L+J=]T0IA((Q^XV
M@)D+@")!Y"[B9>1>V<-8Q,<MKO76,P^':RPO'I8Z7'#81H#1E)+OP14!N)T9
M!94QCW*86J")3V$E@]7UT+ZY8UH\.!H:QH/U1QKZ?DHJ&E<BDTKD<\LSQ=YI
M,^6XED;_`&KS4M#>.UH%!NQ%Q&];(<>U+(8IC?D?XKR(9*?%=%-F/D'HC<V1
MXZ@P;8YDL='-LC['JCE<0DFS&3473YD*)5D0D>:9!XIIYYELZ..?+G8O#A'B
MQR$4H0*]1V_TE$]UGD5[=Y3K.+P?C<R<;*\M8WEQDC<XQUIL>TX:&AW'PJ$[
M28D;PWF=NL,0RK;N0[47WAOR'F,WD\A:8E`.](X,Y88XWD(.$V(V1:,)+'IJ
M8QYFFW(X9+MU$%;HID#B!CT_RM]RULETZ0W<X+B<(\-M!4!VX@D;*@BFX*\.
MN[;))9[/(XK)NGLL>R%K#*\7DP,A:]\!JYLC&2$N+7M<'"CG$[AA7EGB@MBW
MC5CN_IJ;/&O<PRMG&XW`PR/\7XZZQQ]"N949R4GHD3.\6,V7C':`-E4WZW,A
M$U13-W#EQ4N6^'8-O7FA>Z@`[PI2M21M;N.S:>:D"RUL;O5LNF8(Q)';PETC
MW?A2!X>&X&L?W9:AS3B!C;0DM!V`X>NV#MEVQ<)<4UN?8<)J).&CCM\>[Z9X
MW.JU<]DQP*?@<W`WNFL("%8IS7-W[OD[=RWV*>*:HC/>&\$$.%=U6FA%>%0*
MC:-B\=>557V;N'#14CAJNLV73Y<%FZIT52<BF(;@HF8IR\B&$!L/4!$*^@EI
MJ#0KP^-DK2R1H<P[P14=A1PN=RJ=90J)3GXW*W;MVB0<2E('!NU2103Z%Z\2
MA<;B/41&A-34_0C&"-H8VM!S)<>TDD^DK-SX?FB_YU^04"M*L_4X;KCLYSD_
M<)R;.EHYR3^&X57D`I*?:DX"9U$C`(*LV[@/DK5=7YK^69.\1FES/W&\Q4=Y
MWH;7;P)"COS2U+_EW2TK8'4S"[K#'S`</Q'C[+*@'@YS5U%5!"XR6OOXCF\/
MY4Z(=XI$O/3Y;MI1UB;`$E.+AMC1$DSYC(E`!`>V:/<)L+AU*9^!@^J-2IY1
MZ:_/-3MOIVUL+`"5U=QDK^$W^4"_J93BH[\RL]_*,@=:0NI>7E8QS#/[1W80
MS[]>"YLJ[`7,B41<Z'F;N'^;^[9Y>.=>HQ7#>>'XQVS\FZZ$8X5^U99+C^S4
M"6ES*G(H`7.V*B`_5"LC"S`S;O*D7);/X.Q:'#\5_>=Z=P]`^6JQ/JJLLI/F
MWXSR[\SS_P!ZNZ(HQ1$HB41*(E$2B++G3WFMN[4GI8X9O^.<5;\$_P"'<Q4<
M2`MVY;!VXJ<[@3$;VTPXI$%19JG_`-R/LJB^%C]NXK$7F2V-W5V'PY3Q;L[1
MN/S]*V8X7YT:HVK!&AQ77P+,7_99J0N2N&Y&*P.!`BX0V0E%%C("H)@1(FJ5
MJY4,>Y41`!&L+FT5S':.$#2\NV&G`<33?NV>E9[RTTS8QZTMKG.YX66%O65F
M(X0^5M/#::[`0XX]IH<&&M313T!`0`0&X#U`0]@A\X5HJ[7!!%1M!7]HOJ41
M>^/E)"+5%5@[5;&$0$Y2"!DE>-^(+(*`=!<"\AL!RF`!ZU2EABF&&5H(^7T'
M>/0KRRS"^RV;XBPE?%+S::5Z"-Q'000KB16P$C\$9=OV3"(%]8T`QT>HIE`R
MS8PF53`I>1CF(901&P%(`5BILK<.]`:CD=_H.[MIUJ3,G\S)&TASN+$/]9&*
M'K<PFAZVD?9*O9@6PYK$)$N1X7+,@6.S>QKE-U'1&0Q#^.EFP(R$3.8]/L9.
M%DV3UOQ!5J];*$$2E$2<BE$+%KI[22M,+Z$4(!!''8001VA2&)<BU39X(Y&S
M0AS7=Q[F2,<TU:X%I9+&X'<06G?385EWCWDY$Y?D>/3NSAEL?S3'\$V!B<)L
M>'#[;AXW(,X5DUU,]>8(1%BZ1R1$^0/Q,Y9/A12.+/T[))-FFG5^S,&RR-?<
M5;*UCFAPV@%U>]AY[3M!Y4`HM9NM'SV-I+;9/@ER^6YAE?`[N.<R$-'@B:I!
MC.!G=>RI'B8Y'&0E9A,8#QSW?BV-1;>+CYR!QIW'KL(R$%DWV0O`XY@CB+B<
M(&;;D5?Q3`8^8QLS\"**).L\?F:%Y`NHNEE&LL;N-K0`6-(H![5`V@;7>-A9
M7G(:<:C1)+K5>G;V:9SWQW,S7!SGU,`?),'.FP&C7'$V?!4`MLV!^S"&NP(V
M[JAEBF>L=<Z[F)/:+Q%DI]ILW`8[,8^P)')MVSJ3Q_+L;RJ1.RQPLF@Z*N#P
ML*YCTF92O2F*-PP]S;B.86\!,IIM!H0*<0X.-!6N_"13:I(R/.'7N6NS?,XV
M6+2[NN;C9([$20V2*2)H=)A+:8?&:\O)C(*^3[?N_6.-):LE=BYFEBD2^)'/
M->9R\XMW"..R!6[G%W4\Y0:.GD*U68'0<L'"S1NF4H-RD4$+5\-Y>"/X8R/\
M,&F!QY'=7ELV@T'#:O4>FM-ONSG,=I;F\>W$+B!NT%[:B01@FCR'`M>T/<?;
M):%E)GOD-KG:.5R,[B^2;^U'NC>LM@.&9)]N9-$PNI,%Q1RBVP[(SK>G,@YR
M3&SQ2JBR9G35JLV<%%P55$2'*KD9[V"XE+V.GBNYBUIJ0&-;[)ZQ3F!0[:CC
MIV5Z8S3*+%MO=197?Z>RUDTL>"-S[F:45ECI6HCDQ4!PN<'-.$M=4%N4V89,
M.M9S<&RXMDLEAGC'B6+^-GC5AZ2Z<HSE]I9-C#'NY89BS47:/IAI#Y2F43#=
M5>.<*%,!%N9:R$LGP[Y;AH_"MVB*)N^KR/:ISH?2#S6G6%G^;VUAE$S@;_.)
MY+^_EIA+;>.0_A5-"&ET9/(2-!%6T*L9D'B=JV)C3XSDL^?`E]'Z80S'R.VD
MCZK($)3:>P7Q)'"<'>X\X^T8N5+!IK.5`,V:"\7079E*8%3E$+1^6V[&^&]V
M`PQ8I7[ZO=M:TC:#3;N%=W%;#;ZUSBYE%Y:Q?$MS',#%86^R,MMX1AFF;(,+
MF8Z-&U^$$25&$%8*>06C3Z/RG'H"8G(J7;YAA<)GN,9/C[.09,)."GC.T6JL
MQC$HFE*X\\,[9K"H5(3$31*0$VW,3%)A[VS%I(UCR#C8'!PK0@\VG:/1Z`I&
MTOJ)VH+*6YMHWM-O</ADBD+2YKV4)#)6U;(*$4Q4)))=)2A./;MDJT[9C&16
M06YBW=-E2K-U@)Q$P`8OOHK%(H0QD52IKIE.7F0O(*L7-+>K^'\*;UM<4S9:
M@`AXW@BA'TC80'`EIH:$T7CKRJJZ>/AVZ+_DYX_1$O*L_3YCM,S?-IX5"<7+
M6*<M^.)0Z@B!3E*TAE?4F3,`'2<OEB#[*@S66:_F6<.CC-;:WJQO(D'OGTG9
MTAH7&_FOJ7\_U3)!`ZN7V586<BX'\5WI>,((V%K&E9Z5J2C-<N7G+O#^>&_L
MED(UYZG#\,$V$X?VU.;9=C#N%@DYA'B/;4";FCKKIJ``&,U[!37X!7:GEIIO
M_+>EH8IFTS"X_&EYASP,+#]AF$$>]B(WKE/7F>_GNH99(G5LH/PH^1#2<3A]
MIU2#[N$<%AW4@+3%BUYA[A_DYI/(9&/=>GRG*2FQ'%!(?BX1D)5!8'LHE8>9
M#0T419<A["4'`)%'ZX55A9C>.065R>S^,O6M<*Q,[SNH;AZ30=55SBUD5(R4
M12?-OQGEWYGG_O5W1%&*(E$2B)1$HB41*(E$5[];^0VT-8]AK#3AI2"1`I`Q
MO(.[)Q)$BEXE39<E4WL60@#<"M5D2";J8IO96.O,JLKW;*VDOO-V'T\#Z05M
M.1:RS_3Y#+*8NM1_92=Z/T"M6_<+5L!UOYB:VS$4&&4]S`9I00)_Q5<'./+J
M")_W,\1)$C0`(3D87B39,HF`I3G&M5O-/7<%7V_XL?1L=V<?02>A3-D/FEDN
M8X8<T!L[H[*DXHB?MTJW[P`'O%99-W#=V@BZ:KHN6SA,BR#ANJ19!=)0`,15
M%5,QDU$SE&X&`1`0K`N:YI+7`APX%29%+%/&)87-?$X5#FD$$<P1L(ZE]J^*
MHE$7H:NW3)4%V;A9LL`"7N(*&3,)36Y$,)1#DF>W4HW`0]H5X?&R1N&0`MZ5
M6@N)[643VSWQS-W.:2"/2-JN!%[`6)9.8;^H+\KMF4B2U_VIA%1L(D;J"8QB
ME#@*)2%#ZIAK%S96T[8#0\CN[=_;52+DWF3?VU(<W8)X??;1L@W;Q[+OU23O
M<KOXAF[^'D6F0X3DKZ)EXU=J\;2$*^<QTDR79/&[MHL/:,@Z1[+]ND<@F`"B
MH0HA>P#6-+;BTD!.)CZ[#U;=A&P\U)EGFVG]46QMV.BF8YI#HG@8J$$$%CMX
MH2"14;3M61.IO)">UKFN59Z:(AG>4Y;'H12LZQA(6(""(<@(OI:,@H)E!-/M
M1P*:3A06KB-4=KI&!=8Q'#CG<VU^^WE=-0&1PI4`"G2`*;>.PBO$[2K3.])V
MV;9?#E@?(VR@>78"][L?$-<]Y><(VM&)L@:",+06-I[O(;;<3ES/&L!PJ;?9
M-K[&3GFX:=R5[-O\S7?2#!K&.&<XE)1D-"8VHU0CBG.PA&YV`JK"H=X]4XJ)
M_;ZY;*&PQ$N@;M!-2[:*;:@`;MS13I*I:6R.>QDFS/,(VPYI-W'LC#&Q`-<7
M`L+7/?)4NH'RN#Z"@CC%0<;&LDY:IBW`2+LSG%15BZ("[,YS%*0Z@)&ZMW)D
MB\.^D*:Y"B(%.6K$/+13>WEP_ATC:MKDMXY'8]K90*!PV.'17B*[<+JM)W@K
M(/37DAL32X':X%DC.)@G4_%9/+X5ED,AE&%RLO#JMUFKU*[)S.1#KN-T2@9H
M=!R*3<G-X82D*%[:W\UKL@<&L+@2UPQ-)'HJ/1MV>TM6S_2>6Y]1^9PNEN&Q
M.C9-$_PIFM<""#W@QXH2>]5M7&D0!)6R7*<NT63!]?8#OG;2<+*[,R6/\JMS
M2V*PKC.\4V"^?/WBJ&G0E\6<2@1R,1'MFC9/MF<MT4X\@``'52-6>EDLQ"R&
M]EHZ1WC/(&)KC7V*BM*"@XC9TA1/966HG9C=9EIFR\2&SA.76K)'B&6!H:*W
M6"0-J7N+G&H:XEYX-<M7_DMN9WOO<V9;&.5=O$OWI8W$XU<"D-%8C$%]%`,A
M1(8Z3==1HGZAP0@B3U2ZH@(WO6O7]V;V[?/]4FC1R:-WTGIJICTCD#-,Y!;Y
M2*&=K<4CA]:5VUYKO(KW6D[<("L15DME64WAMHX^_=^8?B#QJ9QBL2M_%N<&
M$HF1#%X%9!9PQ6$.I2SK]5O'@(=2^JY>PHU@=2YK^491)<M-+APP,^T[<?NB
MKO0M+\P-2#2^F)[^,TO7CPH>?B/!`(^PT.?]VG%=8A"$3(5-,I2$(4I"$(4"
MD(0H`!2E*``!2E`+``=`"N?B234[UP^22:G>L.O.C>'\D-`Y(]C7?ILPS8#X
M1B/;4X.6[R7;+!*3*(E'N)C"0I%UDU``2E=B@4;<PJ0/+33?^9-4PQS-K86W
MXTO(AA&%A^V^@(]W$>"TK7N>_D6GI7Q.I>S_`(4?,%P.)WW6U(/O8>:Y=:[3
M7*J41:!//G</\R=S.,7C'7>QG6";G&V@)GY(.,C443/E3XH7MS3>()L?F$&7
M(/K5?V[,+*G>5O\`D%G\-9"5P_%E[WH^J.S;Z5@W5=9Q*(I/FWXSR[\SS_WJ
M[HBC%$2B)1$HB41*(E$2B)1$HBN=K[<6Q-8KE/B61NVK'N@JO!NQ]?!.A$Y3
MJ@K&.1.@BHN!.)ED.TXX]`4"K.ZL+2\%+A@+N>XCTC;Z-W0LYDVI,ZR&3'ED
M[V,K4L/>8[K8:M]-`X<"%GUK7S8Q&=]/';%C5,0DC<$QF&!5Y+'%U+$*)U4R
ME4E8GNJF'B42NDB%"YU@K5KS3<\=7V;L;.1V.[=Q^3J4R9%YLV%SA@SZ,V\W
M^L95T9ZV[7M]&/I(69T3,1,\P;RL))L)B,=%$[:0C':#YFN4!$!%)RV441/Q
M,%AL/00L/6M=DCDB>8Y6EKQP(H5*UI>6E_`+FRD9+;NW.8X.':./,;QQ52KP
MKE*(OHBLLW5(N@JH@LD8#I+(G,FJF<O4#D4()3D,`^P0&]>7-:X%K@"T\"O3
M'OC<'QDM>#4$&A'40IS%9X_:\$9)(K]`.)>\7BB\(4`3(`B8H=E<"$((V,4I
MSF&YE*QTV6Q/[T)PNY;Q](^8<EOF3^86<9?2*^I=6WZ1I(.I^VOW@X\`0KD1
MD]%2Y0]$Z*97B)C-5OV+L@`4YS71,(]P$R$$3&3$Y"_*:L3-;30?M&]WF-H[
M?IH>A2MD^K<DSJC+>4,NC_9O[KJ\AMH[[I)Z`JO5!;*E$7L:/W;+N`W5XIK<
M.^W432<-'';Y=KU+-P15JY[)CB8G,AN!O>+80`:]-<YN[=\G9N5*6"*:AD'>
M&X@D.%=]'"A%>-"*C8=B^SA6,<)'43;K,'8<;-VYA<QZUS%*/`SI?UK'MI%Y
M#R.[[IS#;M%``KZ2PBH%'?)](^7T+PQMPQP:YP?%S.QP[!A=4\@R@]XJFUX5
MPNCKX8.C/Y<Z46V7,L^SE&WET)1L*R?%=GA$:*Z.-HEY`(D++JK+R`F*(%60
M7;W"Y`J%]=9K\;F@L8C6"V%#TO/M=FQO00>:Y+\Y-2_FVHAD]NZME8`M--QF
M=0R'[H#6=#@_FMF5:.H?7-=\1G>'\V-\/<7B7G?Q+4Q'6(QP)GY-W61BL0^8
M290`1#G]I($87`1*9-@4X?6&NP?*33?Y'IAM[.VE_?$2NYB.GX3?Y)+^@O(X
M+F/S*SW\WU`ZTA=6SLZQCD7U_$=V@,ZF`\5K_J4U'BL3Y)[;1TKI[+,U*JF2
M:!K]C8HBIQ,+C*)<JC>+$J9_=6)'V.\5)TY(-C@'6O<;,;PW@K_+;0WMXR'Z
ME:N^R-_;NZRN9M==9RLLY<*J+N'"JBZZZQS*+++*G%15550XB=110YA$QA$1
M$1N-9-26``*#<OE1?4HBD^;?C/+OS//_`'J[HBC%$2B)1$HB41*(E$2B)1$H
MB41*(IEANPLUU\_^T<-R.2@G!C%,NFU6`[%YP*8I`?QC@JT=(%(!QX@LD<"B
M-PL/6K>XM;>Z9@N&-<WIWCJ.\>A9'+,WS/)Y_B<LFDAEXX3L/0YI[KAT.!"S
MPUMYPLG'IXW:,$+!41*F.2XVFJNR&YK`I(0:JBKQN4A`N<[95P)S#[J)0Z5K
M-YIHBK[)U?T7>IWT]JE_(O-L=V#4,/1XL0^5T9/I):>IBSBQ?,,7S6-)+XI/
M1D]'FX@9Q'.DUQ04,0J@(.T0$'#)T4AP$R2Q2*%OU*%:S/;3VS\$[',=TCYC
MN/H4O9;FV6YQ!\1EDT<T7'"=HZ'-]IIZ'`%22J*R*41`$0$!`1`0&X"'00$/
M8(#\]$W;1O4RB\WEV/%-V8)1N`]2N3B#H`$3F'@]`#J&,8QO:J"M@"P6K'S9
M=!)M9W'=&[L^BBW')M<9WE-(GO\`B+0?4DJ2!^B_VALW`U:/=5R8K*(>6X)H
MN.PZ.(%!H[`J*QCB*9`*B;D9%P)U%+$*0PJ"`"(E+6)FLYX-KA5G,;1Z>(](
MITJ5LGUSD>:TCD?\/='ZLA`!/Z+_`&3Z<)/`*0U:K<DHBOEXW:<?;YW1@^M6
MI5B,)B4(ZR1Z@`@:-Q6+`7^0O04MP26^SD3I-Q-8IG2J1+W,%8K.\R9E.62W
MSJ8VMHT<WG8T=NT]`)6MZNS^/3.GKG-WT\6-E(P?K2.[K!TC$07?H@G@NNV-
MCF,1',(F+:HL8V+9-8Z.9-B`FW9L62!&S1J@F'1-%NW2*0I0]A0`*YW>]\CS
M)(27N)))WDG:2N$YI99Y73S.+IGN+G$[RXFI)Z2=I6/OEANI'0NC<RSE)=-/
M(56O\.X6D?B)E\MG$UF\6H1,_NK%BDR*OU2#;F@T.%[B%;9H;3KM4:EM\L<"
M;0.\28\HF4+NK%L8#P+@M5U=G@T_D,]^"!<D8(NF1VQO7AVO(Y-*Y0EEEG"R
MKAPJHNNNH=9=98YE%5EE3"=1550XB=110YA$QA$1$1N-=QM:UC0Q@`:!0`;@
M!P"Y'<XN<7.)+B:D\U\J]+XM'/Q&-P_Q?LJ.U?$NNY!ZX0%26!(]T7682R*2
MKHI^(B17[%BQ20*/UDEU7!!MUJ^MV4;B.\_,MXTY9^#;&Z>._)N^R/I.WJHM
M<U7"V-*(E$4GS;\9Y=^9Y_[U=T11BB)1$HB41*(E$2B)1$HB41*(E$2B)1%7
M<=R?(L1DTIC&)J2@I-&P%>1CM9JJ8@'*H*"_:,!'+90Q`YI*`9,X!8Q1#I5.
M6&*=GAS-#F'@157-I>W=A.+FQE?%<-W.8XM/:.',;BLW-;><$RP!O';/A"SC
M<H%3'(\?3092P`!;"J]B#F0BWJAS^TR!V8%+["&&M;O--Q/J^R=@=[KMH]!W
MCTU4KY%YLWUO2#/HA/%_K&`-D'26[&.]&#K*STP?9F"['9"]PW)(^9`A`.Y9
MIJ&;RC(!,8@"^BG149%H4QRB!3'3`A[7*)@ZUJ]S975F[#<,+1SW@]1&Q3'D
M^H\FSZ/'ED[)'TJ6;GMZV&CNBM"T\"5.ZM5G$HB412:*RV8B@*D58'C4H`4&
MSSDJ4A2E*0H(J@8JZ()D+8I0-VP'J)1JSGL8)MM,+^8]8W'Y^E;)D^K,[R4A
MEM*7VP_LW]YGHVU;]TCIJKDQ>9P\CQ(LI]FN!_[)X<H(B/[4P@F\L1$2D(0.
MJ@)"8QK%*-8F:PN(MK1C9S&_LW]E>M2MDWF%E&84AOZVMR?>-8R>A_#[P``^
ML5T4?"DT8&,X!D.\YIF!)C8*JN/8H=4EE6^&PCT0DG:)A`#E+/9$U$IBCT$D
M<D<HV/4*Z_S7Q[MF51'\.'O/Z7N&P?=:?UB."AOSJU0S,<QAT_9/#K.V:))"
MTU:Z5X[NT;#@C-01QD<."VXU':@Y<]7Q/]X?QUMN/U1#/.[CNJFYRRH(GN@\
MS>8116DA,)1X*_8D:"#4M_>1<&=%Z7&NK?)?3?Y9D+\\N&TN[X]VN\0L)#>K
M&[$[I;@*YS\U,]^/SAN40.K;6@[W(RNH7?R6T;T'$%K#J9U%BMCN;9<=J'66
M7[!D>V<("*54CFBAN(2,VZ,5G"1H6$#\7LHX2(<2W$B8F/:Q1KTQI>X-"NK*
MV=>73+=OUCMZ!Q/H"Y@)F7D<@EY2=F'2KZ6FI%[*R;U8;JNY"0<J.WCE4>@"
M==PJ8P_2-9,``4&Y2>QC8V"-@HQH``Z`J;7U>DHB412?-OQGEWYGG_O5W1%&
M*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1%[8Z2D8AZWDHE^]BY%H?NM)".=
M+LGK53B)>XW=-E$ET3\3"%RF`;#7ES&O:6/`+3O!VA5(I98)!-`YS)6FH<TD
M$'F"-H/4LQM;>:6<8X+>.SUDEFL202)C(I]J.R1NE<A1.*Z:81\IVD@&Q54T
MU5##<Z_RU@+S3MK-5]L?"DY;V]F\>@TZ%)F1>:6=9=2'-0+RU'$]V4#[0%'?
M>!)]X+/S76[M;;023+B^0MQE#)]Q7'9/C'3Z'$A3JA]GKG_UTB`'`#JM3+H`
M/3G>M5N\LO++;,P^'[PVM[>'IHIGR/6.0:@`;93!MT?[)_=D]`)H[[A<!Q5V
M:L%M"41>V-8K2;]JP0#]JZ6(D`VN!"B-SJ&#_-23`3#]`55AB=/*V%GM.-/X
M_1O6(S_.;73V37.=7G_E[:)SR-V(CV6#I>XAHZ2%L=T?Y(;D\>?2-]:9G(1\
M$V[8+8G)C]KXF^*40%45X-X)VS9PYM^T<-?3NAOT5"LIGFB=-:B@$69VS'2M
M;1LC>[*V@H.^-IIR=B;T+@J#7.IK;,YLUBN7>+<3.D>QW>C+G$D]PU`'`8:$
M"@!6US#?BPXO(83D'\<X*]Q_8K#'Y)?'Q@S'EL.R*?29J#&M5^\JG,X\DZ?B
M0IBG]8F1(#&%>]BC"F8>1E[%F47Y9=-ERETK0_'W98V$]XBG<D(;7:,!)H,/
M%279>;MI)8R?'V[H\R;&XLP]Z-[Z=T&O>94TWX@!4XN"TA3,O)9!+RL],O%I
M"8FY)]+RK]P;DN^DI)RJ\?.US```95RY6,<P_.:ND+>"&U@9:V[0RWC8&M:-
MP:T`-`Z```H+GFEN9GW$[BZ:1Q<XG>7.-23UDU5-JLJ2TV_$IW#]IY#CFEXA
MUR9XX1'*<N*D?W3SD@V.2"CEP`0$#QT.X.Y$!N4WKDQ]I.EY;,H,9WE;EIJS
MP1NO7CO.[K>H;SZ3L]"U95=+:4HB41*(I/FWXSR[\SS_`-ZNZ(HQ1$HB41*(
ME$2B)1$HB41*(E$2B)1$HB41*(E$2B+]I*J(J)K(J'262.15)5(YDU$E$S`<
MBB9R"!B'(8`$!`0$!"A`(H=R^@D&HV$+*C6WEWL[".PQGEB9Y!I<2"WG%U"3
M:*0`?HUR$I%G)S"8P7%VF[]TO$O`.M82\R&RN:NC'A2\V[O2W=V46_Y%YD:@
MR?#%<.^+LQ]60G$!^C)M<.C%C`X!;`=;>2>K=E^G9L9D("?6$I`Q[)!2CGJJ
MQC"0J<>Z%52-E#*F`1(1%8R_'J9,GLK5;S)KVSJXMQQ>\W;VC>/FZ5-&0^8&
MGL\PQ>)\/>G^SEHVIY-?[+N@5#C[H6:VM(>XNIM8GU;LV5P^4;&<JEO\P<2`
M/TF"KS([;:ZZ=]EOK/J[5#?_`%`:IHVWTC:NVFD\].6T1,/IQ/(/*,J[M;&N
M8$HB411#/\UA]<X5D^<SRG"*Q>&>R[HH&*11P+9(1;L6XF]T74@Z$B"(#]95
M0H?+7UK2YP:-Y5:WA?<SM@C]M[@/X_1O7+KFF6S&>9;D>9SZW?F<GF'\S('#
MEVRKOG!UNP@4PB*;5J0P))$]A$B%*'0`K*-`:`T;@I0AA9!"V&/V&@`>A1FO
MJJI1$HB412?-OQGEWYGG_O5W1%&*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)
M1$HB41*(E$2B+*'3_E_NW3@MF47D9\FQA`2%'%,N,O+QB:!;%[48Z,LG*PP$
M)?@1LN1`##R,D?V51=!$1L`'5L6/S#+;;,G>+<8OB*`8Z]Z@``!K6H```KN`
M`%`MJNGO/S3>Q_2Q>6K*:OR9;@F*&0N4UL9<KFL`@RRDB:#9`GR_Z\DR`/84
M3CUJV?`]NT;0M1O,@O+:KX?Q8NCVO2WZ*K.1NX0=H(NFJZ+ELX2(LW<-U"+(
M+HJ%`Z:J*R9C)JI*$$!*8HB`@-PJ@L&00:'80OP[>-(]JN]?NFS%FU3,LY=N
MUTFS5ND3J95==8Q$DDRA[3&$`"F]`"XX6@EQ6H+X@/DMBF80$)J?6^4QN2,5
MI,TQF\G!.@>QAOLLQ0A(1*00YL9%,[TYW2PHG.4AVZ'O7$P!>6\9!QN%.2V_
M3^62PR.N[EI:ZE&@[#MWFF\;-GI*U2U=+:THB41*(E$4GS;\9Y=^9Y_[U=T1
M1BB)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(KVZL\BMQ:
M;NC@F:2+&+/W>YC[\$IC'C'6`W-=.'DB.6C1R)Q`PJH`DH82@!C"6Y1\.C8_
MVAM5C=9=9WFV=@+^8V'M'K4=V#N/:&U'0NM@9O/Y*'<[J3%V\%&&:J"(CR90
M;,K:&8FZ^U%`@C8+^ROK6-;[(HJMO9VMJ*6[&MZ>/I)VGM5M*]*Y2B)1$HB4
M1*(I/FWXSR[\SS_WJ[HBC%$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(
ME$2B)1$HB41*(E$2B)1$HB41*(E$4GS;\9Y=^9Y_[U=T11BB)1$HB41*(E$2
MB)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B*3YM^,\
MN_,\_P#>KNB*,41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B
M)1$HB41*(E$2B)1$HB412?-OQGEWYGG_`+U=T11BB)1$HB41*(E$2B)1$HB4
M1*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B*3YM^,\N_,\_\`
M>KNB*,41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41
M*(E$2B)1$HB412?-OQGEWYGG_O5W1%&*(E$2B)1$HB419^^)/AS#;XQN7SC-
M<DEHG&VTHM`Q4?C"K!&9=R+-%JY?.GKJ3C91HT9))/$R)D*B=14XF,(IE(7N
M4)9BPX1O6`S;.'V$@@A:#)2I+JTIPI0C;_#JSNQKX9OCTL1UZV8VA(&`Z()B
MXR.`2%(!`]P(#'$F8&YC[>7(>G2W6LIE5O'?->9:@M(I3IKSKR6/ASZ]F!)$
M8IR!]9*N2R^&=XT%[!!QW-Y`R0$$_?RJ4YN0((<A7*Q1:@7G_:[8)^WI:LK^
M5VPWXNW^)5?S2^.XC^2%*&OPU?&<.1@U3DKXHV`.>4Y\)2"%[B46DP@-Q^D1
MKT,MM.1[2OGYCF!W./\`)'T*KI_#=\9FY2*GT7,'!,Q3=YQD^U!(8>?N@H7^
M*2MS%Y6"PEL/L$!JO'E,#W!C(G.<=P&(GL!7EV8Y@!5SR!]EOT*3L/AQZ=R9
M8(_"/&EUD4R`&7-'0K#-)E\+-(H@NN#%*0<JBBD8Y.1P)8MPN/6L+JEEII_+
M!F%^6V=OXK6^)*[PV5<'4;BD(;4TV#>:+Q'-G-\[P,N\6:XWX8VXG4&\T:":
M#94K"'S,\-M6X'JG-I:'P176V<:S547>,4$GS1THNG(M(V5@LBCI-554AV_,
M3%N!%FZR=OJF4(;7+.\;<M9-"]LEO(T.:YI!:YKA5KFD;""-H(-""F7YAF,6
M9?!7N+%B+'->*.:X5X4!!!V$'T[5I#K)+<$HB41*(E$2B)1$HB41*(E$2B)1
M$HB41*(E$2B*3YM^,\N_,\_]ZNZ(HQ1$HB41*(E$2B+>1\-ER*FB)\@#[S3:
M,\D'R\>6-X<Y`;"'LY+C\X597%/$]"TC4@I?M/[H?SG+L,\]FS,&^FG+9%-J
MS72S.Y6B"92)IJ_P@X`4DB"BD8P]TYK7+R'Y>MZT3_I#EDQ:C@D)=(#9':=_
M_FP>G@%)WFNQN'+GL`#")MW^Z/TK&V#\?G.00T5*L<PB2*2D(XGRQ[IDN@N5
M@W04<JBBJ#@[=R=LBF/J!`Q4T3E.43#VU!)U_)F1C>6.C-`ZE:\>SLYJ*&VN
M)H<';2*TI_&KN1&JI;[44QQAC&MY1R_9SKPDJ:#<O6:3J!DX7&U6#)RM'O6C
M=5RYE"*E3.HH9-0YC&N@9HLI9/O&X?$<][0"-E=M""ZN\$TI2M/EJ!7;`<6`
M-:2:[:<J#E_#L*HTYX_EE'4&]>&<PCB>1>I-8F'QMFR*5.'FXO'G;LS5DHHU
MXE?S:+@YQ4!0(Q-5PH4IT3(5[9F18'-!:X-IM))W@NXGD*?:H.-5Y=:@D$@B
MO`#D:>OLVKY>&0"RWW&I`S>L/48MD)>R^-S5/9$BO<*/I&G[,>Q8/=]I1][Y
M*A3_`*FV^+Y4S.JUV"^MSL^T1S/O?Q+<?+4X=4L%"*P2;^H'ET+2S\5YA_K_
M`)HMQ"PC(YQ(6]GM>A*@/6_MO>M$T,_%I7*G?X&`=D;1ZE@\Z&#7%R/\:\]K
MB?6N26MY6S)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$4GS;\9Y=^9Y_[
MU=T11BB)1$HB41*(E$6ZSX9Z_+46<M;_`+G8[A>W7IZG&,<3O;V=?2_U58W7
MMCJ6EZE'_.,/[O\`I%=DOF>L+G7^A)7N*$`S1TIWT?>53]9"8TY[B7OI`*A>
MQ<OO%N(>T/;4>_\`2D?"U!J.UH-K8=GV9)Q_24F^9GXF5Y9-7@[Y61GU+!6.
M<.GSH&[+(,B!8Z#LYC%3.0I&J+1==\HL<DT(IMDV2:AE3#[A4@,)K%N-=HN8
MUHJZ..G\*?5YJ(`230.=7^'2I>7!,U?JMR^BS.641BW#QN0[*3;)M(-%R=5:
M2!^*<LW;PQ70'.90030`>2ICE`+FI>/$P;/"8*\P:GE3N[?EX453PY"?K$TZ
M=WR[%0,AQ);'"&6EH]\!RK,TG299/_6&:\FS/),"OR+0"0M5'[$@K(@I8RR5
MSDY%`PA5BF=+L8YM-OU=]#0T[W`[#R5-S`W:X'M_B5\O#E9L7R`Q@K9)9$BT
M1DR0E773<',<()^L(@=-LU`"\4@Z<1&X>WK8(._ZDXW.\H[YSJ$MN+8[!3^W
MC',\UNWEPX#5D`'&.0?J./J6JOXL\8*68>9S42VOBF62=AN'1;7K>9`W6_M`
M]_IJ*?+>7Q='98_E`&_R7%OJ6.U2WPM>SCG=,/\`*##ZUQU5(RV%*(E$2B)1
M$HB41*(E$2B)1$HB41*(E$2B)1$HBD^;?C/+OS//_>KNB*,41*(E$2B)1$HB
MW)?#)<<L#V:UO^ZRZ)7M_M$,*=_FZ^E_JJRNAW@>A:=J8?CQ']`_.NW3<.KL
MUW)HC0Q<(C$)5\RQO&I-X1>1CX\"-)##HT`4*M(.6Q%1,L!0L41'Y:@?R5U]
MICR\UKGLVJ)W06L^)C"V.22KV3N-*1M<1L)VF@X*8-49'F6H=.Y:W+&"25D;
M'&KFMH'1-XN(KM6,K'P[\A6"R;QA'1L<[!)4A5FN6,&[E(CI!1NY1[S9P`@5
M9NL=-0"F$IR&$HW`1OT>_P#ZE_*8DM-S<N;7_P!-+0TX[1Z1456B#RYU3O\`
M#C!_VC?45>)71OEP_;J,'\YA[ABX@)/%U6JCJ*;-QAI=,2.6I_LV!:K'(DN)
M5R`(FLL0!L8.138C_P#)3RD9WV#,<8<';(-M1UR4V[N&SDKG_P"W6JSW3\/A
MI3V^!ZFJ(OO"_P`@)KTB$KD^(.D&C=@R:E>9).JM6;6,8-XM@FD@3'E"ID:Q
M[1-(O`G+@0/;5/\`_*KRPB:71V^;%VTT$$-22:G?<`;3S*^__:_4KR`Z2UIT
MO?LX?ZM77T+XE[)U;M/',WGIO"7<3$)S2;MO#R4\XD%?M&"DHQ#L)/<;CVQ@
M(Z=D,?DJ6Q`$0N-@&,_-G_J%T5KS0=[I?*+7-(\QN'0ECIHX&QCPYXY78BRY
MD<*M8X"C#M(K05(V32N@<YR+/(<SNI;9T$8?4,<\N[S'-%`8VC>17;N6EKXM
MS,JNV_+)J4M@>ZU$`+U"YG6CH0J@W#K[RAC#^NKCRG).A,N<?WWR7,H'S+0M
M<##KZ<C=XMN?[J)<5M2JLVE$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB412
M?-OQGEWYGG_O5W1%&*(E$5[-<^/VS=F"@YAX,\;!K"`_Q%/=R-BA3'_M&@G2
M.\DR^T`%LDJ4#!8PEJD^5C-YV\ECKO-;.SJV1U9?=;M/IX#TD+R;:TEF&G7<
M>ED9H]['RYG18N6B5EEFC@S3LF616(X0;KM'1"."#P,6Q@OP,8"B(?8Y6R#N
M[POMAF5OF#28:A[=X._;\X5GJJ+()1%MV^&(ORA=P-;_`+F4PQ>W^TM,D3O\
MW7TM6ESO"U'4X[\)Z'>I=P.=^0^0>/OAGH39./043DCV2Q34,&NSFEGJ39-K
M+:[,_4<E.R436%PFXCDR@`C:QS7ZVKC[*]*6NJO,/-,GNY9(8V3W3P6`$U;/
MAIMJ*4<>P*:<PU'<:=T5E^9VT;)7NAMVD.)I1T-:[-M:M"PZ;?$I\HIINDKC
MVE<-?`[]YDX;8GL.7;KD*8W,4@99(CZFQ2&"Y#@`"`C\EJD!_D_HNV>1=YC<
M-P[P98&D==8S3TA:6WS-U5.T&VL875W$1S.!['BO:H&_^*1Y)E<'0/C&J8M=
ML=1NX:DQ?*BJ$72.)%".$W^:N5DEDCE$IB^[80L(7K*1>2ND,`<)KY[3M!\2
M+=T880"%CY/-;4V+"8K1KAL(P2;^FLI4><?$Y\GE@6!-S@;05!,)#-\2YF;@
M8;@"/JY-T!@('0.X!QM[;CUJZ9Y-:+:1B;=.ISEW]=&CY**V=YHZI=6AMVUY
M1[NUQ^6JW=Z+V>^SO6>K9C([N,GRK!L:G)AXU;-VK!62E()M*N3HH)J!V2',
MJ/N%*!2FZ!T"]07JO0\V3SWMW:OC&60SN#&XG%^#Q,#026TJ*[=OI4UY!GAS
M"PM#<@F\E@8YQ``;B+`XT`.[T+GJ^*TR[N]M_(VO]HZ]C`M;ZW<U;&,_DZC^
MZM71GE,:Z!R_H\?_`-YF4&Z_&'7$[NF`_P!W']"XA*E99E*(E$2B)1$HB41*
M(E$2B)1$HB41*(E$2B)1$HBE&:@(YIEH``B(Y1/```%Q$1EG8```'41$:(KT
M:X\6]GY_V'CI@&'P*O$WVID:2K=TLB8`'G'PH`60<B8H@)#*`@B<!Z*51?.Q
MF[:>A8>[SNRM:M!\27DWUG</E/0L_-;>+>L,!,V=KQ_\73Z8IB$MDA4%FR"X
M"'OL8D?^&LRE.`&*=0%EDQ#HK5F^X>[H'0M7N\ZO;ON`^'$>#=G:=_S#H73'
MXZ_!Y&1;1&5>06=H%CW2#60;8+K9VB[%RU633<-R2N;+(J,RHJ)B!5$XUNL4
MZ9N23THV&N?-2^=`B<^STY;GQ`2#+."*$;#AB!K7D7D4/M1E2AD/E5XC6W6>
MSC`0"(XC6H.T8I#LZPP&HW/6C3XB/BC)85D&W-'.4%G4GADNK/:^D%R!WI>,
M[!I3%W1#@0J1UYS'7OI5^`B1)THH01NF-IDTEG\6?Y+;9Q'0>,P8P/JO'=>W
MG0.!I7:6T/%:%>6<FEM226$I/@L?2I^M&[:QW8033B"%SN"`E$2F`2F*(@8H
M@("`@-A`0'J`@-;BMM7\HBVN?#!7LONML(_72UXN4/F[1\V3./Z^\']%6MS]
M7T^I:IJ<;(#]O^BNQ;R2_P"(?#2TFY^MZ&*T[U]X>/IH!>)_J%2WS?U5S1I#
M\+SCS)GO/N_E>'*1-3?B>6-B[W66WR,+5F;X'NA<>)NG50&_&+R%O\@_W/-,
MD:6Z?-V+?/4>>9S,&NLP;^G&>V&,^M;KH%V/2%D?T'CLE>/4N=3<Z`--Q;99
MVX^EV7G;;C:UNQE,JE8`N/LX5UKIYV/3]C)[UG">V-JYNSMN#.KQG*ZE'9(Y
M6UK+K%KI;\57/<U7HU4H]`U_AS<?THXZU:"'ZA):H#UVS%89DT^_(>R2JZ+T
MB[_E+`_N8Q^H`M1'Q2F'<\B<[3X_^:Z]Q\;6^OSQU6/Z6ZC?TUOGK=O*)^+0
MMHWBV28?WSSZU&WF2,&KY'\XXCV-`]2X4:EY95*(E$2B)1$HB41*(E$2B)1$
MHB41*(E$2B)1$HBZ"_%#P/S':N<9H&HM3/LWGV.8I(R.<OVZ(0F/N9+&L:R%
MZ57*);TT#!<'DRNJDDF<KQ1`0*4%1``'4L_U7D>GX?&S:Y9$UP):W>]XJ:86
M-JX\JTP@[R%K?Y=J'4-S\+ET<CX@7!U.[&*/<WO.-!6@&PFIX!3O8N`9-JS.
MLKUUF3((_)\.FWT%,-B'%5#U3)42`Y9KB1/U+!ZCQ6;J@4`504(<.A@J\RS,
M;7-LOAS.R=BM9XP]IXT/`C@1N(X$$+5[^QN,MO9;"[&&XB>6N'"HX@\0=X/$
M$%0X#6]OL^?Y:O".2M%U0_"U\@PV_P".[;"IM^"^8Z54:8B^%=4#.'6'JHJJ
MX3)GY#<$F\>V6C?G_P"&\C=3A?DKS9TY^2ZD-]`VEE?5D%-PDV>*WTDA_P!^
M@W+I+RWSS\TR$6DSJW=G1AKO,?\`9GT`%GW-N]8/?%D>:.V;DFOYC`LZ@)O:
M>,@_Q3,6D%W95F;%#&7D8P7LZR(K#!)P$T9RF#0JYE[/C]P"`F4!D;R;L=1Y
M?:W$.8V\D63RTDC<_NGQ-C748>_A>W"<1`;W!2M2M'\T;K([ZX@EL9V29I'5
MD@9WA@WBKAW:M=48:U[QK2BY)/+OQ7=:X-+[8QN13D,5F,@2-+0Y6)VSG&W<
MR*ACN2K$66;N(AS+7(3W4C('<)I`4P!SJ?(9<5&'>`M;R;-!<-;9RBDS6[#7
MV@/73KK0E8"U<+85EEXB>0C'06>2#C(6:SO#\O9LXK(%F9.X_B3LW1UH^:01
M`HG>(LO4K%60*('.FJ)B<CD*0]*6/&W9O"Q.;Y>[,(`(S29A)%=QYCT\"NG&
M"\I\NRWQY+I]G/Q&9ZKFG<-D.+2BBBS][!H,7(OB-,?DT79$RQ+I4P\VRZ:W
M8-<$^T(G`=*.D<H9J1NJ86NBS0,<U^&@9)B%,3VT]H#<YI;7ZV+937Y-09LS
M)7Z:N:.LP]I`<#CC+37"TU]D\B"!]6BO[J7SZW5IC6^-ZOQ"(UZK`XN,N+%[
M,PDZ]F7`34Y)3[DCUPCD[-B<J+V44*EVVZ0@D!0,)A#D.NY[Y6Z<U%F\V=7\
MEV+J?!B#'L#!@8U@H#&3M#16KCMK2FY9C*/,'/,DRR+*K-EL;>+%0N:\N.)S
MGFI#P-[C2@&RF]899KGR.599EF99!(PC*5R;(9S)IE-!RBR9-9";DG4J_(@B
MX=*J-6J3ET<"%.<QB$``$PB%ZWZPLHLNL(<OM\1@@A9&TNVG"QH:*D`5-!M-
M!MX+4+N>>_NY;V5OXTTCGG"#2KW%QH-NRIV;2H.MGV#M`*+S,\4;%.(@0SC(
MHA$#B'40**CPO(0`?DJZP$[@52$$YW,>?05D'COQ'\IU]"X_C.-^1&M,;C\1
M9(L8Y`SW5KIPBU;E`S8':DZVD%5!02^J(VN4?>O[:U^]TMD^8ME9>P.D9-7&
M,4@KBW^RX$5Z/0MGM-0:ILHHHK(R,9$`&TB:[=N]ICJT_P"U8S^0'GE@68%F
M]H;*W9AFR<D:Q";(C/&)S"WT]+)-Q7]!$Q\)BAVZ!0,LY,4%!1(DB4UU#E(6
MX7V39#8Y'9MRW*8?!LVDD-J]U"=YJ\N.WK5G>G/L^OQ<YB)'W+@!C<P,``W5
MHUK=G57@N7FMF6[I1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$7>+\%+?*
M#'*M\>.LRX32^V,N;;(P<5!*47$BWUSKV+RZ)*8WO*JJQC-F\03+T*1LZ/\`
M+7-'G1IYTEK9ZF@!.!@@EZ&DN=&[JQ%S2>;F!;%Y>9T&7UQD$QIB?)+'UB5[
M7M[`UP'(.*]_QC]#H1F3X+Y!P3=)/^+P3P+-$$N(+.)Z)9*NL8EP2"ZS@[R"
M;+,UCV`J16+<OM4JZ\DM0.FM;C3<Y),/XL70QQI(WHH\AP''&X\%A_-?)6Q7
M$.>P@`2_AR?::*L=Z6@M)X86\UIJCL1D7?%1U9BB-A_:!R<&#Z$0$.`_\\2B
M'S#4\J'P%=C&5Y'#V<PQQV9FHMOD3(D;D*3&5>LT9R/36*Y38RS=HLBW?,B.
M"`H"2A#$`X`-KA>K>:UMKA[)+B.-\D3L3"YH)8ZE*M)!+33944-%<13SP,>R
M%[V,D%'`$@.&^C@#M%>!6Z'Q(^'3JW.\&PW;NQ\P<YU&Y3&-YACB&-'<P<&U
M,)SHNXJ?F2G).2#R/>)*-W";46`).$C%!14H7&!=<>:V<Y9F5QD64VXMIH7E
MAEDH]YXAS&>PT.!#FEV.K2#1I4PZ2\N\KO[&'-\QF,\<K0X1LJUHYM<[VB0:
M@AN&A!VD+!7XF/B;CF"9WDV&L8<L=JK<.,.GF.-FR9C-H5T*9&4Y&,#+&$/4
MP$QVGS<OL12=-RW$2UOOEAJJ74F0!UX_'FMJ_!*3O<#MC>?M-JTGBYCBM5UM
MDHTSJ!L]BW!8R@21@;@1L>ST';3@UX"YC]?^`F]LTGY&/EHYIA&/14L]C'&3
MY$)RDD2,72C91WCT,C>2E6[@J8*(*G!NU63,`E6J5#,P#9M*^RYS9QQA[27/
M(!H.%1Q.X=/'H51\FO"&8T'B:.>0V7?QIC))!A&3!584T1)0JS\ITF[]8$G\
M@U7C'#\A40-R3.FJNF3B>XGI'*'FA%"OEAFS+R3P7-P24)&VH/S;5A$VF9=D
MV49,Y62:,U3]Q5HV?.D&RJGN^^H@DJ5(Y_<#J("/0/FJK0+*EC'&K@">I>5P
M[=NQ*+IRX<B0!`@N%E%A(!K<@**AC<0&P7M1?0`-P`7GHOJ41*(E$2B)1$HB
M41*(E$2B)1$HB41*(E$2B)1$HB41*(E$76`\E?Y<[VA]F::R4F.9%C6#^-4D
MJ\B63-PDQS(WB3HM')R]MVFYCWHR+EVX+()+(J$4657(H4W(P!'>49<<YT_<
M9;GL>.SEN[MM'$@NC^+F,>ZA;0!N`@U`#2."P6IKS\LU'#?Y._!<QP1&H`H)
M,%'[Z@U).,$4J2#Q5]<`T_Y(^9^7/YYLZF<[?,UTV<WGF<3QRPN/%=76(R*Z
M<BJ+-L!??*PBVI^!!N5`"]:I9EG6C_+RQ;;O;';-<"611,K))396@WGACD<`
M3O=56=CE6IM:7;IFE\[FFCI)'48RO"IW#CA8TTX-41\A]"Y3XX;%5U[E3MK*
MJ&AHF<BYV/1<(1TPPDD!*LLS(Y`%^#&5;N6AN8`8QVXFL`&`*R.E=366K<I&
M:V+7,'B.8YCB"YKFG8#39M:6NV<'4X*QU%D-UIS,3E]T0\X&N:X`@.!&\5V[
M'`M]%58X`$P@!0$PCT``"XB(_(`!UO6QTX+![ULQ\0O-B0\=-79;@LWBK_+>
M<RG-8"V&11CF48M)(*IY`UE'*B;ITWCO4MF[E%)%`XG65<7%/D!JBO6_EB-7
M9S!F<,[+8>'@F.$N<X-/<+1L!=0N:2YPH`V@-**2=(ZW?IS*YK&:)TW?Q1#%
M0-)'?#CM(%0"`!M)=NK56:WOY*[+\AY!@XSUQ$IQ4*X<N<?QZ&BT&D;"J/"$
M2<*(.%O52[E9=)(@',NY4`>(<0*'2MLTMHK)-(PN;E;7FXD`#Y'N)<^FZH%&
M`"IIA:-^TE8//]2YIJ.1KK\L$+"2QC6@!M=]#M<:[*U<?0L__%GP#UKFV%XE
MM38&6.,VCLEC4)9EBN.G<PT,V$3'1=1DW+E,2:?NV#M)1!<C86()+I&*"BA0
MN,4:Y\V,ZRS,KC(LIMQ;30O+#+)1[SQ#F,]AH<"'-+L=6D&C2M_TKY?99>V4
M.;9C,9XY6APC95K1S:YWM$@U!#<-"-Y"PB^)!XJ8WB^697@Z,25AJW<&+NUX
M%!NF)D(5R=(C*98,#*F$/5P$QVG[</8BFX;A<1*-;]Y7ZJEU+I\&\?CS6U?@
ME)WN!VQO/VFU:3Q<QQ6KZTR8:<SYLUDW#92@/C`W`C8]GH.VG!K@%Q1YKB,Q
M@.79)A<^CV)C&)A]#/R`!NV=9BN=$'"`F`!4:NTR@JD?V'2.4P=!J50:BH5W
M%(V:-LK/9<*A1>OJJ)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$H
MB41*(NSOX8^L];;6\D\\A-@)QLW",63B5A,=ET.ZVR=^75>L(Q!`R"A>V8T;
M$2*[\A;@<BC4IRA[@B6)O-+-<UR#2XER@O9,9XV.D;L,;:N-=F[$YK6'A1Q!
MWJST=EV7YQJ;P\S#7QB&9P8[:'N\1XITX0XN'&K0>"RS\6IJ3\//-+*]$92\
M5)B.;RJ6'HO'(]M!TJZ4&1U?DI@`"I"O((R!62@%'@D>04`1NETUC6EO#KWR
M^@U+9M'Q]LPRD#>`.[<1\Z-+<8XD,'-7^EYI-'ZTER*Z<?A)W^'4\:[8'^FN
M$\`7GDI5\3C8>K-@9#CN`P[>0=[#UK)NT9S(VZ;9.';1LLR(J_Q85C'%U(23
M9Z@U6$P$[#0W=3`3*'4*G3\F,BSO+K.7-KES&Y1>,!9&:EY<TT;)3<UI!<-]
M7;#0``FX\SLRRJ_N(\OA#G9C;.(<\4P@.&UG,N!#3R;M&TDTPMT;XS[+W>^<
M-=;XXBLPCUT6TSD\L[3CX2(.N03D*]?*`HY75%/WNPU177XCR[?'K4EZDUAD
M6E(A)FTI$SP2R-H+I'TY#<!TN+6\*U6E9'IG-,]>69;&#&T@.>XT:VO,[SU-
M!/0OKOS1^2^/^?JX'DKIM)J&B8N:CIEBBNC'RS&00$JJS0CFRP$9R;=PU-R`
M!,9`36`#`%5=*:HLM6Y2,ULFN8/$<QS'$%S7-.P&FS:TM=LX.IP7S/\`([K3
MV8&PN2''`UP<*@.!&\5V['`M]"LK6S+"+</\,/<W(F4Z-F7?4@K9GA0+'_L&
M%%OD\0@)AZ<3"@\22+[>3D_R"-<[>=VFZ&#5%LW8:0S4])B>?UF$G]`*8_*_
M.MDN13']Y'\SVCY'`?:*R\\XM,_S?T9.'C6GJ,LP+NYGC?;)R<N21[=3[>B$
MN)#K*?:<-W!32+^]=H(!\E1]Y8:C_P`O:HB;,ZEA=TADKN!<?PWG@,+Z`D[F
M.>MNUUDOYQD,AB;6[M_Q&<S0=]O/O-K0<7!JX+?B6:=^S9_'-U1#2S3(B(XK
MEYDB="3<>V.>`DEQ`!$32$0W.V,8;%+Z)(/:>NT(';,)4)Y%=8F.M7':W:WJ
M._L/SK5;5PMA2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41
M=,'A_MZ2P?+6^TL7>D=R^'9YC3P>"QBD?!%:\P2)F(EVH4!."4B@V<L77]JQ
ME`]M:YGV5P9WED^57?[&>-S2>())+7#I:ZCAT@+2VWMQDV<PWT(I-#(YP',>
M(_9U.::'H*W^^>&FGWD'B&F_(S1L1+9/-/F<.P70QQHNYFW6,39#3>.RQD6=
MU6Z^+2BBR+D;\T!=7.)2H&$O/_EIG\6E[^_TIJ21D-NUSG`R$!@D9W)&U.PB
M1M"W@<.RI<%*>O,F?J"SL]1Y&Q\LSFM!#!5Q8[O,=LW%CJ@\L6VF%8N>#^%8
MGN'R$>M]M+)Y,HICF5Y":.R4ZTBXR[)'1T6SM206=BHH]?-V\FZD3'4,*PKH
M`KU$IA"1O,W,K_3FD6.R`&$":*/%'1HBC%2,('L@EK8]@I1U.(6IZ'L;3.=1
M.;FQ$I,<C\+]ID>:`UKO(#G/V[:BO!7E\:I>1\3O+[)]*9([4+BV92:>*).W
M!N"+I5R<TAK?(3``%2%9\B_!HH`#P2.^4`1_9UKFM+>'7OE[!J6S:/CK9GBD
M#>*=VXCYT:6XQQ(8.:S.F9I-):PER2Y)^$F=X=3QKMA?UFN$\L1Y+(SXFF'X
MA+ZSQS+'4Y!1><8G*@G#QCR0:-IC)L>FED&DNPC6)U2.Y`\:[(@[`2E,5%)-
M?V"IUT[R4S',+?.IK".*5^5W$??<&DLCD8"6.<ZE&XAB9P));R6Q^9UG9S99
M'=O?&R^B?W6D@.>QU`X-&\X31W0`[FM)$-"S&1232&@(F2G)=^H"+&+B&+F2
MD7BH@(@DU9,TEG*ZE@O8I1&U=-3W5O9PNN+N1D5NP5<Y[@UH',N)`'I4(0P3
M7,HAMV.DF<:!K07$]0%25M.\3_!C=F.YUANV<NEV>LB8W*-I=K"&*29R>6:B
M4R3V+?M&CE*/AF,Q&KJ-UA4<*.2$5,`H%-U"#->^:.F;S*[G(,OC=>F9A87^
MQ$P[VN:2"Y[F.`<*-#20.\0I3TGH7.[:_AS:[>+41.#@WVGN'%I`-&AP)!J2
MX`GNA;F'4E',EFC9X^9MG#]4$&3=PX226>+#[$FR1S@=<_T%`:Y?NLSRZRFB
MMKR>&*XG?AB8Y[6ND=[K&D@N/0`5.,5M<3L?)#&]T<8JX@$AHYD[@.M<KGQ)
M?%&-99)M;3RC5)GBFP8Q7*=?.A2`&\2$BX5?P_9*0#"1/%<H9';\`'N*-4"\
MK`KU[E\N]2'4FF8+V1U;Z+\*;F7L`[QZ7M+7GA5Q`W+F34^6.TWJ1XA%+5Q\
M1@_0>35H^R<31T`'BN-N:AY+'IB5@9AJHQEH21>Q,HR6"RK20CG*K1XV4#_/
M1<(F*/TA4BC;M658YKVA[=K2*CJ*IE%Z2B)1$HB41*(E$2B)1$HB41*(E$2B
M)1$HB41*(E$2B)1$HBVL>&>SD6.>;.UH_5(F+G+L@R**$YK=XJTEZ"20"X@6
M[55%NH0`ZB558P]"U:7+=H?Z%JFH[4AS+QN[V3\I!^<=B[$/A6[P^W<.R71<
MT\YR>%J+93AY%3W.KBTN\*6;8(`(WX0V0.BK=>HA)6#H3IS'YT:=^&OX=26[
M?P;@".6G"1H[CC]M@I_N^E2;Y5YYX]G)D4[OQ8>_']AQ[P'V7FOW^A89;=D9
MG1'E4^V%CD)_#:L?G3K*64&1T99J0XOU"9)!`[*V;`:-E.\N0`(D4I6;LI2=
M+#4IZ<CMM5Z$;E%[)XP=;")SZ4/L_AOI4]YM&G:=KV$E1_?WLV4:JDOX(O!E
MBNG.P5J!M[S:T%6NV[@.Z[9L6='FQJ&1WSBVH]^:2B9+)9M^UB(\[>"0.I+.
M\>FBC+X])J`@8!:*XU)J*I.3F,`H>JN<Q2HF$(Q\M-00Z5OLPTIJ:1D-LQSW
M5>>Z)&=R1NW>)&T+1];#L!+@I$UOD\F?VEGG^2,=+.X-%&CO%CN\QVS=@=4'
MEBVT#5$-;?#JSW/93^-/)+/Y)-]('*Y?0D;*_P`1Y:\,(@(IS.62!GT<S.00
M$!*W*_`2#[JJ8A5_G/G!E650?ENC;1AB8*->YOAQ#[$3<+C][!MW@JRRWRYS
M"_E^-U+<.$CMI:UV.0_:D-0/1CV<0MA6,XGH7QNB31N*P<%C"ZB)2N`9)#)Y
M;+@``8GVC(N#N9ETF<X<B>H6*W(81X\0Z5S#YA><5A9/,^LLS+[H;66[3B?T
M8(&;&`[L;@T'BY31IC0Q:SPLALPR([#(10'[4CJEU.0)(X!1:<W%G61'598/
MCSN-:"9DD>15;E=O2A*%4-'J*+'*,9%D>)IF$ACB?ZHB"@6KF+4'G1K/4#G6
M>BK"2UM:L!F<T22_B@F,DG\&$/`-"<>XD2"BE3+]%Y/8`39U.V67O'`#A;W*
M8MGMOPFE:4W[6E8\*2TRO+$DW+Y^O-(NDEBNG*RR[XCMNJ!TAY+"=7N)+%#B
M'R"%K5SQ)FF=7&;MS*>:XESMLS7->]SGRB1K@6T+JNQ!P%!P.P!2$VULH[0V
MS&1MLBP@M``;A(V[ME"-Y53\W=?H;T\<XS:D&U*IE.M"N)URB@4QUA@52HM<
MVC@*`A9./,U2D2G/<2MV9^(75Z_K5_TU^9-OFS;6Y+@VUS6(1R-X1W4=0!MV
MT+\;&C9B$D;CLHN.?-[2<D5O+A!-Q8O+VGBZ%U,78W"\\L+AO7"S\1K3O\([
M)C=HQ+7MP>QD11EQ2)9)KF$0@DDX,?B`$2^VHL$EBA]91=%P<>M=RPNJ,/)0
MGDESXD!MW'OLW?9/T'U+7)599M*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1
M$HB41*(E$2B*[#7,7^`;F>9?'"<5X3.)ERJB0W#U;(TJ\0D6)C?V2/F"JB0C
M\G._M"O+VA[2T\5;W=NVZMWV[]SAV'@?0=JZ:_$?R&)@F;:SW9C#X)2-CWC1
M2839*D4^U\;DD"M9Z..4#]L'3N&=G$A5/W#K@80Y)A;3]49%%J'([G)YJ!TK
M#A)^K(W:QW4'`5IO;4<5I^29E/I[.H;ZA#HGT>WFP]UX]+2:=-#P6[/X@&KX
M[-,3@-Q8B*,DQEXUC))2#(.XB_*:-(\8/$E`"ZB4WCG4E@]XS-/Y35!WE/GD
MN5YE)D%_5CVO+"T[V]ZA!Z62;^AYY*2/,?*XWNAU#9T=;W#&AQ&XG#5COO,V
M?='-53X9>Y?MO$LATM,.^4CB"BN2XH54]SJXS*.REF&*("/U(B=<@M\XA(6#
MH3I\\Z].?#9A#J6W;^#<`1RTX2-'<)^VP4_W?2LQY8YUX]I)DDQ_$A)?'TL<
M>\!]EQK]_H5_=@;@SA:3DX%`"XNDQ=N&2Z3!0QY`XHJ&3$QI,Y$U"E/;D0R!
M$;E$.H@-?EMYA><.N9LSNL@@IE<4$KXG-B),IPDBIG(!`.]IB;'4$;2"NO\`
M3VCLC9:Q7\G_`#3Y&!P+A1@J*^P*C9N(<7;>`4.PQ[C+7U$ID,<ED\@JN^3-
M'OEW*(MT1C50;/D3IG<#(/7LDZ`1Y-79&Q&@B=,>\51*/M+39(QS[_-[<9CF
M#WR#PGN>"T>$[#(T@O,LCY'5-89FQ-A)>P^*U\>P9I'>D-@LY/A[<-;W@!0G
M$*M-:86M:.#V%Q>`#W2'5B=V,\?N"C'D;L51BXV",HP(924?,XL2_9R;Q^!U
M#.E0M[Z@K*@L;@95$ZB28IY7.-9RW$X,!CBE^'BMR(1BFD9#3PA)-4M<=G>>
M))<1+#)"]\;3'9VF4-C91X<YOB.D[^QC2_VBUFPCH;A;05#7@..+R,->9;*+
M.BN6AX%56,=2Z#9ZW<%E9FZS=L1FW031%4'3YW(-DP36%J@(N$S```<M_%IH
MK4M\^5ES&<MQV[Y1&YKC<W`JUF`-`#L4CY(FEDAMX7>)&]K.\VOJ;.,NA#71
MN^(I(&EP(\./83BKNHT-><31(\87`G85.]&9$W3?R6#S+7N066-5Q:M9`A5V
MKASZ3M/6JA5$DT%T)2.$2G`2V-P(6P\NLD>0.JY\CSYVGI1-;V-]2:U+R:B>
M-H)+'X6`^(P`@@;"R,"I-3K.OLICOK`9@,$DT'<E`&PQN)&T5=[)V4)W.<>"
MYO/B.>))T_YO:*,W,=5HJ.4:ND'74RH%*I*X>N#M4B9#*+ME#Q3U8H<2G,X`
M/97[1Z.U#'J3(+;.&T\5[*2@?5E;W9!2IH,0Q-!-<!:>*X)S6Q?IG4,EH:^`
MU_=/O1.VM/"I`V&FS$TA<E*Z"S5=9LY24;N&ZJB#A!8ADUD5D3BFJDJF<`.F
MHF<H@8H@`@(6&MQ6>!!%1N7RHOJ41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2
MB)1$HB41*(I/FWXSR[\SS_WJ[HBRY\%=L&PC:(X3)NQ3Q[8Q$HU(BJ@@@VRE
MKW#P:Y0,(@0\B!U&0@4`%119&XV(%4)V8F8AO"P6?6GCVOCM'XD>W[O'LW]J
M[CO`?8#3?/CAEF@LC=IJ9+KM$$(%5R?DL?&I!95]C#PHG$552X]-HJ-%0('%
M-F+=,1]^U<O>9N6/TUJR#4]HTBTNCWZ;O$:`V0<AXC"'"NTOQG@MYT7<QZGT
MI<::NB/B8&T83[I.*,\^X\833<W".*P'@,BE?%[R1C<@;I*I)8QD(C*Q"9R]
MY7')$ZS#(8)5+EP*X2:'<)(]RX%6235MT`:F">VM]=:+?:/(+YHJ-=P$C:.C
M?U$X7&F\$M4=Y7>W.F\\CNG-<U\,A#V\2VI:]O94#D0#P6Y[=T/&2'\.[)@U
M"2$#E,>R,=ZR4*"+L'#$CN&D4EA34`R<C&&+Q'C82I!\IJ_'W_J*T8<JSR+4
M\D+Q'*XV]TT$-<V>,$,)):X`N:TM/=/[*F]U5WYY<YVV]L'9;&]IHT2Q'>#&
M^A--HJ`2"-OUJ\%!\1U_,96071U4(?'4'*B$D[2,FJHCZ5))VY(+0%Q>.ED$
M5`-Q.)Q1$P7`I+B$7:<T9F>H8S+.^.RR!KRV7PZ.<,`;(X/;C,CG-!K21SWP
MN(JQK-VUYCG-ME[L$8=-?EM6XJ@=XEH(-`T`\VAH>![1*NI!)0F'2&/K8>UC
MYF5CW#Y&7>O@*U(L"Z+61C7#R9-(/F4$_B'[),4A9*HBX14$AC(*F#N2'E,.
M5Z5O+.734=O)?0/D$SY*->[$ULD9DG,D@MY8GL:6>"^%LK'%I=!(\8]>NWW.
M:0S#,G2-@>UI8UM2!0EK@UF%OB-<UQKC#RUP!`>T'#;39NT6L5#HLW^:M$5D
MGC@H1T0"RL:W:'4>BX"/>'67>K@<[X@%0:IBDBD''W2ID"L3F$VJ-30-RG3,
MC[BXCF<'&%O_`"T+3XCG4N9'8(\6-I9%'M8T8&NHQ@->+\JRIYN\T#8HW,!`
M>?Q'D80/PFC$ZE"'.=L)VD;7%8=3&[WS)R5YBI3QKEFJ#Q*>D!3,Y;KH""Q7
M:+8QE&R9T%2<P.L94I@^LF'4*W'1GDPS*LQ@SK/KE]QFT4S9&QPES6>(UV(%
MTFR60DT/=\(UJ"7`K7,\UTZ[MY+'+8A%:.86ESP"["10T;M8VFT;<>S@%H<\
MIOB,8-CV4Y`,OF\KOC9#95PP[T;,?:\0W,W56%NU>92HJM%LH]!0Y@]+'@Y%
ML813%),;V_9/2D%J<AM9K&T%C;RPM>8?#\,L<YHQ!S:`EP.PN.UU,536JXAS
M++,SN\TF^.G,V"1S?%+L6)H)H6[3L(V@;`*TZ%SJ3,L^GI>5G9187$G-23Z6
MD7`A85WTBZ5>.UA`.@"JX6,:WTUM0V;%FFM#&AC?9`H/0J;1>DHB41*(E$2B
M)1$HB41*(E$2B)1$HB41*(E$2B)1$HB412?-OQGEWYGG_O5W1%1XHTD23CCP
MWJQEROV9HH&!%3OQDBN$Q8^B(B!ECN_5`7M@0!,)[6ZU\-*;=R\OPX3CI@IM
MKNIQJNHSQ3SW?N18ZWR+6..;BQS93O!G#7.X3#,0S=ME[-@DO'ER$R,=%1(S
MH0J\LV;J)+-R"'[1$H&`Y@+6J9_'I\P,_P`Q&T^!$P+/B"P1^)1V']H<)=A+
MJ#::5--BTRRCS>WS"6+3SIGS%A%8*N=X9+=Y94@5PU.RAIM5EL:W?*R.X3X:
M75FZ`CY9Y(-LBSO)M?Y7!P<9.M$'3A-1\>8C$Y-,7[I$R"JKQ-IQ64`3<@N(
M9B&-@;CB<SPZ"@:1Z*4V4IR7V2UE;:8[E[/B&D[,0+C4[:[=X/6NH+PTGIS,
M?&-[@VS(J9QAEC14$<*R[*XU_"P4YC<N*LCC#B(G99%LPE0B)%)5N(-U#E(S
M].7V'KAW_J<T[I:^@OH[F]L8;:]B(>7S1-%O=QD8#)5P\/$\,=1U'//B#B5T
M9Y.9KG,4,`%O<.EMW]RD;SXL#JDAIIWL(Q#94-&`KQGD\GB,?E0CFF2NH,%R
MHRH8['R\NT<.TU"*MBN#QR;ID@J)TR%35$4BF`0`3B`U^9FF,MU=F=K/E>1R
M-M\K$@%Q,9L$.(.!:7/+G"HH`#`W$YI&(.:5U9FMWE-I(RZOFNENL-8V!F)]
M*;0&@`T/[PT!W4*L#.9GLAXS>(8YBF31<.*R!73L\/).%%%?]8!H*Y`;&CFJ
MQTQ/P`P*J%$#"0X=:EG2VA?+W*[4W.=9Q9WX#F%[1<QLM6OWLQ-$GXCA1X;X
MCL+FEWX8VK2LWU#J:[E\*PL9[<$&A\)[I2WC0EO=!V5PBH-.\M6GD;Y99UK5
M[)PF">-WD5N3.T3'17=)ZKV1%8@Q<E`A`%YDTABZSV9`J9@.F$>V<-EB%X^I
M3Z#79&A/+[(,XLX+J[SO(\NR`L!C;'=6KWN9P\-D<OAL:=W><"W_`%94,YUG
M686T[XQ:7D]_4XB^.04=QQ%S<1/HV^\M%'DWMGSYVM%2DIN+"MP8%K5&PO,>
M9:WS?`]=LD#B0I$Y==[')GER"H7D495X[$IQ'AQ"P!U?HC(O*K(IF6^F;G+K
MK.2-DAN(9[AW,MPN.'I$36#F%'&;7>H;MI?F#)X[:N[`YC!VC;]XDK7O4LK7
G4HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$2B)1$HB41*(E$7__9
`
end    
__EOS__

    $resources{t}=<<'__EOS__';
begin 644 uuencode.uu
M1TE&.#EA`0`!`)'_`/___P```,#`P````"'Y!`$```(`+``````!``$`0`("
35`$`.^T/HYRTVHNSWKS[5P``.P``
`
end
__EOS__

#`
    if( exists($resources{$name}) ) {
	return uudecode($resources{$name});
    } 
    
    return "";	
}


sub locateExecutables {
    my ($form)=@_;    
    my ($env,@paths,@utils,$full_path,$cgi_bin);

    @paths=("/bin","/sbin","/usr/bin","/usr/local/bin","/usr/local/mysql/bin");
    @utils=("tar","uname","wget","lynx","mysql","ldd","mv","mysql_config","mysqladmin");
    
    $cgi_bin=$ENV{SCRIPT_FILENAME};
    $cgi_bin=~s,^(.*/).*$,$1,;
    push(@paths,$cgi_bin);
    
    push(@paths,split(/:/,$ENV{PATH}));
    $env={};

    foreach my $util (@utils) {
	if( $form->{"path_$util"} ) {
	    if( -e $form->{"path_$util"} && -f _ && -x _ ) {
		$env->{$util}=$form->{"path_$util"};
	    }
	} else {
	    foreach my $path (@paths) {
		$full_path=$path."/".$util;
		if( -e $full_path && -f _ && -x _ ) {
		    $env->{$util}=$full_path;
		    last;
		}
	    }
	}
    }
    
    return $env;
}


sub checkSystemUtils {
    my ($form)=@_;
    my ($env,@not_found,@utils);

    @utils=("tar","uname","wget","lynx","mysql","ldd","mv");
    $env=locateExecutables($form);

    print "Content-type: text/plain\n\n";

    if (!defined($env->{lynx}) && defined($env->{wget}) ) {
	$env->{lynx}="/bin/sh";
    }

    if (isLWPAvailable()) {
    	if (!defined($env->{lynx})) {
		$env->{lynx}="/bin/sh";
    	}
	
    	if (!defined($env->{wget})) {
		$env->{wget}="/bin/sh";
	}
    }    
    grep { push(@not_found,$_) unless defined $env->{$_} } @utils;
    print scalar(@not_found) ? join(";",@not_found) : "ok";
}


sub executeSQL {
    my ($env,$form,$sql)=@_;
    my ($res);
    
    my $mysqlPort = '';
    if ($form->{mysql_port}) {
	chomp($form->{mysql_port});
	if ($form->{mysql_port}=~/^\d+$/) {
	    $mysqlPort = " -P$form->{mysql_port} ";
	} else {
	    $mysqlPort = " --socket=$form->{mysql_port} ";
	}
    }
    $res=`$env->{mysql} -e '$sql' -h $form->{mysql_host} $mysqlPort -u $form->{mysql_user} -p"$form->{mysql_password}" $form->{mysql_base} 2>&1`;
    if($res=~/ERROR/i ) {
	print "Content-type: text/plain\n\n$res";
	exit;
    }
    return $res;
}


sub checkMysqlAccess {
    my ($form)=@_;
    my ($env,$res);
    
    $env=locateExecutables($form);
    
    $res=executeSQL($env,$form,"select version() as srv_version");
    my ($major,$minor)=($res=~/srv_version.+?(\d+)\.(\d+)/s);

    executeSQL($env,$form,"create table djem_test ( id int not null, primary key(id) )");
    executeSQL($env,$form,"drop table djem_test");    
    executeSQL($env,$form,"create temporary table djem_test ( id int not null, primary key(id) )");
    
    my $gotDJEM = '';
    if (executeSQL($env, $form, "show tables like \"documents\"") ne '') {
	if (executeSQL($env, $form, "select document_id from documents where document_id=1") ne '') {
	    $gotDJEM = '.installed';
	}
    }
    
    print "Content-type: text/plain\n\nok: $major.$minor$gotDJEM";
}


sub getUname {
    my ($env)=@_;
    my ($uname,$name,$ver);
    $uname=`$env->{uname} -a`;

    ($name,undef,$ver)=(split(/\s+/,$uname));
    $ver=~s/[^0-9\.]//g;

    return "$name $ver";
}

sub getArch {
    my ($env)=@_;
    my ($arch);
    
    $arch = `$env->{uname} -a`;
    return "amd64" if $arch =~ /amd64/i;
    
    $arch=`$env->{uname} -m`;
    chomp($arch);
    
    $arch="i386" if $arch eq "i686";

    return $arch;
}


sub getCgiPath {
    my ($cgi_bin);

    $cgi_bin=$ENV{SCRIPT_FILENAME};
    $cgi_bin=~s,^(.*/).*$,$1,;

    $cgi_bin.="/djem/";
    $cgi_bin=~s,//,/,g;

    return $cgi_bin;
}


sub getHtdocsPath {
    use Cwd 'realpath';
    return realpath($ENV{DOCUMENT_ROOT});
}

sub getMySQLSocket {
    my ($env)=@_;
    my ($sock_path);
    
    $sock_path=`$env->{mysql_config} --socket`;
    chomp $sock_path;

    if (!$sock_path) {
	$sock_path=`$env->{mysqladmin} --print-defaults`;
	($sock_path)=$sock_path=~/--socket=(\S*)/;
	chomp $sock_path;
    }
    $sock_path||="/tmp/mysql.sock";
    
    return $sock_path;
}

sub checkPathPermissions {
    my ($form)=@_;
    my ($err);
    
    print "Content-type: text/plain\n\n";

    $err="ok";
        
    if( -e $form->{cgi_path} ) {
	if( -d _ ) {
	    $err="CGI: 1" unless  -w _;
	} else {
	    $err="CGI: 2";
	}
    } else {
	unless( mkdir($form->{cgi_path},0755) ) {
	    $err="CGI: 3";
	}
    }
    
    if( $err ne "ok" ) {
	print $err;
	return;
    }
    
    if( -e $form->{htdocs_path} ) {
	if( -d _ ) {
	    $err="HTDOCS: 1" unless -w _;
	    mkdir("$form->{htdocs_path}/tmp",0755);
	} else {
	    $err="HTDOCS: 2";
	}
    } else {
	$err="HTDOCS: 3";
    }
    
    print $err;
}



sub getImage {
    my ($name)=@_;
    
    if( $name eq "setup" ) {
	print "Content-type: image/jpeg\n\n";
	print getBinaryResource("setup");
    } else {
	print "Content-type: image/gif\n\n";
	print getBinaryResource("t");
    }
}

sub isLWPAvailable {
    eval "use LWP;";
    return ( $@ ? 0 : 1 );
}

sub isWgetAvailable {
    my ($env)=@_;
    my ($res);
    
    $res=`$env->{wget} --help`;
    
    return ( $res=~/--post-file/s );
}

sub isLynxAvailable {
    my ($env)=@_;
    my ($res);

    $res=`$env->{lynx} --help`;
    
    return ( $res=~/-post_data/s );
}


sub getTmpName {
    my ($name,$fh);
    
    do {
	$name=tmpnam();
    } until $fh=IO::File->new($name,O_RDWR|O_CREAT|O_EXCL);

    END {
	unlink($name);
    }

    return $name;
}


sub htmlDie {
    my ($msg)=@_;
    
    print "Content-type: text/plain; charset=windows-1251\n\n";
    print "ERROR: $msg";
    exit;
}


sub getInstallPaths {
    my @paths;
    my $cgiPath = getcwd();
    
    my @files = <$cgiPath/*>;
    my $file;
    
    foreach $file (@files) {
	if ($file eq '..') { next; }
	if (-f $file) { next; } 
		
	if (-e $file . '/' . 'djemserver') { 
	    push(@paths, $file . '/');
	}
    } 

    return join(';', @paths);
}


sub showInterface {
    my ($cgi_path,$htdocs_path,$sys_libs,$uname,$hostName,$env,$arch);

    $env=locateExecutables(undef);
    $cgi_path=getCgiPath();
    $htdocs_path=getHtdocsPath();
    $sys_libs=getSystemLibraries();
    $uname=getUname($env);
    $arch=getArch($env);
    $hostName = $ENV{SERVER_NAME};
    
    my $mysql_sock=getMySQLSocket($env);    
    my $installPaths = getInstallPaths();
    my $installPathsRadio = '' ;
    my $defaultChecked = ' checked';
    my $path;
    
    if ($installPaths) {
	my $rCnt = 0;
	$defaultChecked = '';
	
	foreach $path (split(';', $installPaths)) {
	    my $isChecked = $rCnt++ == 0 ? ' checked' : '';
	    $installPathsRadio .= "<label for=\"action$rCnt\"><input type=\"radio\" name=\"djem_path\" id=\"action$rCnt\" value=\"$path\" $isChecked>  DJEM   $path</label>";
	}    
    }
    
#`
    print "Content-type: text/html; charset=windows-1251\n\n";
    print <<__EOS__;
<html>
<head>
  <meta http-equiv="Content-type" content="text/html; charset=windows-1251">
  <link rel="shortcut icon" href="http://djem.ru/favicon.ico">
  <title>DJEM Installer</title>
  <style>
    BODY {background-color: #efefef; margin:  1em 1em 3em 2em; font-family: Verdana}
    p.menu {font-size: 70%}
    p.menu2 {font-size: 70%}
    FORM {margin: 0}
    .search {font-size: 65%; font-family: verdana}
    .submit {font-size: 65%; font-family: verdana; margin-bottom: 0em}
    td.research {padding: 0.6em 0.6em 0.3em 0; font-size: 75%; margin: 0 0 0 0; }
    td.research1 { padding: 0.9em 0.6em 0.3em 0; font-size: 75%; margin: 0 0 0 0; }
    LABEL { display: block; margin-bottom: 4px; color: black; cursor: pointer; }
    #mb06 {margin-bottom: 0.6em}
    #mb15 {margin-bottom: 1.5em}
    #r {color: #970000}
    #b {color: #000000}
  </style>

__EOS__


    if (-e 'install2.done') { 
	print <<__EOS__;

</head>
<body>
<table width=100% cellspacing=0 cellpadding=0 border=0>
<tr valign=top>
  <td width=25%><center><img src="$ENV{SCRIPT_NAME}?action=getImage&name=setup" alt=""></center></td>
  <td style="padding: 1.2em 2.4em">
    <table width=100% cellspacing=0 cellpadding=0 border=0 style="border-bottom: 1px solid silver">
    <tr valign=top>
      <td style="padding: 0.3em 0.6em 0.3em 0"><h1>  DJEM</h1></td>
    </tr>
    </table>
 
    <div style="height: 450" id=div_welcome>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g"> !</span></h3>
    	<div style="color: gray; font-size: 80%">
    	    <P id=b>          DJEM.</P>
    	    <P id=b> ,          . 
		         ,
		  install2.done     .
	    </P>
    	</div>
    </div>
  </td>
</tr>
</table>

</body>
</html>
	
__EOS__
    
    } else {
  

	print <<__EOS__;
 
 
  
  <script>
      var request = false;
      try {
  	request = new XMLHttpRequest();
      } catch (fails) {
  	try {
  	    request = new ActiveXObject("Msxml2.XMLHTTP");
  	} catch (othermicrosoft) {
  	    try {
  		request = new ActiveXObject("Microsoft.XMLHTTP");
  	    } catch (failed) {
  		request = false;
  	    }
  	}
      } 
      
      
      var state = 'welcome';
      var utilitiesChecked = false;
      var mysqlChecked = false;
    
      var serverPath = '$ENV{SCRIPT_NAME}';
      var installPaths = '$installPaths';
      var cgiPath = '$cgi_path';
  
 
      function SetText(elName, text) {
        var el = document.getElementById(elName);
	if (el) {
	    el.innerHTML = text;
	}
      }

      function SetValue(elName, value) {
        var el = document.getElementById(elName);
	if (el) {
	    el.value = value;
	}
      }
      
      function DisableButton(buttonName, isDisabled) {
          el = document.getElementById(buttonName); 
	  if (el) {
  	      el.disabled = isDisabled;
	  }
      }

      function ShowEl(elementName, show) {
          el = document.getElementById(elementName); 
	  if (el) {
	      if (show !== true && show !== false) {
	        el.style.display = show;
	      } else if (show) {
	        var displayAttr = el.getAttribute('disp'); 
  	        el.style.display = displayAttr ? displayAttr : 'block';
	      } else {
	        el.setAttribute('disp', el.style.display);
		el.style.display = 'none';
	      }
	  }
      }
  
  
      function ButtonNext() {
  	switch (state) {
  	    case 'welcome': 
		if (installPaths != '') {
		    ShowDiv('welcome', false);
		    ShowDiv('ioa', true);
		    state = 'ioa';
		
		} else if (CheckUtilities()) {
  		    ShowDiv('welcome', false);
  		    ShowDiv('mysql', true);
  		    state = 'mysql';		    
  		    utilitiesChecked = true;
  		} else {
  		    ShowDiv('welcome', false);
  		    ShowDiv('utilities', true);
  		    state = 'utilities';
  		}
  	    
  		el = document.getElementById('buttonPrevious'); 
  		if (el) {
  		    el.disabled = false;
  		}
  		break;
		
	    case 'ioa': 
		var actionInstall = document.getElementById('action0');
		if (actionInstall.checked) {
		    state = 'action_install';
		    document.forms.f['action'].value = 'install';
		    document.forms.f['cgi_path'].value = cgiPath;
		    return ButtonNext();
		    
		} else {
		    state = 'update';
		    document.forms.f.action.value = 'update';
		    
		    var radio = document.forms.f.djem_path;
		    for (var i=0; i < radio.length; ++i) {
			if (radio[i].checked) {
			    document.forms.f['cgi_path'].value = radio[i].value;
			}
		    }
		    
		    
		    return ButtonNext();
		}	    
	    
		break;
		
	    case 'action_install':
		if (CheckUtilities()) {
  		    ShowDiv('ioa', false);
  		    ShowDiv('mysql', true);
  		    state = 'mysql';		    
  		    utilitiesChecked = true;
  		} else {
  		    ShowDiv('ioa', false);
  		    ShowDiv('utilities', true);
  		    state = 'utilities';
  		}
	    
		break;
    
	    case 'update':
		if (CheckUtilities()) {
  		    ShowDiv('ioa', false);
  		    ShowDiv('install', true);
  		    state = 'install';		    
  		    utilitiesChecked = true;
		    
		    SetText('nextButtonName', '');
		    SetValue('buttonNext', '');

  		} else {
  		    ShowDiv('ioa', false);
  		    ShowDiv('utilities', true);
  		    state = 'utilities';
  		}
		
		break;
  
  	    case 'utilities': 	    
  		if (CheckUtilities()) {	    
  		    ShowDiv('utilities', false);
  		    ShowDiv('mysql', true);
  		    state = 'mysql';
  		    
  		    el = document.getElementById('mysql_base'); 
  		    if (el) {
  			el.focus();
  		    }		    
  		}
  		
  		break;
  
  
  	    case 'mysql':
  		if (CheckMySQL()) {	    
  		    ShowDiv('mysql', false);
		    if (databaseExists) {
  			ShowDiv('mysql_replace', true);
  			state = 'mysql_replace';
		    
		    } else {
  			ShowDiv('paths', true);
  			state = 'paths';
		    }
  		}
  		
  		break;
  
	    case 'mysql_replace':
		ShowDiv('mysql_replace', false);
		ShowDiv('paths', true);
  		state = 'paths';
		break;

  
  
  	    case 'paths':
  		if (CheckPaths()) {	    
  		    ShowDiv('paths', false);
  		    // ShowDiv('install', true);
		    
		    if (document.forms.f.mysql_replace[0].checked) {
			ShowDiv('password', true);
  			// state = 'install';
			state = 'password';
		    } else {
			ShowDiv('install', true);
  			state = 'install';
		    }
  		}
  		
  		break;
		
	    case 'password':
  		if (CheckPassword()) {	    
  		    ShowDiv('password', false);
  		    ShowDiv('install', true);
  		    state = 'install';
		    
		    document.getElementById('myRootPassword').innerHTML = document.forms.f.root_password.value.replace(/./g, '*');

		    SetText('nextButtonName', '');
		    SetValue('buttonNext', '');

  		}
	    
	    
		break;
		
  		
  	    case 'install':
  		if( f.license.value=="" ) {
  		    alert("  ' '");
  		    f.license.focus();
  		    return false;
  		}
  		
  		if (TryToInstall()) {
  		    ShowDiv('install', false);
		    
		    if (document.forms.f['action'].value == 'update') {
			ShowDiv('final_update', true);
  			state = 'final_update';
			
		    } else {
  			ShowDiv('final', true);
  			state = 'final';
		    }
  
  		    ShowDiv('buttons', false);
  		}
  
  				
  		break;
  
  		
  		
  	    default: 
  		alert("   ");
  		break;
  	}
      }
  
      
      function ButtonPrevious() {    
  	switch (state) {
  	    case 'welcome': 
  		break;
  
	    case 'ioa':
  	    	ShowDiv('ioa', false);
  		ShowDiv('welcome', true);
		state = 'welcome';
		
		el = document.getElementById('buttonPrevious'); 
  		if (el) {
  		    el.disabled = true;
  		}

		break;
  
  	    case 'utilities':
  		el = document.getElementById('buttonPrevious'); 
  		if (el) {
  		    el.disabled = true;
  		}
  	    
  	    	ShowDiv('utilities', false);
  		ShowDiv('welcome', true);
  
  		state = 'welcome';
  		break;
  
  
  	    case 'mysql':
  		if (utilitiesChecked) {
  	    	    ShowDiv('mysql', false);
		    
		    if (installPaths == '') {
      			ShowDiv('welcome', true);
  			state = 'welcome';
		    
  		    
  			el = document.getElementById('buttonPrevious'); 
  			if (el) {
  			    el.disabled = true;
  			}
		    } else {
			ShowDiv('ioa', true);
			state = 'ioa';		    
		    }
		    
  		} else {
  	    	    ShowDiv('mysql', false);
  		    ShowDiv('utilities', true);
  		    state = 'utilities';
  		}
  
  		break;
  
  
  	    case 'paths':
  	    	ShowDiv('paths', false);
		
		if (databaseExists) {
  		    ShowDiv('mysql_replace', true);
		    state = 'mysql_replace';
		    
		} else {
  		    ShowDiv('mysql', true);
		    state = 'mysql';
		}
  		break;

  	    case 'mysql_replace':
  	    	ShowDiv('mysql_replace', false);
  		ShowDiv('mysql', true);
  
  		state = 'mysql';
  		break;

	    case 'password':
  	    	ShowDiv('password', false);
  		ShowDiv('paths', true);
  
  		state = 'paths';
  		break;  
 
  	    case 'install':
  	    	ShowDiv('install', false);
		
		if (document.forms.f.action.value == 'update') {
		    ShowDiv('ioa', true);
		    state = 'ioa';
		    
		} else if (document.forms.f.mysql_replace[0].checked) {
  		    ShowDiv('password', true);
		    state = 'password';
		} else {
		    ShowDiv('paths', true);
		    state = 'paths';
		}
	
		SetValue('buttonNext', ' >>');
  
  		break;
  
  
  	    default: 
  		alert(" .");
  		break;
  	}
      }
  
      function ShowDiv(elName, showMode) {
  	el = document.getElementById('div_' + elName);
  	if (el) {
  	    el.style.display = showMode ? 'block' : 'none';
  	}
      }
  
  
      function CheckFocus(a) {
  	if (a.value.match(/[--]/)) {
  	    a.value = "";
  	}
      }
  
  
      function CheckUtilities() {
  	queryString = '';
      
  	tf = document.forms.f; 
  	for (i=0; i < tf.length; i++) {
  	    if (tf[i].name.substr(0,5) == 'path_') {
  		if (tf[i].value.match(/[--]/)) {
  		    alert(', ,   !');
  		    tf[i].focus();
  		    return false;
  		}
  		
  		if (tf[i].value != '') {
  		    queryString += '&' + tf[i].name + '=' + escape(tf[i].value);
  		}		
  		
  		utilityName = tf[i].name.substr(5);
  		el = document.getElementById('span_' + utilityName);
  		if (el) {
  		    el.style.color = '#000000';
  		}
  	    }
  	}
      
  	ac = new Date();
  	
  	request.open('POST', serverPath, false);
  	request.send('action=checkUtils&ac=' + ac.getTime() + queryString);
  
  	if (request.status != 200) {
  	    alert(" .   .    .\\n\\n" + request.responseText);
  	    return false;
  	}
  
  	if (request.responseText == 'ok') return true;
  	badPrograms = request.responseText.split(';');
  	once = 0;
  		
  	for (i=0; i < badPrograms.length; i++) {
  	    if (tf["path_" + badPrograms[i]]) {
  		el = document.getElementById('span_' + badPrograms[i]);
  		if (el) {
  		    el.style.color = '#990000';
  		}
  
  
  		if (tf["path_" + badPrograms[i]].value == '') {
  		    tf["path_" + badPrograms[i]].value = '    ';
  		} else {
      		    if (!once++) tf["path_" + badPrograms[i]].focus();
  		}
  	    }
  	}
  	        
  	return false;
      }
  
  
      var databaseExists = false;
  
      function CheckMySQL() {
  	queryString = '';
      
  	tf = document.forms.f; 
  	for (i=0; i < tf.length; i++) {
  	    if (tf[i].name.substr(0,6) == 'mysql_') {
  		if (tf[i].value.match(/[--]/) || tf[i].value == '') {
  		    if (tf[i].name != 'mysql_port' && tf[i].name != 'mysql_replace') {
  			alert(', , !');
  			tf[i].focus();
  		        return false;
  		    }
  		}
  		if (tf[i].value != '') {
  		    queryString += '&' + tf[i].name + '=' + escape(tf[i].value);
  		}		
  		
  		utilityName = tf[i].name.substr(6);
  		el = document.getElementById('span_' + utilityName);
  		if (el) {
  		    el.style.color = '#000000';
  		}
  	    }
  	}
      
  	ac = new Date();
  	
  	request.open('POST', serverPath, false);
  	request.send('action=checkMysql&ac=' + ac.getTime() + queryString);
  
  	if (request.status != 200) {
  	    alert(" .   .    .\\n\\n" + request.responseText);
  	    return false;
  	}
	
  	
  	if (request.responseText.substr(0,3) == 'ok:') {
  	    v = request.responseText.substr(3).split('.');
  	    version = (v[0]-0) * 100 + (v[1]-0);
  	    if (version < 401) {
  		alert ('  ,  DJEM        MySQL,     4.1       ');
  	    }
	    
	    databaseExists = v[2] == 'installed';
	    document.forms.f.mysql_replace[0].checked = !databaseExists;
	    document.forms.f.mysql_replace[1].checked = databaseExists;
	    
  	    return true;
  	}
  	if (request.responseText.match(/ERROR 1045/i)) {
  	    alert('  / : '+request.responseText);
  	    tf.mysql_user.focus();
  	    return false;
  	}
  
  	if (request.responseText.match(/ERROR 1044/i)) {
  	    alert('   ');
  	    tf.mysql_base.focus();
  	    return false;
  	}
  
  	if (request.responseText.match(/ERROR 2005/i)) {
  	    alert('   ');
  	    tf.mysql_base.focus();
  	    return false;
  	}
  	
  	alert("     -     .  : \\n\\n" + request.responseText);
  	        
  	return false;
      }
  
  
  
      function CheckPaths() {
  	queryString = '';
  
  	queryString += '&htdocs_path=' + escape(tf.htdocs_path.value);
  	queryString += '&cgi_path=' + escape(tf.cgi_path.value);
  
  	ac = new Date();
  	request.open('POST', serverPath, false);
  	request.send('action=checkPaths&ac=' + ac.getTime() + queryString);
  
  	if (request.status != 200) {
  	    alert(" .   .    .\\n\\n" + request.responseText);
  	    return false;
  	}
  	if (request.responseText == 'ok') return true;
  
  	if (request.responseText.indexOf('CGI: 1') != -1) {
  	    alert("CGI- '"+document.forms.f.cgi_path.value+"'  ,    ");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  	
  	if (request.responseText.indexOf('CGI: 2') != -1) {
  	    alert("       '"+document.forms.f.cgi_path.value+"'");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  
  	if (request.responseText.indexOf('CGI: 3') != -1) {
  	    alert("CGI- '"+document.forms.f.cgi_path.value+"'   ");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  
  	if (request.responseText.indexOf('HTDOCS: 1') != -1) {
  	    alert("    '"+document.forms.f.htdocs_path.value+"'  ,    ");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  
  	if (request.responseText.indexOf('HTDOCS: 2') != -1) {
  	    alert("       '"+document.forms.f.htdocs_path.value+"'");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  
  	if (request.responseText.indexOf('HTDOCS: 2') != -1) {
  	    alert("     '"+document.forms.f.htdocs_path.value+"'");
  	    tf.cgi_path.focus();
  	    return false;
  	}
  
  	        
  	return false;
      }




      function CheckPassword() {
        if (tf.root_password.value == '') {
	    alert('  ');
	    return false;	
	}
  	if (tf.root_password.value != tf.root_password2.value) {
	    alert('   ');
	    return false;	
	}
  
  	        
  	return true;
      }
  
  
  
      function TryToInstall() {
	DisableButton('buttonNext', true);
	DisableButton('buttonPrevious', true);
	
  	queryString = '';
      
  	tf = document.forms.f; 
  
  	for (i=0; i < tf.length; i++) {	    
  	    if (tf[i].value != '' && (tf[i].type != 'radio' || tf[i].checked) && (tf[i].type != 'checkbox' || tf[i].checked)) {
  	        queryString += '&' + tf[i].name + '=' + escape(tf[i].value);
  	    }
  	}
      
  	ac = new Date();
  	request.open('POST', serverPath, false);
  	request.send('ac=' + ac.getTime() + queryString);

	DisableButton('buttonNext', false);
	DisableButton('buttonPrevious', false);
		
  
  	if (request.status != 200) {
  	    alert(" .   .    .\\n\\n" + request.responseText);
  	    return false;
  	}
  	
  	if (request.responseText.substr(0,3) == 'ok:') {
  	    el = document.getElementById('divServerPath'); 
  	    if (el) {
  		el.innerHTML = request.responseText.substr(4);		
  	    }
  	    
  	    return true;
  	}
  	
  	alert(request.responseText);	
  	        
  	return false;
      }
  
  	function validate(f) {
  	    if (state != 'installing') {
  		ButtonNext();
  		return false;
  	    }
  	
  
  	    return true;
  	}

  </script>
  
</head>

<body>
<table width=100% cellspacing=0 cellpadding=0 border=0>
<tr valign=top>
  <td width=25%><center><img src="$ENV{SCRIPT_NAME}?action=getImage&name=setup" alt=""></center></td>
  <td style="padding: 1.2em 2.4em">
    <table width=100% cellspacing=0 cellpadding=0 border=0 style="border-bottom: 1px solid silver">
    <tr valign=top>
      <td style="padding: 0.3em 0.6em 0.3em 0"><h1>  DJEM</h1></td>
    </tr>
    </table>

  	<form name=f method=post onsubmit="return validate(this)" action="$ENV{SCRIPT_NAME}">
    	<input type=hidden name=action value="install">
  
  
    <div style="height: 450" id=div_welcome>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g"> !</span></h3>
    	<div style="color: gray; font-size: 80%">
    	    <P id=b>          DJEM.</P>
    	    <P id=b>       ,            .</P>
    	    <P id=b>          -      MySQL ( ,  ,      )   ,        .</P>
    	    <P id=b>   , ,  "".</P>
    	</div>
    </div>
    
    
    <div style="display: none; height: 450" id="div_ioa">
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">  ?</span></h3>
    	<div style="color: gray; font-size: 80%">
    	    <P id=b> ,      ,     DJEM.</P>
    	    <P id=b>      &mdash;    .        &mdash;  "   DJEM".</P>
	    <label for="action0"><input type="radio" id="action0" name="djem_path" value="" $defaultChecked>   </label>
	    $installPathsRadio
    	</div>
    </div>
    
    
    
    <div style="display: none; height: 450" id=div_utilities>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">  </span></h3>
    	<div style="color: gray; font-size: 80%">
      	<P id=b>           . ,	     -       -     "".</P>
      	<table width="100%" cellspacing="0" cellpadding="5" border="0">	
        <tr valign=top>
          <td class=research1><p class=big2 id=span_tar> tar:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_tar value="" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2 id=span_uname> uname:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_uname value=""  onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2 id=span_wget> wget:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_wget value="" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2 id=span_lynx> lynx ()</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_lynx value="" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2 id=span_mysql> mysql:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_mysql value="" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2 id=span_mysql_config> ldd:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=path_ldd value="" onfocus="CheckFocus(this)"></td>
        </tr>
        </table>
      </div>
    </div>
    
    
    <div style="display: none; height: 450" id=div_mysql>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">    MySQL</span></h3>
    	<div style="color: gray; font-size: 80%">
      	<P id=b>        MySQL. ,        "".</P>
      	<table width="100%" cellspacing="0" cellpadding="5" border="0">	
        <tr valign=top>
          <td class=research1><p class=big2>:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=mysql_host value="localhost" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2> (     ):</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=mysql_port value="$mysql_sock" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2> :</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=mysql_base value=""  onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2>:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=mysql_user value="" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2></p></td>
          <td class=research><input class=f_login1 type=text size=70% name=mysql_password value="" onfocus="CheckFocus(this)"></td>
        </tr>
        </table>
      </div>
    </div>
    
    
    <div style="display: none; height: 450" id=div_mysql_replace>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">   MySQL</span></h3>
    	<div style="color: gray; font-size: 80%">
      	<P id=b> ,        DJEM.    ,       -   "    ".</P>
      	<label for="replace0"><input type="radio" name="mysql_replace" value="on" id="replace0">    </label>
      	<label for="replace1"><input type="radio" name="mysql_replace" value="" id="replace1">     </label>
      </div>
    </div>
    
    <div style="display: none; height: 450" id=div_paths>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g"> </span></h3>
    	<div style="color: gray; font-size: 80%">
      	<P id=b> ,       ,   CGI-    HTML- (,     )     -.     CGI      ,         HTML-      DJEM.   ,      ,    "".</P>
      	<table width="100%" cellspacing="0" cellpadding="5" border="0">	
        <tr valign=top>
          <td class=research1><p class=big2>HTML-root:</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=htdocs_path value="$htdocs_path" onfocus="CheckFocus(this)"></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2>CGI-BIN :</p></td>
          <td class=research><input class=f_login1 type=text size=70% name=cgi_path value="$cgi_path"  onfocus="CheckFocus(this)"></td>
        </tr>
        </table>
      </div>
    </div>
    
    
    <div style="display: none; height: 450;" id=div_install>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g"> </span></h3>
    	<div style="color: gray; font-size: 80%">	
        <input type=hidden name=mysql value="" >
        <input type=hidden name=os value="$uname" >
        <input type=hidden name=arch value="$arch" >
        <input type=hidden name=libs value="$sys_libs" >
        <br>
      	<P id=b>       ! ,    -   ,     ,    "<span id="nextButtonName"></span>".</P>
        <table width="100%" cellspacing="0" cellpadding="5" border="0">	
        <tr valign=top>
          <td class=research1><p class=big2>  :</p></td>
          <td class=research><input class=f_login1 type=text size=50% name=license><br><br>
	  </td>
        </tr>
        </table>
	
	
      </div>
    </div>
    
    
    <div style="display: none; height: 450;" id=div_password>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g"> </span></h3>
    	<div style="color: gray; font-size: 80%">	
        <br>
      	<P id=b>    DJEM-    ,      .</P>
        <table width="100%" cellspacing="0" cellpadding="5" border="0">	
        <tr valign=top>
          <td class=research1><p class=big2> :</p></td>
          <td class=research><input class=f_login1 type=password size=50% name=root_password><br><br></td>
        </tr>
        <tr valign=top>
          <td class=research1><p class=big2>  :</p></td>
          <td class=research><input class=f_login1 type=password size=50% name=root_password2><br><br></td>
        </tr>
        </table>
      </div>
    </div>
    
    
    <div style="display: none; height: 450;" id=div_final>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">!</span></h3>
    	<div style="color: gray; font-size: 80%">	
      	<input type=hidden name=mysql value="" >
        <input type=hidden name=os value="$uname" >
        <input type=hidden name=libs value="$sys_libs" ><br>
      	<P id=b>   .   ,  ,       DJEM.     ,  !</P>
      	<P>&nbsp;</P>
        <P id=b style="border: 1px solid #888888; padding: 15px">: <b>$hostName</b><br>: <b><span id=divServerPath></span></b><br>: <b>root</b><br>: <b id="myRootPassword">root</b><br></P>
      </div>
    </div>
    
    <div style="display: none; height: 450;" id=div_final_update>
    	<h3 id="mb15" style="margin-top: 1.5em"><span id="g">!</span></h3>
    	<div style="color: gray; font-size: 80%">	
      	<P id=b>   !</P>
      </div>
    </div>
    
    

    
    
    <div id=div_buttons>
      <table width=100%>
      <tr>
        <td align=right><input type=button style="width: 20%" value="<< " disabled id=buttonPrevious onclick="ButtonPrevious()"><input type=button style="width: 20%" value=" >>" onclick="ButtonNext()" id=buttonNext>
	</td>
      </tr>
      </table>
    </div>
    
    </form>
  </td>
</tr>
</table>

</body>
</html>
__EOS__


    }
}




# ---------------------------------------- main --------------------------------------
my ($form,$query,$action);

($form,$query)=parseCgiRequest();
$action=$form->{action};

if( $action eq "install" ) {
    installDjemServer($form,$query);
} elsif( $action eq "update" ) {
    updateDjemServer($form,$query);
} elsif( $action eq "checkUtils" ) {
    checkSystemUtils($form);
} elsif( $action eq "checkMysql" ) {
    checkMysqlAccess($form);
} elsif( $action eq "checkPaths" ) {
    checkPathPermissions($form);
} elsif( $action eq "getImage" ) {
    getImage($form->{name});
} else {
    showInterface();
}



